diff -pruN 1.17.1-1/appveyor.yml 2.0.0-1/appveyor.yml
--- 1.17.1-1/appveyor.yml	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/appveyor.yml	2020-11-23 15:42:41.000000000 +0000
@@ -5,9 +5,6 @@ environment:
     - PYTHON: C:\Python37-x64
       PYTHON_VERSION: 3.7
       PYTHON_ARCH: 64
-    - PYTHON: C:\Python27
-      PYTHON_VERSION: 2.7
-      PYTHON_ARCH: 32
 
 cache:
   # Cache downloaded pip packages and built wheels.
@@ -16,7 +13,8 @@ cache:
 
 install:
   - "SET PATH=%PYTHON%;%PYTHON%\\Scripts;%PATH%"
-  - "pip install pytest pytest-cov pytest-dependency setuptools flake8 coverage chardet codecov"
+  - "pip install codecov chardet setuptools"
+  - "pip install -e \".[dev]\"" # install the codespell dev packages
   - "python setup.py develop"
 
 build: false  # Not a C# project, build stuff at the test step instead.
diff -pruN 1.17.1-1/codecov.yml 2.0.0-1/codecov.yml
--- 1.17.1-1/codecov.yml	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codecov.yml	2020-11-23 15:42:41.000000000 +0000
@@ -1 +1,8 @@
 comment: off
+coverage:
+  status:
+    project:
+      default:
+        # basic
+        target: auto
+        threshold: 1%
diff -pruN 1.17.1-1/codespell_lib/_codespell.py 2.0.0-1/codespell_lib/_codespell.py
--- 1.17.1-1/codespell_lib/_codespell.py	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/_codespell.py	2020-11-23 15:42:41.000000000 +0000
@@ -21,34 +21,55 @@ from __future__ import print_function
 
 import argparse
 import codecs
+import configparser
 import fnmatch
 import os
 import re
 import sys
+import textwrap
 
 word_regex_def = u"[\\w\\-'’`]+"
 encodings = ('utf-8', 'iso-8859-1')
 USAGE = """
 \t%prog [OPTIONS] [file1 file2 ... fileN]
 """
-VERSION = '1.17.1'
+VERSION = '2.0.0'
+
+supported_languages_en = ('en', 'en_GB', 'en_US', 'en_CA', 'en_AU')
+supported_languages = supported_languages_en
 
 # Users might want to link this file into /usr/local/bin, so we resolve the
 # symbolic link path to the real path if necessary.
 _data_root = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'data')
 _builtin_dictionaries = (
-    # name, desc, name, err in aspell, correction in aspell
+    # name, desc, name, err in aspell, correction in aspell, \
+    # err dictionary array, rep dictionary array
+    # The arrays must contain the names of aspell dictionaries
     # The aspell tests here aren't the ideal state, but the None's are
     # realistic for obscure words
-    ('clear', 'for unambiguous errors', '', False, None),
-    ('rare', 'for rare but valid words', '_rare', None, None),
-    ('informal', 'for informal words', '_informal', True, True),
-    ('code', 'for words common to code and/or mathematics', '_code', None, None),  # noqa: E501
-    ('names', 'for valid proper names that might be typos', '_names', None, None),  # noqa: E501
-    ('en-GB_to_en-US', 'for corrections from en-GB to en-US', '_en-GB_to_en-US', True, True),  # noqa: E501
+    ('clear', 'for unambiguous errors', '',
+        False, None, supported_languages_en, None),
+    ('rare', 'for rare but valid words', '_rare',
+        None, None, None, None),
+    ('informal', 'for informal words', '_informal',
+        True, True, supported_languages_en, supported_languages_en),
+    ('usage', 'for recommended terms', '_usage',
+        None, None, None, None),
+    ('code', 'for words common to code and/or mathematics', '_code',
+        None, None, None, None,),
+    ('names', 'for valid proper names that might be typos', '_names',
+        None, None, None, None,),
+    ('en-GB_to_en-US', 'for corrections from en-GB to en-US', '_en-GB_to_en-US',  # noqa: E501
+        True, True, ('en_GB',), ('en_US',)),
 )
 _builtin_default = 'clear,rare'
 
+# docs say os.EX_USAGE et al. are only available on Unix systems, so to be safe
+# we protect and just use the values they are on macOS and Linux
+EX_OK = 0
+EX_USAGE = 64
+EX_DATAERR = 65
+
 # OPTIONS:
 #
 # ARGUMENTS:
@@ -162,12 +183,12 @@ class FileOpener(object):
         try:
             f = codecs.open(filename, 'r', encoding=encoding)
         except UnicodeDecodeError:
-            print('ERROR: Could not detect encoding: %s' % filename,
+            print("ERROR: Could not detect encoding: %s" % filename,
                   file=sys.stderr)
             raise
         except LookupError:
-            print('ERROR: %s -- Don\'t know how to handle encoding %s'
-                  % (filename, encoding), file=sys.stderr)
+            print("ERROR: Don't know how to handle encoding %s: %s"
+                  % (encoding, filename,), file=sys.stderr)
             raise
         else:
             lines = f.readlines()
@@ -182,12 +203,10 @@ class FileOpener(object):
                 f = codecs.open(filename, 'r', encoding=encodings[curr])
             except UnicodeDecodeError:
                 if not self.quiet_level & QuietLevels.ENCODING:
-                    print('WARNING: Decoding file %s' % filename,
-                          file=sys.stderr)
-                    print('WARNING: using encoding=%s failed. '
-                          % encodings[curr], file=sys.stderr)
+                    print("WARNING: Decoding file using encoding=%s failed: %s"
+                          % (encodings[curr], filename,), file=sys.stderr)
                     try:
-                        print('WARNING: Trying next encoding: %s'
+                        print("WARNING: Trying next encoding %s"
                               % encodings[curr + 1], file=sys.stderr)
                     except IndexError:
                         pass
@@ -207,8 +226,34 @@ class FileOpener(object):
 # -.-:-.-:-.-:-.:-.-:-.-:-.-:-.-:-.:-.-:-.-:-.-:-.-:-.:-.-:-
 
 
+# If someday this breaks, we can just switch to using RawTextHelpFormatter,
+# but it has the disadvantage of not wrapping our long lines.
+
+class NewlineHelpFormatter(argparse.HelpFormatter):
+    """Help formatter that preserves newlines and deals with lists."""
+
+    def _split_lines(self, text, width):
+        parts = text.split('\n')
+        out = list()
+        for pi, part in enumerate(parts):
+            # Eventually we could allow others...
+            indent_start = '- '
+            if part.startswith(indent_start):
+                offset = len(indent_start)
+            else:
+                offset = 0
+            part = part[offset:]
+            part = self._whitespace_matcher.sub(' ', part).strip()
+            parts = textwrap.wrap(part, width - offset)
+            parts = [' ' * offset + p for p in parts]
+            if offset:
+                parts[0] = indent_start + parts[0][offset:]
+            out.extend(parts)
+        return out
+
+
 def parse_options(args):
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(formatter_class=NewlineHelpFormatter)
 
     parser.set_defaults(colors=sys.stdout.isatty())
     parser.add_argument('--version', action='version', version=VERSION)
@@ -228,34 +273,40 @@ def parse_options(args):
 
     parser.add_argument('-D', '--dictionary',
                         action='append',
-                        help='Custom dictionary file that contains spelling '
+                        help='custom dictionary file that contains spelling '
                              'corrections. If this flag is not specified or '
                              'equals "-" then the default dictionary is used. '
                              'This option can be specified multiple times.')
-    builtin_opts = ', '.join(
-        '%r %s' % (d[0], d[1]) for d in _builtin_dictionaries)
+    builtin_opts = '\n- '.join([''] + [
+        '%r %s' % (d[0], d[1]) for d in _builtin_dictionaries])
     parser.add_argument('--builtin',
                         dest='builtin', default=_builtin_default,
                         metavar='BUILTIN-LIST',
-                        help='Comma-separated list of builtin dictionaries '
+                        help='comma-separated list of builtin dictionaries '
                         'to include (when "-D -" or no "-D" is passed). '
-                        'Current options are:\n%s. The default is '
-                        '"--builtin %s".'
-                        % (builtin_opts, _builtin_default))
+                        'Current options are:' + builtin_opts + '\n'
+                        'The default is %(default)r.')
+    parser.add_argument('--ignore-regex',
+                        action='store', type=str,
+                        help='regular expression which is used to find '
+                             'patterns to ignore by treating as whitespace. '
+                             'When writing regexes, consider ensuring there '
+                             'are boundary non-word chars, e.g., '
+                             '"\\Wmatch\\W". Defaults to empty/disabled.')
     parser.add_argument('-I', '--ignore-words',
                         action='append', metavar='FILE',
-                        help='File that contains words which will be ignored '
+                        help='file that contains words which will be ignored '
                              'by codespell. File must contain 1 word per line.'
                              ' Words are case sensitive based on how they are '
                              'written in the dictionary file')
     parser.add_argument('-L', '--ignore-words-list',
                         action='append', metavar='WORDS',
-                        help='Comma separated list of words to be ignored '
+                        help='comma separated list of words to be ignored '
                              'by codespell. Words are case sensitive based on '
                              'how they are written in the dictionary file')
     parser.add_argument('-r', '--regex',
                         action='store', type=str,
-                        help='Regular expression which is used to find words. '
+                        help='regular expression which is used to find words. '
                              'By default any alphanumeric character, the '
                              'underscore, the hyphen, and the apostrophe is '
                              'used to build words. This option cannot be '
@@ -264,37 +315,47 @@ def parse_options(args):
                         action='store_true', default=False,
                         help='print summary of fixes')
 
+    parser.add_argument('--count',
+                        action='store_true', default=False,
+                        help='print the number of errors as the last line of '
+                             'stderr')
+
     parser.add_argument('-S', '--skip',
                         action='append',
-                        help='Comma-separated list of files to skip. It '
+                        help='comma-separated list of files to skip. It '
                              'accepts globs as well. E.g.: if you want '
                              'codespell to skip .eps and .txt files, '
                              'you\'d give "*.eps,*.txt" to this option.')
 
     parser.add_argument('-x', '--exclude-file', type=str, metavar='FILE',
-                        help='FILE with lines that should not be changed')
+                        help='FILE with lines that should not be checked for '
+                             'errors or changed')
 
     parser.add_argument('-i', '--interactive',
                         action='store', type=int, default=0,
-                        help='Set interactive mode when writing changes. '
-                             '0: no interactivity. 1: ask for confirmation. '
-                             '2 ask user to choose one fix when more than one '
-                             'is available. 3: both 1 and 2')
+                        help='set interactive mode when writing changes:\n'
+                             '- 0: no interactivity.\n'
+                             '- 1: ask for confirmation.\n'
+                             '- 2: ask user to choose one fix when more than one is available.\n'  # noqa: E501
+                             '- 3: both 1 and 2')
 
     parser.add_argument('-q', '--quiet-level',
-                        action='store', type=int, default=0,
-                        help='Bitmask that allows codespell to run quietly. '
-                             '0: the default, in which all messages are '
-                             'printed. 1: disable warnings about wrong '
-                             'encoding. 2: disable warnings about binary '
-                             'file. 4: shut down warnings about automatic '
-                             'fixes that were disabled in dictionary. '
-                             '8: don\'t print anything for non-automatic '
-                             'fixes. 16: don\'t print fixed files.')
+                        action='store', type=int, default=2,
+                        help='bitmask that allows suppressing messages:\n'
+                             '- 0: print all messages.\n'
+                             '- 1: disable warnings about wrong encoding.\n'
+                             '- 2: disable warnings about binary files.\n'
+                             '- 4: omit warnings about automatic fixes that were disabled in the dictionary.\n'  # noqa: E501
+                             '- 8: don\'t print anything for non-automatic fixes.\n'  # noqa: E501
+                             '- 16: don\'t print the list of fixed files.\n'
+                             'As usual with bitmasks, these levels can be '
+                             'combined; e.g. use 3 for levels 1+2, 7 for '
+                             '1+2+4, 23 for 1+2+4+16, etc. '
+                             'The default mask is %(default)s.')
 
     parser.add_argument('-e', '--hard-encoding-detection',
                         action='store_true', default=False,
-                        help='Use chardet to detect the encoding of each '
+                        help='use chardet to detect the encoding of each '
                              'file. This can slow down codespell, but is more '
                              'reliable in detecting encodings other than '
                              'utf-8, iso8859-1, and ascii.')
@@ -305,20 +366,47 @@ def parse_options(args):
 
     parser.add_argument('-H', '--check-hidden',
                         action='store_true', default=False,
-                        help='check hidden files (those starting with ".") as '
-                             'well')
+                        help='check hidden files and directories (those '
+                             'starting with ".") as well.')
     parser.add_argument('-A', '--after-context', type=int, metavar='LINES',
                         help='print LINES of trailing context')
     parser.add_argument('-B', '--before-context', type=int, metavar='LINES',
                         help='print LINES of leading context')
     parser.add_argument('-C', '--context', type=int, metavar='LINES',
                         help='print LINES of surrounding context')
+    parser.add_argument('--config', type=str,
+                        help='path to config file.')
 
     parser.add_argument('files', nargs='*',
                         help='files or directories to check')
 
+    # Parse command line options.
     options = parser.parse_args(list(args))
 
+    # Load config files and look for ``codespell`` options.
+    cfg_files = ['setup.cfg', '.codespellrc']
+    if options.config:
+        cfg_files.append(options.config)
+    config = configparser.ConfigParser()
+    config.read(cfg_files)
+
+    if config.has_section('codespell'):
+        # Build a "fake" argv list using option name and value.
+        cfg_args = []
+        for key in config['codespell']:
+            # Add option as arg.
+            cfg_args.append("--%s" % key)
+            # If value is blank, skip.
+            val = config['codespell'][key]
+            if val != "":
+                cfg_args.append(val)
+
+        # Parse config file options.
+        options = parser.parse_args(cfg_args)
+
+        # Re-parse command line options to override config.
+        options = parser.parse_args(list(args), namespace=options)
+
     if not options.files:
         options.files.append('.')
 
@@ -448,8 +536,14 @@ def print_context(lines, index, context)
             print('%s %s' % ('>' if i == index else ':', lines[i].rstrip()))
 
 
+def extract_words(text, word_regex, ignore_word_regex):
+    if ignore_word_regex:
+        text = ignore_word_regex.sub(' ', text)
+    return word_regex.findall(text)
+
+
 def parse_file(filename, colors, summary, misspellings, exclude_lines,
-               file_opener, word_regex, context, options):
+               file_opener, word_regex, ignore_word_regex, context, options):
     bad_count = 0
     lines = None
     changed = False
@@ -459,11 +553,8 @@ def parse_file(filename, colors, summary
         f = sys.stdin
         lines = f.readlines()
     else:
-        # ignore binary files
-        if not os.path.isfile(filename):
-            return 0
         if options.check_filenames:
-            for word in word_regex.findall(filename):
+            for word in extract_words(filename, word_regex, ignore_word_regex):
                 lword = word.lower()
                 if lword not in misspellings:
                     continue
@@ -496,15 +587,19 @@ def parse_file(filename, colors, summary
                          'WRONGWORD': cwrongword,
                          'RIGHTWORD': crightword, 'REASON': creason})
 
+        # ignore irregular files
+        if not os.path.isfile(filename):
+            return bad_count
+
         text = is_text_file(filename)
         if not text:
             if not options.quiet_level & QuietLevels.BINARY_FILE:
-                print("WARNING: Binary file: %s " % filename, file=sys.stderr)
-            return 0
+                print("WARNING: Binary file: %s" % filename, file=sys.stderr)
+            return bad_count
         try:
             lines, encoding = file_opener.open(filename)
         except Exception:
-            return 0
+            return bad_count
 
     for i, line in enumerate(lines):
         if line in exclude_lines:
@@ -513,7 +608,7 @@ def parse_file(filename, colors, summary
         fixed_words = set()
         asked_for = set()
 
-        for word in word_regex.findall(line):
+        for word in extract_words(line, word_regex, ignore_word_regex):
             lword = word.lower()
             if lword in misspellings:
                 context_shown = False
@@ -608,27 +703,38 @@ def main(*args):
     options, parser = parse_options(args)
 
     if options.regex and options.write_changes:
-        print('ERROR: --write-changes cannot be used together with '
-              '--regex')
+        print("ERROR: --write-changes cannot be used together with "
+              "--regex")
         parser.print_help()
-        return 1
+        return EX_USAGE
     word_regex = options.regex or word_regex_def
     try:
         word_regex = re.compile(word_regex)
     except re.error as err:
-        print('ERROR: invalid regular expression "%s" (%s)' %
+        print("ERROR: invalid --regex \"%s\" (%s)" %
               (word_regex, err), file=sys.stderr)
         parser.print_help()
-        return 1
+        return EX_USAGE
+
+    if options.ignore_regex:
+        try:
+            ignore_word_regex = re.compile(options.ignore_regex)
+        except re.error as err:
+            print("ERROR: invalid --ignore-regex \"%s\" (%s)" %
+                  (options.ignore_regex, err), file=sys.stderr)
+            parser.print_help()
+            return EX_USAGE
+    else:
+        ignore_word_regex = None
 
     ignore_words_files = options.ignore_words or []
     ignore_words = set()
     for ignore_words_file in ignore_words_files:
         if not os.path.isfile(ignore_words_file):
-            print('ERROR: cannot find ignore-words file: %s' %
+            print("ERROR: cannot find ignore-words file: %s" %
                   ignore_words_file, file=sys.stderr)
             parser.print_help()
-            return 1
+            return EX_USAGE
         build_ignore_words(ignore_words_file, ignore_words)
 
     ignore_words_list = options.ignore_words_list or []
@@ -653,16 +759,16 @@ def main(*args):
                                          % (builtin[2],)))
                         break
                 else:
-                    print('ERROR: Unknown builtin dictionary: %s' % (u,),
+                    print("ERROR: Unknown builtin dictionary: %s" % (u,),
                           file=sys.stderr)
                     parser.print_help()
-                    return 1
+                    return EX_USAGE
         else:
             if not os.path.isfile(dictionary):
-                print('ERROR: cannot find dictionary file: %s' % dictionary,
+                print("ERROR: cannot find dictionary file: %s" % dictionary,
                       file=sys.stderr)
                 parser.print_help()
-                return 1
+                return EX_USAGE
             use_dictionaries.append(dictionary)
     misspellings = dict()
     for dictionary in use_dictionaries:
@@ -680,10 +786,10 @@ def main(*args):
     if options.context is not None:
         if (options.before_context is not None) or \
                 (options.after_context is not None):
-            print('ERROR: --context/-C cannot be used together with '
-                  '--context-before/-B or --context-after/-A')
+            print("ERROR: --context/-C cannot be used together with "
+                  "--context-before/-B or --context-after/-A")
             parser.print_help()
-            return 1
+            return EX_USAGE
         context_both = max(0, options.context)
         context = (context_both, context_both)
     elif (options.before_context is not None) or \
@@ -715,17 +821,21 @@ def main(*args):
                 if glob_match.match(root):  # skip (absolute) directories
                     del dirs[:]
                     continue
+                if is_hidden(root, options.check_hidden):  # dir itself hidden
+                    continue
                 for file_ in files:
+                    # ignore hidden files in directories
+                    if is_hidden(file_, options.check_hidden):
+                        continue
                     if glob_match.match(file_):  # skip files
                         continue
                     fname = os.path.join(root, file_)
                     if glob_match.match(fname):  # skip paths
                         continue
-                    if not os.path.isfile(fname) or not os.path.getsize(fname):
-                        continue
                     bad_count += parse_file(
                         fname, colors, summary, misspellings, exclude_lines,
-                        file_opener, word_regex, context, options)
+                        file_opener, word_regex, ignore_word_regex, context,
+                        options)
 
                 # skip (relative) directories
                 dirs[:] = [dir_ for dir_ in dirs if not glob_match.match(dir_)]
@@ -733,9 +843,11 @@ def main(*args):
         else:
             bad_count += parse_file(
                 filename, colors, summary, misspellings, exclude_lines,
-                file_opener, word_regex, context, options)
+                file_opener, word_regex, ignore_word_regex, context, options)
 
     if summary:
         print("\n-------8<-------\nSUMMARY:")
         print(summary)
-    return bad_count
+    if options.count:
+        print(bad_count, file=sys.stderr)
+    return EX_DATAERR if bad_count else EX_OK
diff -pruN 1.17.1-1/codespell_lib/data/dictionary_code.txt 2.0.0-1/codespell_lib/data/dictionary_code.txt
--- 1.17.1-1/codespell_lib/data/dictionary_code.txt	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/data/dictionary_code.txt	2020-11-23 15:42:41.000000000 +0000
@@ -1,23 +1,49 @@
 amin->main
-cas->case
+apoint->appoint
+atend->attend
+atending->attending
+cas->case, cast,
 clas->class
+cloneable->clonable
 cmo->com
+copyable->copiable
 define'd->defined
 dof->of, doff,
 dont->don't
+dur->due
+endcode->encode
+errorstring->error string
+files'->file's
+gae->game, Gael, gale,
+iam->I am, aim,
 iff->if
 ith->with
+keyserver->key server
+lateset->latest
 movei->movie
 mut->must, mutt, moot,
 nto->not
+objext->object
+od->of
+process'->process's
+protecten->protection
+reday->ready
 referer->referrer
 rela->real
-secant->second
-secants->seconds
 seeked->sought
 sinc->sync, sink, since,
 sincs->syncs, sinks, since,
+stdio->studio
+stdios->studios
 stoll->still
+storaged->storage, stored,
+storaget->storage
+subpatchs->subpatches
+subprocess'->subprocess's
 thead->thread
 todays->today's
+udate->update, date,
+udates->updates, dates,
 uint->unit
+were'->we're
+whome->whom
diff -pruN 1.17.1-1/codespell_lib/data/dictionary_en-GB_to_en-US.txt 2.0.0-1/codespell_lib/data/dictionary_en-GB_to_en-US.txt
--- 1.17.1-1/codespell_lib/data/dictionary_en-GB_to_en-US.txt	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/data/dictionary_en-GB_to_en-US.txt	2020-11-23 15:42:41.000000000 +0000
@@ -1,4 +1,10 @@
+acknowledgement->acknowledgment
+acknowledgements->acknowledgments
+amortise->amortize
 amortised->amortized
+amortises->amortizes
+amortising->amortizing
+analogue->analog
 analyse->analyze
 analysed->analyzed
 analyser->analyzer
@@ -7,58 +13,253 @@ analyses->analyzes
 analysing->analyzing
 artefact->artifact
 artefacts->artifacts
+authorisation->authorization
+authorise->authorize
+authorised->authorized
+authorises->authorizes
+authorising->authorizing
 behaviour->behavior
+behaviours->behaviors
 cancelled->canceled
 cancelling->canceling
+capitalisation->capitalization
 capitalise->capitalize
+capitalised->capitalized
+capitalises->capitalizes
+capitalising->capitalizing
 catalogue->catalog
+catalogues->catalogs
 centimetre->centimeter
 centimetres->centimeters
+centralisation->centralization
 centralise->centralize
+centralised->centralized
+centralises->centralizes
+centralising->centralizing
 centre->center
+centres->centers
+characterisation->characterization
+characterise->characterize
 characterised->characterized
+characterises->characterizes
+characterising->characterizing
 colour->color
+colourful->colorful
+colourfully->colorfully
 colouring->coloring
 colours->colors
 counsellor->counselor
+criticise->criticize
 criticised->criticized
+criticises->criticizes
+criticising->criticizing
+crystallisation->crystallization
+crystallise->crystallize
+crystallised->crystallized
+crystallises->crystallizes
+crystallising->crystallizing
+customisation->customization
+customise->customize
+customised->customized
+customises->customizes
 customising->customizing
+defence->defense
+demonise->demonize
+demonised->demonized
+demonises->demonizes
+demonising->demonizing
 dialogue->dialog
+digitisation->digitization
 digitise->digitize
+digitised->digitized
+digitises->digitizes
 digitising->digitizing
+emphasise->emphasize
 emphasised->emphasized
+emphasises->emphasizes
+emphasising->emphasizing
+endeavour->endeavor
+endeavours->endeavors
+favour->favor
+favourite->favorite
+favourites->favorites
+favouritism->favoritism
+favours->favors
+finalisation->finalization
+finalise->finalize
+finalised->finalized
+finalises->finalizes
+finalising->finalizing
 flavour->flavor
 flavours->flavors
+fulfil->fulfill
+fulfils->fulfills
+generalisation->generalization
+generalisations->generalizations
+generalise->generalize
+generalised->generalized
+generalises->generalizes
+generalising->generalizing
+grey->gray
+honour->honor
+honours->honors
 initialisation->initialization
 initialise->initialize
 initialised->initialized
 initialises->initializes
 initialising->initializing
+judgement->judgment
+judgements->judgments
 kilometre->kilometer
 kilometres->kilometers
 labelled->labeled
 labelling->labeling
 labour->labor
+legalisation->legalization
+legalise->legalize
+legalised->legalized
+legalises->legalizes
+legalising->legalizing
 licence->license
+licences->licenses
 manoeuvre->maneuver
 manoeuvres->maneuvers
+memorisation->memorization
 memorise->memorize
+memorised->memorized
+memorises->memorizes
+memorising->memorizing
 metre->meter
 metres->meters
 millimetre->millimeter
 millimetres->millimeters
+minimisation->minimization
 minimise->minimize
+minimised->minimized
+minimises->minimizes
 minimising->minimizing
 mitre->miter
+modelled->modeled
+modelling->modeling
 mould->mold
+moulds->molds
+nasalisation->nasalization
+neighbour->neighbor
+neighbouring->neighboring
+neighbours->neighbors
+normalisation->normalization
+normalise->normalize
+normalised->normalized
+normalises->normalizes
+normalising->normalizing
+optimisation->optimization
+optimisations->optimizations
+optimise->optimize
+optimised->optimized
+optimiser->optimizer
+optimises->optimizes
+optimising->optimizing
 organisation->organization
+organisations->organizations
+organise->organize
+organised->organized
+organiser->organizer
+organisers->organizers
+organises->organizes
+organising->organizing
+plagiarise->plagiarize
+plagiarised->plagiarized
+plagiarises->plagiarizes
+plagiarising->plagiarizing
+polarise->polarize
+polarised->polarized
+polarises->polarizes
+polarising->polarizing
+practise->practice
+prioritisation->prioritization
 prioritise->prioritize
+prioritised->prioritized
+prioritises->prioritizes
 prioritising->prioritizing
+publicise->publicize
+publicised->publicized
+publicises->publicizes
+publicising->publicizing
+realisation->realization
 realise->realize
+realised->realized
+realises->realizes
+realising->realizing
+recognise->recognize
+recognised->recognized
+recognises->recognizes
+recognising->recognizing
+regularisation->regularization
+regularise->regularize
+regularised->regularized
+regularises->regularizes
+regularising->regularizing
+reinitialise->reinitialize
+reinitialised->reinitialized
+reorganisation->reorganization
+reorganise->reorganize
+reorganised->reorganized
+reorganises->reorganizes
+reorganising->reorganizing
+sanitise->sanitize
 sanitised->sanitized
+sanitiser->sanitizer
+sanitises->sanitizes
+sanitising->sanitizing
 serialisation->serialization
 serialise->serialize
+serialised->serialized
+serialises->serializes
+serialising->serializing
+skilful->skillful
+skilfully->skillfully
+skilfulness->skillfulness
+specialisation->specialization
 specialise->specialize
 specialised->specialized
+specialises->specializes
+specialising->specializing
+specialities->specialties
+speciality->specialty
+splendour->splendor
+standardisation->standardization
+standardise->standardize
+standardised->standardized
+standardises->standardizes
+standardising->standardizing
+sterilisation->sterilization
+sterilise->sterilize
+sterilised->sterilized
+steriliser->sterilizer
+sterilises->sterilizes
+sterilising->sterilizing
+summarise->summarize
+summarised->summarized
+summarises->summarizes
+summarising->summarizing
+synchronisation->synchronization
+synchronise->synchronize
+synchronised->synchronized
+synchronises->synchronizes
+synchronising->synchronizing
+unauthorised->unauthorized
+unorganised->unorganized
+unrecognised->unrecognized
+utilisation->utilization
 utilise->utilize
 utilised->utilized
+utilises->utilizes
+utilising->utilizing
+virtualisation->virtualization
+visualisation->visualization
+visualisations->visualizations
+visualise->visualize
+visualised->visualized
+visualiser->visualizer
+visualises->visualizes
+visualising->visualizing
diff -pruN 1.17.1-1/codespell_lib/data/dictionary_names.txt 2.0.0-1/codespell_lib/data/dictionary_names.txt
--- 1.17.1-1/codespell_lib/data/dictionary_names.txt	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/data/dictionary_names.txt	2020-11-23 15:42:41.000000000 +0000
@@ -1,3 +1,4 @@
+aldo->also
 ang->and
 anny->any
 bae->base
diff -pruN 1.17.1-1/codespell_lib/data/dictionary_rare.txt 2.0.0-1/codespell_lib/data/dictionary_rare.txt
--- 1.17.1-1/codespell_lib/data/dictionary_rare.txt	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/data/dictionary_rare.txt	2020-11-23 15:42:41.000000000 +0000
@@ -6,25 +6,31 @@ automatized->automated
 automatizes->automates
 backword->backward
 backwords->backwards
+bale->able
+bellow->below
 bloc->block
 blocs->blocks
 bodgy->body
 buss->bus
 busses->buses
 calculatable->calculable
+calender->calendar
+calenders->calendars
 cant->can't
 chack->check, chalk, cheque,
 chancel->cancel
 chancels->cancels
 circularly->circular
+commata->commas
 commend->comment, command,
 commends->comments, commands,
+confectionary->confectionery
 consequentially->consequently
 coo->coup
 copping->coping, copying, cropping,
-copyable->copiable
 crasher->crash
 crashers->crashes
+crate->create
 crated->created
 creche->crèche
 cristal->crystal
@@ -36,6 +42,7 @@ degrates->degrades
 dependant->dependent
 derails->details
 discontentment->discontent
+ether->either
 fallow->follow
 fallowed->followed
 fallowing->following
@@ -59,11 +66,13 @@ hart->heart, harm,
 hided->hidden, hid,
 hist->heist, his,
 hove->have, hover, love,
+impassible->impassable
 implicity->implicitly
 inactivate->deactivate
 incluse->include
 indention->indentation
 indite->indict
+infarction->infraction
 inly->only
 irregardless->regardless
 knifes->knives
@@ -74,6 +83,7 @@ loafing->loading
 loos->loose, lose,
 loosing->losing
 lousily->loosely
+lumination->lamination, illumination,
 manger->manager
 marge->merge
 mater->matter, master, mother,
@@ -91,8 +101,10 @@ preform->perform
 preformed->performed
 preforms->performs
 pres->press
+prioritary->priority
 prosses->process, processes, possess,
 purportive->supportive
+purvue->purview
 readd->re-add, read,
 readded->read
 ream->stream
@@ -102,18 +114,19 @@ revered->reversed
 rime->rhyme
 rouge->rogue
 sate->state
+sates->states
 savable->saveable
 setts->sets
 sightly->slightly
 singe->single
 singed->signed, singled,
 slippy->slippery
-specialties->specialities
 specif->specify, specific,
 steams->streams
 sting->string
 stings->strings
 straightaway->straight away
+straighted->straightened, straighten,
 suppressable->suppressible
 therefor->therefore
 therefrom->there from
@@ -122,6 +135,7 @@ tittle->title
 tittles->title
 toke->took
 tread->thread, treat,
+trough->through
 unknow->unknown
 unknows->unknowns
 untypically->atypically
@@ -136,6 +150,7 @@ whet->when, what, wet,
 whiling->while
 wight->weight, white, right, write,
 wights->weights, whites, rights, writes,
+wile->while
 wit->with
 withe->with
 wither->either, whether, weather,
diff -pruN 1.17.1-1/codespell_lib/data/dictionary.txt 2.0.0-1/codespell_lib/data/dictionary.txt
--- 1.17.1-1/codespell_lib/data/dictionary.txt	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/data/dictionary.txt	2020-11-23 15:42:41.000000000 +0000
@@ -28,11 +28,11 @@ abberation->aberration
 abberations->aberrations
 abberivates->abbreviates
 abberration->aberration
-abbort->abort
+abbort->abort, abbot,
 abborted->aborted
 abborting->aborting
-abborts->aborts
-abbout->about
+abborts->aborts, abbots,
+abbout->about, abbot,
 abbrevate->abbreviate
 abbrevation->abbreviation
 abbrevations->abbreviations
@@ -56,14 +56,18 @@ abnormaly->abnormally
 abnornally->abnormally
 abnove->above
 abnrormal->abnormal
-aboce->above
+aboce->above, abode,
+aboluste->absolute
+abolustely->absolutely
 abolute->absolute
 abondon->abandon
 abondoned->abandoned
 abondoning->abandoning
 abondons->abandons
-abord->abort
+aboout->about
+abord->abort, aboard,
 aborigene->aborigine
+aborte->aborted, abort, aborts,
 abortificant->abortifacient
 aboslute->absolute
 aboslutely->absolutely
@@ -72,8 +76,9 @@ abosultely->absolutely
 abosulute->absolute
 abosulutely->absolutely
 abotu->about
+abount->about
 abourt->abort, about,
-abouta->about a
+abouta->about a, about,
 aboutit->about it
 aboutthe->about the
 abouve->above
@@ -163,15 +168,58 @@ absoute->absolute
 absoutely->absolutely
 absoutly->absolutely
 abstact->abstract
+abstacted->abstracted
+abstacter->abstracter
+abstacting->abstracting
 abstaction->abstraction
 abstactions->abstractions
 abstactly->abstractly
+abstactness->abstractness
+abstactor->abstractor
+abstacts->abstracts
 abstanence->abstinence
+abstrac->abstract
+abstraced->abstracted
+abstracer->abstracter
+abstracing->abstracting
+abstracion->abstraction
+abstracions->abstractions
+abstracly->abstractly
+abstracness->abstractness
+abstracor->abstractor
+abstracs->abstracts
+abstrat->abstract
+abstrated->abstracted
+abstrater->abstracter
+abstrating->abstracting
 abstration->abstraction
+abstrations->abstractions
+abstratly->abstractly
+abstratness->abstractness
+abstrator->abstractor
+abstrats->abstracts
 abstrct->abstract
+abstrcted->abstracted
+abstrcter->abstracter
+abstrcting->abstracting
+abstrction->abstraction
+abstrctions->abstractions
+abstrctly->abstractly
+abstrctness->abstractness
+abstrctor->abstractor
+abstrcts->abstracts
 absulute->absolute
 absymal->abysmal
 abtract->abstract
+abtracted->abstracted
+abtracter->abstracter
+abtracting->abstracting
+abtraction->abstraction
+abtractions->abstractions
+abtractly->abstractly
+abtractness->abstractness
+abtractor->abstractor
+abtracts->abstracts
 abudance->abundance
 abudances->abundances
 abundacies->abundances
@@ -251,6 +299,9 @@ accessiblilty->accessibility
 accessile->accessible
 accessintg->accessing
 accessisble->accessible
+accessoire->accessory
+accessoires->accessories, accessorise,
+accessoirez->accessorize, accessories,
 accessort->accessor
 accesss->access
 accesssor->accessor
@@ -336,6 +387,10 @@ accoriding->according
 accoring->according, occurring,
 accoringly->accordingly
 accorndingly->accordingly
+accort->accord
+accortance->accordance
+accorted->accorded
+accorting->according
 accound->account
 accoustic->acoustic
 accoustically->acoustically
@@ -395,6 +450,8 @@ accuratelly->accurately
 accuratley->accurately
 accuratly->accurately
 accuray->accuracy, actuary,
+accure->accrue, occur, acquire,
+accured->accrued, occurred, acquired,
 accurences->occurrences
 accurracy->accuracy
 accurring->occurring
@@ -517,9 +574,10 @@ acquited->acquitted
 acqure->acquire
 acqured->acquired
 acqures->acquires
+acquries->acquires, equerries,
 acquring->acquiring
 acrage->acreage
-acrued->accured
+acrued->accrued
 acses->cases, access,
 acssumed->assumed
 actally->actually
@@ -611,6 +669,7 @@ adddress->address
 adddresses->addresses
 addds->adds
 addedd->added
+addeed->added
 addersses->addresses
 addert->assert
 adderted->asserted
@@ -676,6 +735,7 @@ adherance->adherence
 adiacent->adjacent
 adiditon->addition
 adin->admin
+adition->addition
 aditional->additional
 aditionally->additionally
 aditionaly->additionally
@@ -685,7 +745,7 @@ adivsories->advisories
 adivsoriy->advisory, advisories,
 adivsoriyes->advisories
 adivsory->advisory
-adjacentcy->adjacence
+adjacentcy->adjacency, adjacence,
 adjacentsy->adjacency
 adjactend->adjacent
 adjancent->adjacent
@@ -808,7 +868,8 @@ afficionados->aficionados
 affilate->affiliate
 affilates->affiliates
 affilliate->affiliate
-affinitied->affinitized
+affinitied->affinities
+affinitized->affinities, affinity,
 affinitze->affinitize
 affintize->affinitize
 affitnity->affinity
@@ -905,11 +966,13 @@ airbourne->airborne
 aircaft->aircraft
 aircrafts'->aircraft's
 aircrafts->aircraft
+airfow->airflow
 airial->aerial, arial,
+airlfow->airflow
 airloom->heirloom
 airporta->airports
 airrcraft->aircraft
-aisian->asian
+aisian->Asian
 aixs->axis
 aizmuth->azimuth
 ajacence->adjacence
@@ -1192,7 +1255,7 @@ aliasas->aliases
 aliase->aliases, alias,
 aliasses->aliases
 alientating->alienating
-alighed->aligned
+alighed->aligned, alighted,
 alighned->aligned
 alighnment->alignment
 aligin->align
@@ -1220,20 +1283,20 @@ alignmments->alignments
 alignmnet->alignment
 alignmnt->alignment
 alignrigh->alignright
-alikes->alike
-aline->align
+alikes->alike, likes,
+aline->align, a line, line, saline,
 alined->aligned
 alingment->alignment
 alinment->alignment
 alinments->alignments
 alising->aliasing
-aliver->alive, liver,
+aliver->alive, liver, a liver, sliver,
 allcate->allocate
 allcation->allocation
 allcator->allocator
 allcoated->allocated
 allcommnads->allcommands
-alle->all
+alle->all, alley,
 alled->called, allied,
 alledge->allege
 alledged->alleged
@@ -1264,8 +1327,21 @@ allmost->almost
 alloacate->allocate
 alloate->allocate, allotted, allot,
 alloated->allocated, allotted,
+allocae->allocate
 allocaed->allocated
+allocaes->allocates
 allocagtor->allocator
+allocaiing->allocating
+allocaing->allocating
+allocaion->allocation
+allocaions->allocations
+allocaite->allocate
+allocaites->allocates
+allocaiting->allocating
+allocaition->allocation
+allocaitions->allocations
+allocaiton->allocation
+allocaitons->allocations
 allocal->allocate
 allocarion->allocation
 allocat->allocate
@@ -1283,7 +1359,7 @@ allocte->allocate
 allocted->allocated
 alloctions->allocations
 alloctor->allocator
-alloed->allowed
+alloed->allowed, aloud,
 alloews->allows
 allone->alone, all one,
 allong->along
@@ -1291,16 +1367,18 @@ alloocates->allocates
 allopone->allophone
 allopones->allophones
 alloted->allotted
-allowd->allowed
-allowe->allowed, allow,
+alloud->aloud
+allowd->allowed, allow, allows,
+allowe->allowed, allow, allows,
 allpication->application
 allready->already, all ready,
 allredy->already, all ready,
+allreight->all right, alright,
 allright->all right, alright,
 alls->all, falls,
 allso->also
 allthough->although
-alltime->all-time
+alltime->all-time, all time,
 alltogeher->altogether, all together,
 alltogehter->altogether, all together,
 alltogether->altogether, all together,
@@ -1315,6 +1393,7 @@ allwys->always
 almostly->almost
 almsot->almost
 alo->also
+aloable->allowable, available,
 alocatable->allocatable
 alocate->allocate
 alocated->allocated
@@ -1366,13 +1445,16 @@ alreadt->already
 alreasy->already
 alreay->already
 alreayd->already
+alreday->already
 alredy->already
+alreight->all right, alright,
 alrelady->already
 alrms->alarms
 alrogithm->algorithm
 alrteady->already
 als->also
-alse->also, else,
+alse->also, else, false,
+alsmost->almost
 alsot->also
 alsready->already
 altenative->alternative
@@ -1492,6 +1574,7 @@ analised->analysed
 analiser->analyser
 analises->analysis, analyses,
 analising->analysing
+analisis->analysis
 analitic->analytic
 analitical->analytical
 analitically->analytically
@@ -1505,7 +1588,14 @@ analogeous->analogous
 analoguous->analogous
 analoguously->analogously
 analogus->analogous
+analouge->analogue
+analouges->analogues
 analsyis->analysis
+analye->analyse, analyze,
+analyed->analysed, analyzed,
+analyer->analyser, analyzer,
+analyers->analysers, analyzers,
+analyes->analyses, analyzes, analyse, analyze,
 analyis->analysis
 analysator->analyser
 analysies->analyses, analysis,
@@ -1640,7 +1730,10 @@ ansynchronous->asynchronous
 antaliasing->antialiasing
 antartic->antarctic
 antecedant->antecedent
+anteena->antenna
+anteenas->antennas
 anthing->anything
+anthings->anythings
 anthor->another
 anthromorphization->anthropomorphization
 anthropolgist->anthropologist
@@ -1679,6 +1772,7 @@ anytrhing->anything
 anytthing->anything
 anytying->anything
 anywere->anywhere
+aoache->apache
 aond->and
 aother->another, other, mother,
 aovid->avoid
@@ -1714,6 +1808,10 @@ apllies->applies
 aplly->apply
 apllying->applying
 aplyed->applied
+apointed->appointed
+apointing->appointing
+apointment->appointment
+apoints->appoints
 apolegetic->apologetic
 apolegetics->apologetics
 apon->upon, apron,
@@ -1907,6 +2005,7 @@ approxiates->approximates
 approxiation->approximation
 approxiations->approximations
 approximatly->approximately
+approximed->approximated
 approximitely->approximately
 approxmate->approximate
 approxmately->approximately
@@ -1927,6 +2026,7 @@ apreciative->appreciative
 aprehensive->apprehensive
 apreteate->appreciate
 apreteated->appreciated
+apreteating->appreciating
 aproach->approach
 aproached->approached
 aproaches->approaches
@@ -1973,7 +2073,7 @@ aquiring->acquiring
 aquisition->acquisition
 aquit->acquit
 aquitted->acquitted
-aquries->acquries
+aquries->acquires, equerries,
 arameters->parameters
 aranged->arranged
 arangement->arrangement
@@ -1981,21 +2081,91 @@ araound->around
 ararbic->arabic
 aray->array
 arays->arrays
+arbiatraily->arbitrarily
+arbiatray->arbitrary
+arbibtarily->arbitrarily
+arbibtary->arbitrary
+arbibtrarily->arbitrarily
+arbibtrary->arbitrary
+arbiitrarily->arbitrarily
+arbiitrary->arbitrary
+arbirarily->arbitrarily
+arbirary->arbitrary
+arbiratily->arbitrarily
+arbiraty->arbitrary
+arbirtarily->arbitrarily
+arbirtary->arbitrary
+arbirtrarily->arbitrarily
 arbirtrary->arbitrary
 arbitarary->arbitrary
 arbitarily->arbitrarily
 arbitary->arbitrary
+arbitiarily->arbitrarily
+arbitiary->arbitrary
+arbitiraly->arbitrarily
+arbitiray->arbitrary
+arbitor->arbiter, arbitrator,
+arbitors->arbiters, arbitrators,
+arbitrailly->arbitrarily
+arbitraily->arbitrarily
+arbitraion->arbitration
+arbitrairly->arbitrarily
+arbitrairy->arbitrary
+arbitral->arbitrary
+arbitralily->arbitrarily
+arbitrally->arbitrarily
 arbitralrily->arbitrarily
+arbitralry->arbitrary
+arbitraly->arbitrary
+arbitrarion->arbitration
 arbitrariy->arbitrarily, arbitrary,
 arbitrarly->arbitrarily, arbitrary,
 arbitraryily->arbitrarily
 arbitraryly->arbitrary
+arbitratily->arbitrarily
 arbitratiojn->arbitration
+arbitraton->arbitration
+arbitratrily->arbitrarily
+arbitratrion->arbitration
+arbitratry->arbitrary
 arbitraty->arbitrary
 arbitray->arbitrary
+arbitrer->arbiter, arbitrator,
+arbitrers->arbiters, arbitrators,
+arbitriarily->arbitrarily
+arbitriary->arbitrary
+arbitrily->arbitrarily
+arbitrion->arbitration
+arbitriraly->arbitrarily
+arbitriray->arbitrary
+arbitrition->arbitration
+arbitror->arbiter, arbitrator,
+arbitrors->arbiters, arbitrators,
+arbitrtily->arbitrarily
+arbitrty->arbitrary
+arbitry->arbitrary
+arbitryarily->arbitrarily
+arbitryary->arbitrary
+arbitual->arbitrary
+arbitually->arbitrarily
+arbitualy->arbitrary
+arbituarily->arbitrarily
+arbituary->arbitrary
+arbiturarily->arbitrarily
+arbiturary->arbitrary
+arbort->abort
+arborted->aborted
+arborting->aborting
+arborts->aborts
 arbritary->arbitrary
+arbritrarily->arbitrarily
 arbritrary->arbitrary
+arbtirarily->arbitrarily
 arbtirary->arbitrary
+arbtrarily->arbitrarily
+arbtrary->arbitrary
+arbutrarily->arbitrarily
+arbutrary->arbitrary
 archaelogical->archaeological
 archaelogists->archaeologists
 archaelogy->archaeology
@@ -2016,12 +2186,17 @@ archicture->architecture
 archiecture->architecture
 archiectures->architectures
 archimedian->archimedean
+architct->architect
+architcts->architects
+architcture->architecture
 architctures->architectures
 architecht->architect
+architechts->architects
 architechturally->architecturally
 architechture->architecture
 architechtures->architectures
 architectual->architectural
+architectur->architecture
 architecturs->architectures
 architecturse->architectures
 architecure->architecture
@@ -2029,19 +2204,29 @@ architecures->architectures
 architecutre->architecture
 architecutres->architectures
 architecuture->architecture
+architecutures->architectures
+architetcure->architecture
+architetcures->architectures
 architeture->architecture
 architetures->architectures
+architure->architecture
+architures->architectures
 archiv->archive
 archivel->archival
 archor->anchor
 archtecture->architecture
 archtectures->architectures
 archtiecture->architecture
+archtiectures->architectures
+archtitecture->architecture
+archtitectures->architectures
 archtype->archetype
 archtypes->archetypes
 archvie->archive
 archvies->archives
 archving->archiving
+arcitecture->architecture
+arcitectures->architectures
 arcticle->article
 Ardiuno->Arduino
 are'nt->aren't
@@ -2076,8 +2261,10 @@ argumengs->arguments
 argumens->arguments
 argumentents->arguments
 argumeny->argument
+argumet->argument
 argumetn->argument
 argumetns->arguments
+argumets->arguments
 argumnet->argument
 argumnets->arguments
 arhive->archive
@@ -2086,6 +2273,7 @@ aribitary->arbitrary
 aribiter->arbiter
 aribtrarily->arbitrarily
 aribtrary->arbitrary
+ariflow->airflow
 arised->arose
 arithemetic->arithmetic
 arithemtic->arithmetic
@@ -2111,6 +2299,8 @@ aronud->around
 aroud->around
 aroung->around
 arount->around
+arquitecture->architecture
+arquitectures->architectures
 arraay->array
 arragement->arrangement
 arraival->arrival
@@ -2191,10 +2381,21 @@ arugment->argument
 arugments->arguments
 aruments->arguments
 arund->around
+asai->Asia
+asain->Asian
 asbolute->absolute
 asbolutelly->absolutely
 asbolutely->absolutely
+asbtract->abstract
+asbtracted->abstracted
+asbtracter->abstracter
+asbtracting->abstracting
 asbtraction->abstraction
+asbtractions->abstractions
+asbtractly->abstractly
+asbtractness->abstractness
+asbtractor->abstractor
+asbtracts->abstracts
 asceding->ascending
 asend->ascend, as end,
 asendance->ascendance
@@ -2220,6 +2421,12 @@ asistance->assistance
 aske->ask
 askes->asks
 aslo->also
+asnwer->answer
+asnwered->answered
+asnwerer->answerer
+asnwerers->answerers
+asnwering->answering
+asnwers->answers
 asny->any
 asnychronoue->asynchronous
 asociated->associated
@@ -2238,6 +2445,7 @@ assasins->assassins
 assassintation->assassination
 asscciated->associated
 assciated->associated
+asscii->ASCII
 asscociated->associated
 asscoitaed->associated
 assebly->assembly
@@ -2376,6 +2584,7 @@ assumbe->assume
 assumbed->assumed
 assumbes->assumes
 assumbing->assuming
+assumend->assumed
 assumking->assuming
 assumme->assume
 assummed->assumed
@@ -2412,8 +2621,11 @@ assurred->assured
 assymetric->asymmetric
 assymetrical->asymmetrical
 assymetries->asymmetries
+assymetry->asymmetry
 assymmetric->asymmetric
 assymmetrical->asymmetrical
+assymmetries->asymmetries
+assymmetry->asymmetry
 asterices->asterisks
 asteriks->asterisk, asterisks,
 asteriod->asteroid
@@ -2430,15 +2642,19 @@ asuming->assuming
 asumption->assumption
 asure->assure
 aswell->as well
+asychronize->asynchronize
+asychronized->asynchronized
+asychronous->asynchronous
 asychronously->asynchronously
+asycn->async
 asycronous->asynchronous
 asymetic->asymmetric
-asymetri->assymetry
+asymetri->asymmetric, asymmetry,
 asymetric->asymmetric
 asymetrical->asymmetrical
 asymetricaly->asymmetrically
 asymmeric->asymmetric
-asymmetri->asymmetric
+asymmetri->asymmetric, asymmetry,
 asynchnous->asynchronous
 asynchonous->asynchronous
 asynchonously->asynchronously
@@ -2469,9 +2685,14 @@ atain->attain
 atempt->attempt
 atempting->attempting
 atempts->attempts
+atendance->attendance
+atended->attended
+atendee->attendee
+atends->attends
+atention->attention
 atheistical->atheistic
-athenean->athenian
-atheneans->athenians
+athenean->Athenian
+atheneans->Athenians
 ather->other
 athiesm->atheism
 athiest->atheist
@@ -2480,6 +2701,8 @@ athron->athlon
 athros->atheros
 atleast->at least
 atll->all
+atmoic->atomic
+atmoically->atomically
 atomatically->automatically
 atomical->atomic
 atomicly->atomically
@@ -2496,6 +2719,7 @@ atrribute->attribute
 atrributes->attributes
 atrtribute->attribute
 atrtributes->attributes
+attaced->attached
 attachd->attached
 attachement->attachment
 attachements->attachments
@@ -2562,7 +2786,10 @@ attrbiute->attribute
 attribbute->attribute
 attribiute->attribute
 attribiutes->attributes
-attribtes->attribute
+attribte->attribute
+attribted->attributed
+attribtes->attributes, attribute,
+attribting->attributing
 attribtue->attribute
 attribtutes->attributes
 attribude->attribute
@@ -2621,7 +2848,7 @@ auospacing->autospacing
 auot->auto
 auotmatic->automatic
 auromated->automated
-aussian->gaussian, russian,
+aussian->Gaussian, Russian, Austrian,
 austrailia->Australia
 austrailian->Australian
 Australien->Australian
@@ -2814,6 +3041,9 @@ auto-detetes->auto-deletes, auto-detects
 auto-deteting->auto-detecting, auto-deleting,
 auto-detetion->auto-detection, auto-deletion,
 auto-detets->auto-detects, auto-deletes,
+auto-genrated->auto-generated
+auto-genratet->auto-generated
+auto-genration->auto-generation
 auto-negatiotiation->auto-negotiation
 auto-negatiotiations->auto-negotiations
 auto-negoatiation->auto-negotiation
@@ -2873,6 +3103,9 @@ autoeselect->autoselect
 autofilt->autofilter
 autofomat->autoformat
 autoformating->autoformatting
+autogenrated->autogenerated
+autogenratet->autogenerated
+autogenration->autogeneration
 autogroping->autogrouping
 autohorized->authorized
 autoincrememnt->autoincrement
@@ -2986,6 +3219,8 @@ avaiblable->available
 avaible->available
 avaiiability->availability
 avaiiable->available
+avaiibility->availability
+avaiible->available
 avaiilable->available
 availaable->available
 availabable->available
@@ -3036,10 +3271,15 @@ avalance->avalanche
 avaliable->available
 avalibale->available
 avalible->available
+avaloable->available
 avaluate->evaluate
 avaluated->evaluated
 avaluates->evaluates
 avaluating->evaluating
+avance->advance
+avanced->advanced
+avances->advances
+avancing->advancing
 avaoid->avoid
 avaoidable->avoidable
 avaoided->avoided
@@ -3084,11 +3324,14 @@ avriant->variant
 avriants->variants
 avtive->active
 awared->awarded
-aways->always
+aways->always, away,
 aweful->awful
 awefully->awfully
 awnser->answer
+awnsered->answered
+awnsers->answers
 awoid->avoid
+awsome->awesome
 awya->away
 axises->axes
 axix->axis
@@ -3104,17 +3347,34 @@ bacground->background
 bacic->basic
 backards->backwards
 backbround->background
+backbrounds->backgrounds
+backedn->backend
+backedns->backends
+backened->backend, blackened,
+backeneds->backends, blackens,
 backgorund->background
+backgorunds->backgrounds
 backgound->background
+backgounds->backgrounds
 backgournd->background
+backgournds->backgrounds
 backgrond->background
 backgronds->backgrounds
 backgroud->background
+backgrouds->backgrounds
 backgroung->background
+backgroungs->backgrounds
 backgrount->background
+backgrounts->backgrounds
 backgrund->background
+backgrunds->backgrounds
 backlght->backlight
+backlghting->backlighting
+backlghts->backlights
+backned->backend
+backneds->backends
 backound->background
+backounds->backgrounds
 backpsace->backspace
 backrefence->backreference
 backround->background
@@ -3141,6 +3401,8 @@ baisc->basic
 baised->raised
 bakc->back
 bakcrefs->backrefs
+bakend->backend, baked,
+bakends->backends
 bakup->backup
 bakups->backups
 bakward->backward
@@ -3178,9 +3440,28 @@ basci->basic
 bascially->basically
 bascktrack->backtrack
 basf->base
+basicallly->basically
 basicaly->basically
+basiclly->basically
 basicly->basically
+bassic->basic
+bassically->basically
+bastract->abstract
+bastracted->abstracted
+bastracter->abstracter
+bastracting->abstracting
+bastraction->abstraction
+bastractions->abstractions
+bastractly->abstractly
+bastractness->abstractness
+bastractor->abstractor
+bastracts->abstracts
+bateries->batteries
 batery->battery
+battaries->batteries
+battary->battery
+bboolean->boolean
+bbooleans->booleans
 bcak->back
 bcause->because
 beacaon->beacon
@@ -3195,6 +3476,7 @@ beauracracy->bureaucracy
 beaurocracy->bureaucracy
 beaurocratic->bureaucratic
 beause->because
+beauti->beauty
 beautiy->beauty
 beautyfied->beautified
 beautyfull->beautiful
@@ -3266,6 +3548,8 @@ begining->beginning
 beginn->begin
 beginnig->beginning
 beginnin->beginning
+beginnning->beginning
+beginnnings->beginnings
 behabviour->behaviour
 behaivior->behavior
 behavious->behaviour, behaviours,
@@ -3386,8 +3670,13 @@ betwene->between
 betwern->between
 beucase->because
 beuracracy->bureaucracy
+beutification->beautification
+beutiful->beautiful
+beutifully->beautifully
 bever->never
 bevore->before
+bevorehand->beforehand
+bevorhand->beforehand
 beweeen->between
 beween->between
 bewteen->between
@@ -3412,17 +3701,32 @@ bilateraly->bilaterally
 billingualism->bilingualism
 billon->billion
 bimask->bitmask
+bimillenia->bimillennia
+bimillenial->bimillennial
+bimillenium->bimillennium
 bimontly->bimonthly
 binairy->binary
 binanary->binary
+binar->binary
 binay->binary
 bindins->bindings
 binidng->binding
 binominal->binomial
 bion->bio
+birght->bright
+birghten->brighten
+birghter->brighter
+birghtest->brightest
+birghtness->brightness
 biridectionality->bidirectionality
 bisct->bisect
+bisines->business
+bisiness->business
+bisnes->business
+bisness->business
 bistream->bitstream
+bisunes->business
+bisuness->business
 bitamps->bitmaps
 bitap->bitmap
 bitfileld->bitfield
@@ -3463,12 +3767,20 @@ bloaded->bloated
 blocack->blockack
 bloccks->blocks
 blocekd->blocked
+blockhain->blockchain
+blockhains->blockchains
 blockin->blocking
 bloddy->bloody
 blodk->block
 blohted->bloated
 blokcer->blocker
+blokchain->blockchain
+blokchains->blockchains
 bloking->blocking
+blong->belong
+blonged->belonged
+blonging->belonging
+blongs->belongs
 bloted->bloated
 bluestooth->bluetooth
 bluetooh->bluetooth
@@ -3502,18 +3814,29 @@ bookkepp->bookkeep
 bookmakr->bookmark
 bookmar->bookmark
 boold->bold, bool,
+booleam->boolean
 booleamn->boolean
+booleamns->booleans
+booleams->booleans
 booleanss->booleans
 booleen->boolean
+booleens->booleans
 boolen->boolean
+boolens->booleans
 booltloader->bootloader
+booltloaders->bootloaders
 boomark->bookmark
 boomarks->bookmarks
 boook->book
 booolean->boolean
+boooleans->booleans
 boostrap->bootstrap
+boostrapped->bootstrapped
 boostrapping->bootstrapping
+boostraps->bootstraps
 booteek->boutique
+bootlaoder->bootloader
+bootlaoders->bootloaders
 bootoloader->bootloader
 bootom->bottom
 bootraping->bootstrapping
@@ -3552,9 +3875,31 @@ bottome->bottom
 botton->bottom, button,
 bottons->bottoms, buttons,
 botttom->bottom
+bouce->bounce
+bouces->bounces
 boudaries->boundaries
 boudary->boundary
 bouding->bounding
+boudnaries->boundaries
+boudnary->boundary
+bouds->bounds
+bouind->bound
+bouinded->bounded
+bouinding->bounding
+bouinds->bounds
+boun->bound
+bounaaries->boundaries
+bounaary->boundary
+bounad->bound
+bounadaries->boundaries
+bounadary->boundary
+bounaded->bounded
+bounading->bounding
+bounadries->boundaries
+bounadry->boundary
+bounads->bounds
+bounardies->boundaries
+bounardy->boundary
 bounaries->boundaries
 bounary->boundary
 bounbdaries->boundaries
@@ -3570,10 +3915,40 @@ boundrary->boundary
 boundries->boundaries
 boundry->boundary
 bounduaries->boundaries
+bouned->bounded
+boungaries->boundaries
+boungary->boundary
+boungin->bounding
+boungind->bounding
+bounhdaries->boundaries
+bounhdary->boundary
+bounidng->bounding
 bouning->bounding
+bounnd->bound
+bounnded->bounded
+bounnding->bounding
+bounnds->bounds
+bounradies->boundaries
+bounrady->boundary
+bounraies->boundaries
+bounraries->boundaries
+bounrary->boundary
+bounray->boundary
+bouns->bounds
+bounsaries->boundaries
+bounsary->boundary
+bounsd->bounds
 bount->bound
+bountries->boundaries
+bountry->boundary
+bounudaries->boundaries
+bounudary->boundary
 bounus->bonus
 bouqet->bouquet
+bouund->bound
+bouunded->bounded
+bouunding->bounding
+bouunds->bounds
 bouy->buoy
 bouyancy->buoyancy
 bouyant->buoyant
@@ -3589,6 +3964,7 @@ bradcast->broadcast
 brakpoint->breakpoint
 brakpoints->breakpoints
 brance->branch, brace, branches,
+branchces->branches
 branchs->branches
 branck->branch
 branckes->branches
@@ -3598,7 +3974,7 @@ brane->brain
 braodcasted->broadcasted
 Brasillian->Brazilian
 brazeer->brassiere
-brazillian->brazilian
+brazillian->Brazilian
 bre->be, brie,
 breakes->breaks
 breakthough->breakthrough
@@ -3611,6 +3987,8 @@ breefly->briefly
 brefore->before
 breif->brief
 breifly->briefly
+brekpoint->breakpoint
+brekpoints->breakpoints
 bresh->brush, fresh,
 breshed->brushed
 breshes->brushes
@@ -3658,14 +4036,38 @@ brokend->broken
 brokened->broken
 brokeness->brokenness
 bronken->broken
+brosable->browsable
+brose->browse, rose,
+brosed->browsed, rosed,
 broser->browser
+brosers->browsers
+brosing->browsing
+broswable->browsable
+broswe->browse
+broswed->browsed
+broswer->browser
+broswers->browsers
+broswing->browsing
 brouter->router
 brower->browser
 browers->browsers
 browing->browsing
 browseable->browsable
+browswable->browsable
+browswe->browse
+browswed->browsed
 browswer->browser
+browswers->browsers
+browswing->browsing
 brutaly->brutally
+brwosable->browsable
+brwose->browse
+brwosed->browsed
+brwoser->browser
+brwosers->browsers
+brwosing->browsing
+btye->byte
+btyes->bytes
 buad->baud
 Buddah->Buddha
 Buddist->Buddhist
@@ -3782,6 +4184,8 @@ caclucations->calculations
 caclucator->calculator
 caclulated->calculated
 caclulating->calculating
+caclulation->calculation
+caclulations->calculations
 caculate->calculate
 caculated->calculated
 caculater->calculator
@@ -3864,10 +4268,13 @@ calculatble->calculatable, calculable,
 calculater->calculator
 calculatted->calculated
 calculatter->calculator
+calculattion->calculation
+calculattions->calculations
 calculaution->calculation
 calculautions->calculations
 calculcate->calculate
 calculcation->calculation
+calculed->calculated
 calculs->calculus
 calcultate->calculate
 calcultated->calculated
@@ -3879,8 +4286,6 @@ calculuations->calculations
 calcurate->calculate
 calcutated->calculated
 caleed->called
-calender->calendar
-calenders->calendars
 caler->caller
 calescing->coalescing
 caliased->aliased
@@ -4036,7 +4441,7 @@ caracterized->characterized
 caracters->characters
 carbus->cardbus
 carcas->carcass, Caracas,
-carefull->careful
+carefull->careful, carefully,
 carefuly->carefully
 careing->caring
 carfull->careful
@@ -4110,6 +4515,10 @@ catastrphic->catastrophic
 catched->caught
 catchi->catch
 catchs->catches
+categogical->categorical
+categogically->categorically
+categogies->categories
+categogy->category
 categorie->category, categories,
 cateogrical->categorical
 cateogrically->categorically
@@ -4214,6 +4623,12 @@ centuty->century
 cerate->create
 ceratin->certain, keratin,
 cereates->creates
+cerification->certification, verification,
+cerifications->certifications, verifications,
+cerified->certified, verified,
+cerifies->certifies, verifies,
+cerify->certify, verify,
+cerifying->certifying, verifying,
 cerimonial->ceremonial
 cerimonies->ceremonies
 cerimonious->ceremonious
@@ -4247,6 +4662,12 @@ certifciate->certificate
 certifciated->certificated
 certifciates->certificates
 certifciation->certification
+certifiate->certificate
+certifiated->certificated
+certifiates->certificates
+certifiating->certificating
+certifiation->certification
+certifiations->certifications
 certificat->certificate
 certificatd->certificated
 certificatin->certificating, certification,
@@ -4283,6 +4704,9 @@ chage->change, charge,
 chaged->changed, charged,
 chages->changes, charges,
 chaging->changing, charging,
+chagne->change
+chagned->changed
+chagnes->changes
 chahged->changed
 chaied->chained
 chaing->chain
@@ -4292,6 +4716,8 @@ challange->challenge
 challanged->challenged
 challanges->challenges
 challege->challenge
+chambre->chamber
+chambres->chambers
 Champange->Champagne
 chanceled->canceled
 chanceling->canceling
@@ -4354,9 +4780,16 @@ characterisitic->characteristic
 characterisitics->characteristics
 characteristicly->characteristically
 charactersistic->characteristic
+charactersistically->characteristically
+charactersistics->characteristics
 charactersm->characters
+characterss->characters
 characterstic->characteristic
+characterstically->characteristically
 characterstics->characteristics
+charactertistic->characteristic
+charactertistically->characteristically
+charactertistics->characteristics
 charactes->characters
 charactet->character
 characteter->character
@@ -4365,12 +4798,14 @@ characteteristics->characteristics
 characteters->characters
 charactetistic->characteristic
 charactetistics->characteristics
-charactetr->characters
-charactetrs->characterss
+charactetr->character
+charactetrs->characters
 charactets->characters
 characther->character
 charactor->character
 charactors->characters
+charactristic->characteristic
+charactristically->characteristically
 charactristics->characteristics
 charactrs->characters
 characts->characters
@@ -4475,11 +4910,11 @@ childen->children
 childern->children
 childres->children
 childs->children, child's,
-chiled->child
+chiled->child, chilled,
 chiledren->children
 chilren->children
-chineese->chinese
-chiop->chip
+chineese->Chinese
+chiop->chip, chop,
 chipet->chipset
 chipslect->chipselect
 chipstes->chipsets
@@ -4506,7 +4941,7 @@ choser->chooser
 chosing->choosing
 chossen->chosen
 chould->should, could,
-chouse->chose
+chouse->choose, chose, choux,
 chracter->character
 chracters->characters
 chractor->character
@@ -4535,8 +4970,10 @@ cicruit->circuit
 cicruits->circuits
 cicular->circular
 ciculars->circulars
-cilincer->cylinder
-cilincers->cylinders
+cilent->client, silent,
+cilents->clients, silents, silence,
+cilincer->cylinder, silencer,
+cilincers->cylinders, silencers,
 cilinder->cylinder
 cilinders->cylinders
 cilyndre->cylinder
@@ -4629,6 +5066,9 @@ clasifying->classifying
 classe->class, classes,
 classess->classes
 classesss->classes
+classifed->classified
+classifer->classifier
+classifers->classifiers
 classs->class
 classses->classes
 clatified->clarified
@@ -4636,7 +5076,7 @@ claus->clause
 clcoksource->clocksource
 clcosed->closed
 clea->clean
-cleaer->clear, clearer,
+cleaer->clear, clearer, cleaner,
 cleaered->cleared
 cleaing->cleaning
 cleancacne->cleancache
@@ -4648,7 +5088,7 @@ cleanp->cleanup, clean up,
 cleanpu->cleanup
 cleanpus->cleanups
 cleantup->cleanup
-cleare->cleared
+cleare->cleared, clear,
 cleareance->clearance
 clearified->clarified
 clearifies->clarifies
@@ -4676,6 +5116,9 @@ cliente->client, clientele,
 clientelle->clientele
 clik->click
 cliks->clicks
+climer->climber
+climers->climbers
+climing->climbing
 clincial->clinical
 clinets->clients
 clinicaly->clinically
@@ -4701,13 +5144,13 @@ cloes->close
 cloesd->closed
 cloesed->closed
 cloesing->closing
-cloneable->clonable
 clonez->clones, cloner,
 clonning->cloning
 clory->glory
 clos->close
 closeing->closing
 closests->closest, closets,
+closig->closing
 clossed->closed
 clossing->closing
 cloude->cloud
@@ -4829,10 +5272,15 @@ coducter->conductor
 coducting->conducting
 coductor->conductor
 coducts->conducts
+coeffcient->coefficient
 coeffcients->coefficients
+coefficeint->coefficient
 coefficeints->coefficients
 coefficent->coefficient
 coefficents->coefficients
+coeffiecient->coefficient
+coeffiecients->coefficients
+coeffient->coefficient
 coeffients->coefficients
 coeficent->coefficient
 coeficents->coefficients
@@ -4879,6 +5327,10 @@ cofrimed->confirmed
 cofriming->confirming
 cofrims->confirms
 cognizent->cognizant
+coherance->coherence
+coherancy->coherency
+coherant->coherent
+coherantly->coherently
 coice->choice
 coincedentally->coincidentally
 coinitailize->coinitialize
@@ -4942,7 +5394,7 @@ coloers->colors
 colomns->columns
 colon-seperated->colon-separated
 colonizators->colonizers
-colorfull->colorful
+colorfull->colorful, colorfully,
 coloringh->coloring
 colorizoer->colorizer
 colorpsace->colorspace
@@ -4952,6 +5404,7 @@ coloum->column
 coloumn->column
 coloumns->columns
 coloums->columns
+colourfull->colourful, colourfully,
 colourpsace->colourspace
 colourpsaces->colourspaces
 colsed->closed
@@ -4966,6 +5419,8 @@ colunns->columns
 comammand->command
 comamnd->command
 comamnd-line->command-line
+comamnded->commanded
+comamnding->commanding
 comamndline->commandline
 comamnds->commands
 comand->command
@@ -5049,6 +5504,13 @@ comittees->committees
 comitter->committer
 comitting->committing
 comittish->committish
+comlain->complain
+comlained->complained
+comlainer->complainer
+comlaining->complaining
+comlains->complains
+comlaint->complaint
+comlaints->complaints
 comlete->complete
 comleted->completed
 comletely->completely
@@ -5072,6 +5534,7 @@ commansd->commands
 commant->command, comment,
 commanted->commanded, commented,
 commants->commands, comments,
+commatas->commas, commata,
 commect->connect
 commected->connected
 commecting->connecting
@@ -5108,11 +5571,14 @@ commited->committed
 commitee->committee
 commiter->committer
 commiters->committers
+commiti->committee, committing, commit,
 commitin->committing
 commiting->committing
 commitish->committish
 committ->commit
 committe->committee
+committi->committee
+committis->committees
 committment->commitment
 committments->commitments
 committy->committee
@@ -5248,6 +5714,11 @@ compagny->company
 compaibility->compatibility
 compain->complain
 compair->compare
+compaire->compare
+compaired->compared
+compairing->comparing
+compairison->comparison
+compairisons->comparisons
 compairs->compares
 compansate->compensate
 compansated->compensated
@@ -5344,6 +5815,7 @@ compatbility->compatibility
 compatiability->compatibility
 compatiable->compatible
 compatiablity->compatibility
+compatibel->compatible
 compatibile->compatible
 compatibiliy->compatibility
 compatibilty->compatibility
@@ -5465,6 +5937,9 @@ componnents->components
 componsites->composites
 compontent->component
 compontents->components
+composablity->composability
+composibility->composability
+composiblity->composability
 composit->composite
 compount->compound
 comppatible->compatible
@@ -5486,6 +5961,7 @@ compromize->compromise
 compsable->composable
 compsite->composite
 comptabile->compatible
+comptability->compatibility, computability,
 comptible->compatible
 comptue->compute
 compuatation->computation
@@ -5708,6 +6184,9 @@ conersion->conversion
 conersions->conversions
 conert->convert
 conerted->converted
+conerter->converter
+conerters->converters
+conerting->converting
 conervative->conservative
 conesencus->consensus
 conet->connect
@@ -5928,6 +6407,7 @@ connction->connection
 conncurrent->concurrent
 connecetd->connected
 connecion->connection
+connecions->connections
 conneciton->connection
 connecitons->connections
 connecor->connector
@@ -5939,7 +6419,9 @@ connectet->connected
 connectibity->connectivity
 connectino->connection
 connectinos->connections
+connectiom->connection
 connectioms->connections
+connectiona->connection
 connectionas->connections
 connecto->connect
 connecton->connection, connector,
@@ -6056,6 +6538,10 @@ consistancy->consistency
 consistant->consistent
 consistantly->consistently
 consisten->consistent
+consistend->consistent
+consistendly->consistently
+consistendt->consistent
+consistendtly->consistently
 consistenly->consistently
 consisteny->consistency, consistent,
 consistuents->constituents
@@ -6070,9 +6556,20 @@ consitional->conditional
 consits->consists
 consituencies->constituencies
 consituency->constituency
+consituent->constituent
+consituents->constituents
+consitute->constitute
 consituted->constituted
+consitutes->constitutes
+consituting->constituting
 consitution->constitution
 consitutional->constitutional
+consitutuent->constituent
+consitutuents->constituents
+consitutute->constitute
+consitututed->constituted
+consitututes->constitutes
+consitututing->constituting
 consol->console
 consolodate->consolidate
 consolodated->consolidated
@@ -6101,6 +6598,8 @@ constanly->constantly
 constantsm->constants
 constarnation->consternation
 constatn->constant
+constatnt->constant
+constatnts->constants
 constcurts->constructs
 constext->context
 consting->consisting
@@ -6146,7 +6645,7 @@ constrcuts->constructs
 constriants->constraints
 constrollers->controllers
 construc->construct
-construced->construtced
+construced->constructed, construed,
 construces->constructs
 construcing->constructing
 construcion->construction
@@ -6170,6 +6669,7 @@ construktor->constructor
 construnctor->constructor
 construrtors->constructors
 construt->construct
+construtced->constructed
 construter->constructor
 construters->constructors
 constrution->construction
@@ -6345,6 +6845,8 @@ contollers->controllers
 contolls->controls
 contols->controls
 contongency->contingency
+contorl->control
+contorled->controlled
 contorls->controls
 contoroller->controller
 contraciction->contradiction
@@ -6460,6 +6962,7 @@ convertet->converted
 convertion->conversion
 convertions->conversions
 convertor->converter
+convertors->converters
 convery->convert
 convesion->conversion
 convesions->conversions
@@ -6470,8 +6973,7 @@ conveters->converters
 conveting->converting
 convetion->convention
 convets->converts
-convexe->convex
-convexes->convex
+convexe->convex, convexes,
 conveyer->conveyor
 conviced->convinced
 convience->convince, convenience,
@@ -6562,6 +7064,8 @@ coordonated->coordinated
 coordonates->coordinates
 coorespond->correspond
 cooresponded->corresponded
+coorespondend->correspondent
+coorespondent->correspondent
 cooresponding->corresponding
 cooresponds->corresponds
 cooridate->coordinate
@@ -6606,7 +7110,10 @@ copstruction->construction
 copuright->copyright
 copurighted->copyrighted
 copurights->copyrights
+copute->compute
+coputed->computed
 coputer->computer
+coputes->computes
 copver->cover
 copyed->copied
 copyeight->copyright
@@ -6647,6 +7154,7 @@ corelated->correlated
 corelates->correlates
 corellation->correlation
 corener->corner, coroner,
+coreolis->Coriolis
 corerct->correct
 corerctly->correctly
 corespond->correspond
@@ -6663,6 +7171,12 @@ corordinates->coordinates
 corordination->coordination
 corosbonding->corresponding
 corosion->corrosion
+corospond->correspond
+corospondance->correspondence
+corosponded->corresponded
+corospondence->correspondence
+corosponding->corresponding
+corosponds->corresponds
 corousel->carousel
 corparate->corporate
 corperations->corporations
@@ -6693,6 +7207,10 @@ correllation->correlation
 correllations->correlations
 correnspond->correspond
 corrensponded->corresponded
+correnspondence->correspondence
+correnspondences->correspondences
+correnspondent->correspondent
+correnspondents->correspondents
 corrensponding->corresponding
 corrensponds->corresponds
 corrent->correct, current,
@@ -6712,10 +7230,19 @@ correspnding->corresponding
 correspodence->correspondence
 correspoding->corresponding
 correspoinding->corresponding
+correspomd->correspond
+correspomded->corresponded
+correspomdence->correspondence
+correspomdences->correspondences
+correspomdent->correspondent
+correspomdents->correspondents
+correspomding->corresponding
+correspomds->corresponds
 correspondance->correspondence
 correspondances->correspondences
 correspondant->correspondent
 correspondants->correspondents
+correspondend->correspondent
 correspondes->corresponds
 correspondg->corresponding
 correspondig->corresponding
@@ -6723,6 +7250,14 @@ corresponging->corresponding
 corresponing->corresponding
 corresponsding->corresponding
 corresponsing->corresponding
+correspont->correspond
+correspontence->correspondence
+correspontences->correspondences
+correspontend->correspondent
+correspontent->correspondent
+correspontents->correspondents
+corresponting->corresponding
+corresponts->corresponds
 correspoond->correspond
 corressponding->corresponding
 corret->correct
@@ -6801,6 +7336,9 @@ cotnainer->container
 cotnainers->containers
 cotnaining->containing
 cotnains->contains
+cotranser->cotransfer
+cotrasferred->cotransferred
+cotrasfers->cotransfers
 cotrol->control
 cotrolled->controlled
 cotrolling->controlling
@@ -6831,9 +7369,10 @@ cound->could, count,
 counding->counting
 coundition->condition
 counds->counts
+counld->could
 counpound->compound
 counpounds->compounds
-counries->countries
+counries->countries, counties,
 countain->contain
 countainer->container
 countains->contains
@@ -6841,14 +7380,16 @@ counterfit->counterfeit
 counterintuive->counter intuitive
 counterpar->counterpart
 counterpoart->counterpart
-countinueq->continueq
-countires->countries
+countie's->counties, counties', county's,
+countinue->continue
+countinueq->continueq, continue,
+countires->countries, counties,
 countour->contour, counter,
 countours->contours, counters,
-countr->counter, contour, country,
+countr->counter, contour, country, county,
 countrie's->countries, countries', country's,
 countrs->counters, contours, countries,
-cource->course, source,
+cource->course, coerce, source,
 coururier->courier, couturier,
 couse->course, cause,
 couses->courses, causes,
@@ -6866,6 +7407,7 @@ covarege->coverage
 covention->convention
 covere->cover
 coveres->covers
+coverge->coverage
 coverred->covered
 coverted->converted, covered, coveted,
 coverting->converting
@@ -6915,6 +7457,8 @@ creatre->create
 creatred->created
 creats->creates
 credate->created
+credetial->credential
+credetials->credentials
 credintial->credential
 credintials->credentials
 credis->credits
@@ -6982,7 +7526,13 @@ crowkay->croquet
 crowm->crown
 crrespond->correspond
 crsytal->crystal
+crsytalline->crystalline
+crsytallisation->crystallisation
+crsytallise->crystallise
+crsytallization->crystallization
+crsytallize->crystallize
 crsytallographic->crystallographic
+crsytals->crystals
 crtical->critical
 crticised->criticised
 crucialy->crucially
@@ -7015,6 +7565,7 @@ cuestioned->questioned
 cuestions->questions
 cuileoga->cuileog
 culiminating->culminating
+cumlative->cumulative
 cummand->command
 cummulative->cumulative
 cummunicate->communicate
@@ -7034,6 +7585,7 @@ curent->current
 curentfilter->currentfilter
 curently->currently
 curernt->current
+curerntly->currently
 curiousities->curiosities
 curiousity's->curiosity's
 curiousity->curiosity
@@ -7044,6 +7596,7 @@ currectly->correctly, currently,
 currects->corrects, currents,
 curremt->current
 curremts->currents
+curren->current
 currenlty->currently
 currenly->currently
 currennt->current
@@ -7079,7 +7632,7 @@ cursot->cursor
 cursro->cursor
 curvelinear->curvilinear
 customable->customizable
-custome->custom, costume,
+custome->custom, customs, costume, customer,
 customicable->customisable, customizable,
 customie->customize
 customied->customized
@@ -7087,25 +7640,41 @@ customsied->customised
 customzied->customized
 custumised->customised
 custumized->customized
+cuted->cut, cute, cuter,
 cutom->custom
+cutted->cut
 cuurently->currently
 cuve->curve, cube, cave,
 cuves->curves, cubes, caves,
+cuvre->curve, cover,
+cuvres->curves, covers,
 cvignore->cvsignore
 cxan->cyan
 cycic->cyclic
 cyclinder->cylinder
 cyclinders->cylinders
+cycular->circular
 cyle->cycle
 cylic->cyclic
+cylindre->cylinder
 cylnder->cylinder
 cylnders->cylinders
 cylynders->cylinders
 cymk->CMYK
+cyprt->crypt
+cyprtic->cryptic
+cyprto->crypto
 Cyrllic->Cyrillic
 cyrpto->crypto
 cyrrent->current
 cyrrilic->Cyrillic
+cyrstal->crystal
+cyrstalline->crystalline
+cyrstallisation->crystallisation
+cyrstallise->crystallise
+cyrstallization->crystallization
+cyrstallize->crystallize
+cyrstals->crystals
 cyrto->crypto
 cywgin->Cygwin
 daa->data
@@ -7115,6 +7684,7 @@ dacquiri->daiquiri
 dadlock->deadlock
 daed->dead
 dael->deal, dial, dahl,
+daemonified->daemonised, daemonized,
 dafault->default
 dafaults->defaults
 dafaut->default
@@ -7123,7 +7693,7 @@ dafualted->defaulted
 dafualts->defaults
 daita->data
 dake->take
-dalmation->dalmatian
+dalmation->Dalmatian
 dalta->delta
 damenor->demeanor
 dameon->daemon, demon, Damien,
@@ -7142,10 +7712,17 @@ dashs->dashes
 dasy->daisy
 data-strcuture->data-structure
 data-strcutures->data-structures
+databaase->database
+databaases->databases
 databae->database
 databas->database
+databsae->database
+databsaes->databases
 databse->database
+databses->databases
 datadsir->datadir
+dataet->dataset
+dataets->datasets
 datas->data
 datastrcuture->datastructure
 datastrcutures->datastructures
@@ -7176,10 +7753,14 @@ datatyoe->datatype
 datatyoes->datatypes
 datatytpe->datatype
 datatytpes->datatypes
+datbase->database
+datbases->databases
 datea->date, data,
 datecreatedd->datecreated
 datection->detection
 datee->date
+datset->dataset
+datsets->datasets
 daty->data, date,
 daugher->daughter
 DCHP->DHCP
@@ -7246,7 +7827,7 @@ deamiguate->disambiguate
 deamiguates->disambiguates
 deamiguation->disambiguation
 deamon->daemon
-deamonified->daemonified
+deamonified->daemonised, daemonized,
 deamonisation->daemonisation
 deamonise->daemonise
 deamonised->daemonised
@@ -7298,6 +7879,7 @@ decalratiosn->declarations
 decapsulting->decapsulating
 decathalon->decathlon
 deccelerate->decelerate
+Decemer->December
 decend->descend
 decendant->descendant
 decendants->descendants
@@ -7369,6 +7951,13 @@ declatory->declaratory
 decleration->declaration
 declerations->declarations
 declration->declaration
+decocde->decode
+decocded->decoded
+decocder->decoder
+decocders->decoders
+decocdes->decodes
+decocding->decoding
+decocdings->decodings
 decodded->decoded
 decodding->decoding
 decodeing->decoding
@@ -7396,7 +7985,13 @@ decompressd->decompressed
 decompresser->decompressor
 decompse->decompose
 decond->decode
+deconde->decode
+deconded->decoded
+deconder->decoder
+deconders->decoders
+decondes->decodes
 deconding->decoding
+decondings->decodings
 deconstract->deconstruct
 deconstracted->deconstructed
 deconstrcutor->deconstructor
@@ -7404,7 +7999,21 @@ decopose->decompose
 decoposes->decomposes
 decoraded->decorated
 decoratrion->decoration
+decorde->decode
+decorded->decoded
+decorder->decoder
+decorders->decoders
+decordes->decodes
+decording->decoding
+decordings->decodings
 decorrellation->decorrelation
+decose->decode
+decosed->decoded
+decoser->decoder
+decosers->decoders
+decoses->decodes
+decosing->decoding
+decosings->decodings
 decraesing->decreasing, deceasing,
 decrasing->decreasing, deceasing,
 decration->decoration
@@ -7458,7 +8067,6 @@ dedidated->dedicated
 dedly->deadly
 deductable->deductible
 deductables->deductibles
-dedup->dedupe
 deduplacate->deduplicate
 deduplacated->deduplicated
 deduplacates->deduplicates
@@ -7627,9 +8235,11 @@ degenarate->degenerate
 degenarated->degenerated
 degenarating->degenerating
 degenaration->degeneration
+degenracy->degeneracy
 degenrate->degenerate
 degenrated->degenerated
 degenrates->degenerates
+degenratet->degenerated
 degenrating->degenerating
 degenration->degeneration
 degerate->degenerate
@@ -7638,6 +8248,7 @@ degnerate->degenerate
 degnerated->degenerated
 degnerates->degenerates
 degrads->degrades
+degration->degradation
 degreee->degree
 degreeee->degree
 degreeees->degrees
@@ -7665,6 +8276,8 @@ deivices->devices
 deklaration->declaration
 dekstop->desktop
 dekstops->desktops
+dektop->desktop
+dektops->desktops
 delagate->delegate
 delagates->delegates
 delaloc->delalloc
@@ -7684,7 +8297,8 @@ delcare->declare
 delcared->declared
 delcares->declares
 delclaration->declaration
-delection->detection, deletion,
+delection->detection, deletion, selection,
+delections->detections, deletions, selections,
 delele->delete
 delelte->delete
 delemeter->delimiter
@@ -7715,6 +8329,9 @@ delibrate->deliberate
 delibrately->deliberately
 delievering->delivering
 delievery->delivery
+delievred->delivered
+delievries->deliveries
+delievry->delivery
 delimeted->delimited
 delimeter->delimiter
 delimeters->delimiters
@@ -7780,7 +8397,14 @@ demudulator->demodulator
 denegrating->denigrating
 densitity->density
 densly->densely
+denstiy->density
+deocde->decode
+deocded->decoded
 deocder->decoder
+deocders->decoders
+deocdes->decodes
+deocding->decoding
+deocdings->decodings
 deoes->does
 deoesn't->doesn't
 deompression->decompression
@@ -7791,13 +8415,41 @@ depandent->dependent
 deparment->department
 deparmental->departmental
 deparments->departments
+depden->depend
+depdence->dependence
+depdencente->dependence
+depdencentes->dependences
+depdences->dependences
 depdencies->dependencies
 depdency->dependency
 depdend->depend
+depdendancies->dependencies
+depdendancy->dependency
+depdendant->dependent
+depdendants->dependents
+depdended->depended
 depdendence->dependence
+depdendences->dependences
 depdendencies->dependencies
 depdendency->dependency
+depdendent->dependent
+depdendents->dependents
+depdendet->dependent
+depdendets->dependents
 depdending->depending
+depdends->depends
+depdenence->dependence
+depdenences->dependences
+depdenencies->dependencies
+depdenency->dependency
+depdenent->dependent
+depdenents->dependents
+depdening->depending
+depdenncies->dependencies
+depdenncy->dependency
+depdens->depends
+depdent->dependent
+depdents->dependents
 depecated->deprecated
 depedencies->dependencies
 depedency->dependency
@@ -7836,6 +8488,7 @@ dependicy->dependency
 dependig->depending
 dependncies->dependencies
 dependncy->dependency
+depened->depend
 depenedecies->dependencies
 depenedecy->dependency
 depenedent->dependent
@@ -7843,11 +8496,14 @@ depenencies->dependencies
 depenencis->dependencies
 depenency->dependency
 depenencys->dependencies
+depenend->depend
 depenendecies->dependencies
 depenendecy->dependency
 depenendence->dependence
 depenendencies->dependencies
 depenendency->dependency
+depenendent->dependent
+depenending->depending
 depenent->dependent
 depenently->dependently
 depening->depending, deepening,
@@ -8018,6 +8674,8 @@ descriptionm->description
 descriptior->descriptor
 descriptiors->descriptors
 descripto->descriptor
+descriptoin->description
+descriptoins->descriptions
 descripton->description
 descriptons->descriptions
 descriptot->descriptor
@@ -8072,6 +8730,7 @@ deside->decide
 desided->decided
 desides->decides
 desig->design
+desigern->designer
 desigining->designing
 designd->designed
 desination->destination
@@ -8082,6 +8741,12 @@ desingable->designable
 desinged->designed
 desinger->designer
 desinging->designing
+desingn->design
+desingned->designed
+desingner->designer
+desingning->designing
+desingns->designs
+desings->designs
 desintaiton->destination
 desintation->destination
 desintations->destinations
@@ -8101,7 +8766,11 @@ desktiop->desktop
 deskys->disguise
 deslected->deselected
 deslects->deselects
+desltop->desktop
+desltops->desktops
 desn't->doesn't
+desne->dense
+desnse->dense
 desogn->design
 desogned->designed
 desogner->designer
@@ -8177,6 +8846,8 @@ destuction->destruction
 desturcted->destructed
 desturtor->destructor
 desturtors->destructors
+desychronize->desynchronize
+desychronized->desynchronized
 detabase->database
 detachs->detaches
 detahced->detached
@@ -8395,6 +9066,8 @@ dicarded->discarded
 dicarding->discarding
 dicards->discards
 dicates->dictates
+dicationaries->dictionaries
+dicationary->dictionary
 dicergence->divergence
 dichtomy->dichotomy
 dicionaries->dictionaries
@@ -8583,6 +9256,8 @@ dimentionnals->dimensional
 dimentions->dimensions
 dimesions->dimensions
 dimesnional->dimensional
+diminsh->diminish
+diminshed->diminished
 diminuitive->diminutive
 dimissed->dismissed
 dimmension->dimension
@@ -8768,6 +9443,7 @@ discconetions->disconnections
 discconets->disconnects
 disccuss->discuss
 discernable->discernible
+dischare->discharge
 discimenation->dissemination
 disciplins->disciplines
 disclamer->disclaimer
@@ -8858,7 +9534,13 @@ disertation->dissertation
 disfunctional->dysfunctional
 disfunctionality->dysfunctionality
 disgarded->discarded, discarted,
+disgn->design
+disgned->designed
+disgner->designer
+disgning->designing-
 disgnostic->diagnostic
+disgnostics->diagnostics
+disgns->designs
 disguisting->disgusting
 disharge->discharge
 disign->design
@@ -8866,6 +9548,12 @@ disignated->designated
 disinguish->distinguish
 disiplined->disciplined
 disired->desired
+diskrete->discrete
+diskretion->discretion
+diskretization->discretization
+diskretize->discretize
+diskretized->discretized
+diskrimination->discrimination
 dislaimer->disclaimer
 dislay->display
 dislayed->displayed
@@ -8921,8 +9609,14 @@ displys->displays
 dispode->dispose
 disporue->disparue
 disposel->disposal
+dispossable->disposable
+dispossal->disposal
+disposse->dispose
+dispossed->disposed, dispossessed,
+disposses->disposes, dispossess,
+dispossing->disposing
 dispostion->disposition
-dispprove->disapprove
+dispprove->disprove, disapprove,
 disproportiate->disproportionate
 disproportionatly->disproportionately
 disputandem->disputandum
@@ -9101,6 +9795,12 @@ distingusih->distinguish
 distinquish->distinguish
 distinquishable->distinguishable
 distintions->distinctions
+distirbute->distribute
+distirbuted->distributed
+distirbutes->distributes
+distirbuting->distributing
+distirbution->distribution
+distirbutions->distributions
 distirted->distorted
 distnace->distance
 distnaces->distances
@@ -9149,8 +9849,10 @@ disussions->discussions
 disutils->distutils
 ditance->distance
 ditinguishes->distinguishes
+ditribute->distribute
 ditributed->distributed
 ditribution->distribution
+ditributions->distributions
 divde->divide
 diversed->diverse, diverged,
 divertion->diversion
@@ -9276,6 +9978,8 @@ domians->domains
 dominaton->domination
 dominent->dominant
 dominiant->dominant
+donain->domain
+donains->domains
 donejun->dungeon
 donejuns->dungeons
 donig->doing
@@ -9297,7 +10001,7 @@ dordered->ordered
 dorment->dormant
 dorp->drop
 dosen't->doesn't
-dosen->doesn
+dosen->dozen, dose, doesn,
 dosen;t->doesn't
 dosens->dozens
 dosent'->doesn't
@@ -9341,7 +10045,13 @@ doulbe->double
 doumentc->document
 dout->doubt
 dowgrade->downgrade
+dowlink->downlink
+dowlinks->downlinks
 dowload->download
+dowloaded->downloaded
+dowloader->downloader
+dowloaders->downloaders
+dowloading->downloading
 dowloads->downloads
 downgrate->downgrade
 downgrated->downgraded
@@ -9397,6 +10107,12 @@ drawm->drawn
 drawng->drawing
 dreasm->dreams
 dreawn->drawn
+drescription->description
+drescriptions->descriptions
+driagram->diagram
+driagrammed->diagrammed
+driagramming->diagramming
+driagrams->diagrams
 driectly->directly
 drity->dirty
 driveing->driving
@@ -9469,8 +10185,11 @@ dupliacted->duplicated
 dupliactes->duplicates
 dupliagte->duplicate
 dupliate->duplicate
+dupliated->duplicated
 dupliates->duplicates
+dupliating->duplicating
 dupliation->duplication
+dupliations->duplications
 duplicat->duplicate
 duplicatd->duplicated
 duplicats->duplicates
@@ -9480,7 +10199,6 @@ dupplicates->duplicates
 dupplicating->duplicating
 dupplication->duplication
 dupplications->duplications
-dur->due
 durationm->duration
 durectories->directories
 durectory->directory
@@ -9495,6 +10213,9 @@ dyanmic->dynamic
 dyanmically->dynamically
 dyas->dryas
 dymamically->dynamically
+dynamc->dynamic
+dynamcly->dynamincally
+dynamcs->dynamics
 dynamicaly->dynamically
 dynamiclly->dynamically
 dynamicly->dynamically
@@ -9503,7 +10224,9 @@ dynamlically->dynamically
 dynically->dynamically
 dynmaic->dynamic
 dynmaically->dynamically
+dynmic->dynamic
 dynmically->dynamically
+dynmics->dynamics
 eabled->enabled
 eacf->each
 eacg->each
@@ -9520,10 +10243,12 @@ eample->example
 eamples->examples
 eanable->enable
 eanble->enable
-earch->search
+earch->search, each,
 earler->earlier
 earliear->earlier
 earlies->earliest
+earlist->earliest
+earlyer->earlier
 earnt->earned
 earpeice->earpiece
 easer->easier, eraser,
@@ -9555,6 +10280,10 @@ ecret->secret, erect,
 ecspecially->especially
 ect->etc
 ecxept->except
+ecxite->excite
+ecxited->excited
+ecxites->excites
+ecxiting->exciting
 ecxtracted->extracted
 EDCDIC->EBCDIC
 edditable->editable
@@ -9591,6 +10320,8 @@ effeck->effect
 effecked->effected
 effecks->effects
 effeckt->effect
+effectice->effective
+effecticely->effectively
 effectiviness->effectiveness
 effectivness->effectiveness
 effectly->effectively
@@ -9612,14 +10343,24 @@ eforceable->enforceable
 egde->edge
 egdes->edges
 ege->edge
+egenral->general
+egenralise->generalise
+egenralised->generalised
+egenralises->generalises
+egenralize->generalize
+egenralized->generalized
+egenralizes->generalizes
+egenrally->generally
 ehance->enhance
 ehanced->enhanced
 ehancement->enhancement
 ehancements->enhancements
+ehen->when, hen, even, then,
+ehenever->whenever
 ehough->enough
 ehr->her
 ehternet->Ethernet
-ehther->ether
+ehther->ether, either,
 ehthernet->ethernet
 eighter->either
 eigth->eighth, eight,
@@ -9632,6 +10373,7 @@ elction->election
 elctromagnetic->electromagnetic
 eleate->relate
 electic->eclectic, electric,
+electical->electrical
 electirc->electric
 electircal->electrical
 electon->election, electron,
@@ -9646,6 +10388,8 @@ eleent->element
 elegible->eligible
 elemant->element
 elemantary->elementary
+elemement->element
+elemements->elements
 elememt->element
 elemen->element
 elemenent->element
@@ -9794,6 +10538,8 @@ emties->empties
 emtpy->empty
 emty->empty
 emtying->emptying
+emultor->emulator
+emultors->emulators
 enabe->enable
 enabel->enable
 enabeled->enabled
@@ -9824,15 +10570,35 @@ enclosue->enclosure
 enclosung->enclosing
 enclude->include
 encluding->including
+encocde->encode
 encocded->encoded
+encocder->encoder
+encocders->encoders
+encocdes->encodes
+encocding->encoding
+encocdings->encodings
+enconde->encode
+enconded->encoded
+enconder->encoder
+enconders->encoders
+encondes->encodes
 enconding->encoding
 encondings->encodings
+encorde->encode, encore,
 encorded->encoded
+encorder->encoder
+encorders->encoders
+encordes->encodes, encores,
+encording->encoding
+encordings->encodings
 encorporating->incorporating
-encose->enclose
-encosed->enclosed
-encoses->encloses
-encosing->enclosing
+encose->enclose, encode,
+encosed->enclosed, encoded,
+encoser->encoder
+encosers->encoders
+encoses->encloses, encodes,
+encosing->enclosing, encoding,
+encosings->enclosings, encodings,
 encosure->enclosure
 encounted->encountered, encounter,
 encounterd->encountered
@@ -9842,6 +10608,7 @@ encoutered->encountered
 encouters->encounters
 encoutner->encounter
 encoutners->encounters
+encouttering->encountering
 encrcypt->encrypt
 encripted->encrypted
 encrpt->encrypt
@@ -9859,7 +10626,12 @@ encupsulates->encapsulates
 encylopedia->encyclopedia
 encypted->encrypted
 encyption->encryption
+endcoded->encoded
+endcoder->encoder
+endcoders->encoders
+endcodes->encodes
 endcoding->encoding
+endcodings->encodings
 endding->ending
 ende->end
 endevors->endeavors
@@ -9868,6 +10640,8 @@ endfi->endif
 endianes->endianness
 endianess->endianness
 endiannes->endianness
+endien->endian, indian,
+endiens->endians, indians,
 endig->ending
 endnoden->endnode
 endoint->endpoint
@@ -9891,6 +10665,10 @@ eneter->enter
 enetered->entered
 enetities->entities
 enetity->entity
+eneumeration->enumeration
+eneumerations->enumerations
+eneumretaion->enumeration
+eneumretaions->enumerations
 enew->new
 enflamed->inflamed
 enforcable->enforceable
@@ -9943,7 +10721,13 @@ enmpty->empty
 enmum->enum
 ennpoint->endpoint
 enntries->entries
+enocde->encode
 enocded->encoded
+enocder->encoder
+enocders->encoders
+enocdes->encodes
+enocding->encoding
+enocdings->encodings
 enogh->enough
 enoght->enough
 enoguh->enough
@@ -10029,7 +10813,8 @@ entquiry->enquiry, inquiry,
 entrepeneur->entrepreneur
 entrepeneurs->entrepreneurs
 entrie->entry, entries,
-entrys->entries
+entriy->entry, entries,
+entrys->entries, entry,
 enty->entry, entity,
 enulation->emulation
 enumarate->enumerate
@@ -10082,6 +10867,10 @@ enviromental->environmental
 enviromentalist->environmentalist
 enviromentally->environmentally
 enviroments->environments
+enviromnent->environment
+enviromnental->environmental
+enviromnentally->environmentally
+enviromnents->environments
 environement->environment
 environemnt->environment
 environemntal->environmental
@@ -10108,6 +10897,7 @@ envrironments->environments
 envrirons->environs
 envvironment->environment
 enxt->next
+enyway->anyway
 epecifica->especifica
 epect->expect
 epected->expected
@@ -10149,6 +10939,7 @@ equiped->equipped
 equipmentd->equipment
 equipments->equipment
 equippment->equipment
+equiptment->equipment
 equire->require, enquire, equine, esquire,
 equitorial->equatorial
 equivalance->equivalence
@@ -10163,6 +10954,8 @@ equivivalent->equivalent
 equivlalent->equivalent
 equivlantly->equivalently
 equivqlent->equivalent
+eqution->equation
+equtions->equations
 equvalent->equivalent
 erally->orally, really,
 erasablocks->eraseblocks
@@ -10336,6 +11129,7 @@ evauluated->evaluated
 evauluates->evaluates
 evauluation->evaluation
 evelope->envelope, envelop,
+evem->even, ever,
 evenhtually->eventually
 eventally->eventually
 eventaully->eventually
@@ -10436,10 +11230,22 @@ excecpt->except
 excecption->exception
 excecptional->exceptional
 excecptions->exceptions
-excect->except
-excection->exception
+excect->except, expect,
+excectable->executable
+excectables->executables
+excecte->execute
+excected->executed, expected,
+excectedly->expectedly
+excectes->executes
+excecting->executing
+excection->exception, execution,
 excectional->exceptional
-excections->exceptions
+excections->exceptions, executions,
+excective->executive
+excectives->executives
+excector->executor
+excectors->executors
+excects->expects
 excecutable->executable
 excecutables->executables
 excecute->execute
@@ -10453,12 +11259,16 @@ excecutives->executives
 excecutor->executor
 excecutors->executors
 excecuts->executes
+exced->exceed
 excedded->exceeded
 excedding->exceeding
+excede->exceed
 exceded->exceeded
 excedeed->exceeded
 excedes->exceeds
 exceding->exceeding
+exceirpt->excerpt
+exceirpts->excerpts
 excelent->excellent
 excell->excel
 excellance->excellence
@@ -10489,8 +11299,13 @@ excercised->exercised
 excerciser->exerciser
 excercises->exercises
 excercising->exercising
+exces->excess
+excesed->exceeded
 excesive->excessive
+excesively->excessively
 excesss->excess
+excesv->excessive
+excesvly->excessively
 excetion->exception
 excetional->exceptional
 excetions->exceptions
@@ -10513,6 +11328,18 @@ excetutive->executive
 excetutives->executives
 excetutor->executor
 excetutors->executors
+exceuctable->executable
+exceuctables->executables
+exceucte->execute
+exceucted->executed
+exceuctes->executes
+exceucting->executing
+exceuction->execution
+exceuctions->executions
+exceuctive->executive
+exceuctives->executives
+exceuctor->executor
+exceuctors->executors
 exceutable->executable
 exceutables->executables
 exceute->execute
@@ -10586,8 +11413,13 @@ excitment->excitement
 exclamantion->exclamation
 excludde->exclude
 excludind->excluding
+excluse->exclude, excuse, exclusive,
 exclusiv->exclusive
+exclusivs->exclusives
 excluslvely->exclusively
+exclusuive->exclusive
+exclusuively->exclusively
+exclusuives->exclusives
 excpect->expect
 excpected->expected
 excpecting->expecting
@@ -10634,24 +11466,124 @@ exectuable->executable
 exectuableness->executableness
 exectuables->executables
 exectued->executed
+exectuion->execution
+exectuions->executions
 exectution->execution
 exectutions->executions
 execuable->executable
 execuables->executables
+execuatable->executable
+execuatables->executables
+execuatble->executable
+execuatbles->executables
+execuate->execute
+execuated->executed
+execuates->executes
+execuation->execution
+execuations->executions
+execubale->executable
+execubales->executables
+execucte->execute
+execucted->executed
+execuctes->executes
+execuction->execution
+execuctions->executions
+execuctor->executor
+execuctors->executors
+execude->execute
+execuded->executed
+execudes->executes
+execuding->executing, excluding,
+execue->execute
+execued->executed
+execues->executes
+execuet->execute
 execuetable->executable
+execuetd->executed
+execuete->execute
+execueted->executed
+execuetes->executes
+execuets->executes
+execuing->executing
+execuion->execution
+execuions->executions
+execuitable->executable
+execuitables->executables
+execuite->execute
+execuited->executed
+execuites->executes
+execuiting->executing
+execuition->execution
+execuitions->executions
+execulatble->executable
+execulatbles->executables
+execultable->executable
+execultables->executables
+execulusive->exclusive
+execune->execute
+execuned->executed
+execunes->executes
+execurable->executable
+execurables->executables
 execure->execute
+execured->executed
+execures->executes
+execuse->excuse, execute,
+execused->excused, executed,
+execuses->excuses, executes,
+execusion->execution
+execusions->executions
+execusive->exclusive
+execustion->execution
+execustions->executions
 execut->execute
+executabable->executable
+executabables->executables
+executabe->executable
+executabel->executable
+executabels->executables
+executabes->executables
 executablble->executable
+executabnle->executable
+executabnles->executables
 executation->execution
+executations->executions
 executbale->executable
+executbales->executables
+executble->executable
+executbles->executables
+executd->executed
+executding->executing
 executeable->executable
 executeables->executables
 executign->executing
 executiong->execution, executing,
+executng->executing
+executre->execute
+executred->executed
+executres->executes
 executs->executes
+executting->executing
+executtion->execution
+executtions->executions
+executuable->executable
+executuables->executables
+executuble->executable
+executubles->executables
+executue->execute
+executued->executed
+executues->executes
+executuing->executing
+executuion->execution
+executuions->executions
+executung->executing
+executuon->execution
+executuons->executions
 executute->execute
 execututed->executed
 execututes->executes
+executution->execution
+execututions->executions
 exeed->exceed
 exeeding->exceeding
 exeedingly->exceedingly
@@ -10677,23 +11609,32 @@ exepects->expects
 exepriment->experiment
 exeprimental->experimental
 exept->except, exempt,
-exeption->exception
+exeption->exception, exemption,
 exeptional->exceptional
 exeptions->exceptions
 exeqution->execution
 exerbate->exacerbate
 exerbated->exacerbated
-exerciese->exercises
+exerciese->exercise
+exerciesed->exercised
+exercieses->exercises
+exerciesing->exercising
 exercize->exercise
 exerpt->excerpt
 exerpts->excerpts
 exersize->exercise
 exersizes->exercises
 exerternal->external
+exeucte->execute
+exeucted->executed
+exeuctes->executes
 exeution->execution
 exexutable->executable
 exhalted->exalted
+exhange->exchange
 exhanged->exchanged
+exhanges->exchanges
+exhanging->exchanging
 exhaused->exhausted
 exhautivity->exhaustivity
 exhcuast->exhaust
@@ -10710,6 +11651,10 @@ exibition->exhibition
 exibitions->exhibitions
 exicting->exciting
 exinct->extinct
+exipration->expiration
+exipre->expire
+exipred->expired
+exipres->expires
 exising->existing
 exisit->exist
 exisited->existed
@@ -10729,6 +11674,9 @@ existsing->existing
 existung->existing
 existy->exist
 existying->existing
+exitation->excitation
+exitations->excitations
+exite->exit, excite, exits,
 exixst->exist
 exixt->exist
 exlamation->exclamation
@@ -10740,6 +11688,9 @@ exlicite->explicit
 exlicitely->explicitly
 exlicitly->explicitly
 exliled->exiled
+exlpoit->exploit
+exlpoited->exploited
+exlpoits->exploits
 exlude->exclude, exude,
 exluded->excluded, exuded,
 exludes->excludes, exudes,
@@ -10776,6 +11727,10 @@ exparation->expiration
 expasion->expansion
 expatriot->expatriate
 expception->exception
+expct->expect
+expcted->expected
+expctedly->expectedly
+expcting->expecting
 expeced->expected
 expeceted->expected
 expecially->especially
@@ -10794,6 +11749,13 @@ expeected->expected
 expeectedly->expectedly
 expeecting->expecting
 expeects->expects
+expeense->expense
+expeenses->expenses
+expeensive->expensive
+expeience->experience
+expeienced->experienced
+expeiences->experiences
+expeiencing->experiencing
 expeiment->experiment
 expeimental->experimental
 expeimentally->experimentally
@@ -10832,10 +11794,16 @@ expementer->experimenter
 expementers->experimenters
 expementing->experimenting
 expements->experiments
+expemplar->exemplar
 expemplars->exemplars
 expemplary->exemplary
 expempt->exempt
 expempted->exempted
+expemt->exempt
+expemted->exempted
+expemtion->exemption
+expemtions->exemptions
+expemts->exempts
 expendeble->expendable
 expepect->expect
 expepected->expected
@@ -10847,6 +11815,7 @@ expepted->expected
 expeptedly->expectedly
 expepting->expecting
 expeption->exception
+expeptions->exceptions
 expepts->expects
 experament->experiment
 experamental->experimental
@@ -10860,10 +11829,15 @@ experamenter->experimenter
 experamenters->experimenters
 experamenting->experimenting
 experaments->experiments
+experation->expiration
 experct->expect, excerpt,
 expercted->expected, excerpted,
+expercting->expecting
+expercts->expects
 expereince->experience
 expereinced->experienced
+expereinces->experiences
+expereincing->experiencing
 experement->experiment
 experemental->experimental
 experementally->experimentally
@@ -10878,6 +11852,7 @@ experementing->experimenting
 experements->experiments
 experence->experience
 experenced->experienced
+experences->experiences
 experencing->experiencing
 experes->express
 experesed->expressed
@@ -10885,6 +11860,8 @@ experesion->expression
 experesions->expressions
 experess->express
 experessed->expressed
+experesses->expresses
+experessing->expressing
 experession's->expression's
 experession->expression
 experessions->expressions
@@ -10896,8 +11873,11 @@ experiancing->experiencing
 experiansial->experiential
 experiantial->experiential
 experiation->expiration
+experiations->expirations
 experice->experience
 expericed->experienced
+experices->experiences
+expericing->experiencing
 experiement->experiment
 experienshial->experiential
 experiensial->experiential
@@ -11136,6 +12116,7 @@ experinementers->experimenters
 experinementing->experimenting
 experinements->experiments
 experiration->expiration
+experirations->expirations
 expermenet->experiment
 expermenetal->experimental
 expermenetally->experimentally
@@ -11184,17 +12165,43 @@ expermimenter->experimenter
 expermimenters->experimenters
 expermimenting->experimenting
 expermiments->experiments
+experminent->experiment
+experminental->experimental
+experminentally->experimentally
+experminentation->experimentation
+experminentations->experimentations
+experminents->experiments
 expernal->external
+expers->express
+experse->expense, express,
+expersed->expressed
+experses->expenses, expresses,
+expersing->expressing
+expersion->expression
+expersions->expressions
+expersive->expensive
 experss->express
 experssed->expressed
+expersses->expresses
+experssing->expressing
 experssion->expression
 experssions->expressions
+expese->expense
+expeses->expenses
 expesive->expensive
 expesnce->expense
+expesnces->expenses
+expesncive->expensive
 expess->express
 expessed->expressed
+expesses->expresses
+expessing->expressing
 expession->expression
 expessions->expressions
+expest->expect
+expested->expected
+expestedly->expectedly
+expesting->expecting
 expet->expect, expat,
 expetancy->expectancy
 expetation->expectation
@@ -11210,6 +12217,7 @@ expetcting->expecting
 expetcts->expects
 expetect->expect
 expetected->expected
+expetectedly->expectedly
 expetecting->expecting
 expetectly->expectedly
 expetects->expects
@@ -11247,6 +12255,7 @@ expexctedly->expectedly
 expexcting->expecting
 expexcts->expects
 expexnasion->expansion
+expexnasions->expansions
 expext->expect
 expexted->expected
 expextedly->expectedly
@@ -11290,11 +12299,14 @@ explict->explicit
 explictely->explicitly
 explictily->explicitly
 explictly->explicitly
+explicty->explicitly, explicit,
 explit->explicit
 explitit->explicit
 explitly->explicitly
 explizit->explicit
 explizitly->explicitly
+exploition->explosion, exploitation, exploit,
+exploitions->explosions, exploitations, exploits,
 exploititive->exploitative
 explot->exploit, explore,
 explotation->exploitation, exploration,
@@ -11304,12 +12316,19 @@ expoential->exponential
 expoentially->exponentially
 expoert->export, expert,
 expoerted->exported
+expoit->exploit
+expoitation->exploitation
+expoited->exploited
+expoits->exploits
 expolde->explode
 exponentation->exponentiation
 exponentialy->exponentially
+exponentiel->exponential
+exponentiell->exponential
 exponetial->exponential
 exporession->expression
 exportet->exported, exporter,
+expport->export
 exppressed->expressed
 expresion->expression
 expresions->expressions
@@ -11341,6 +12360,8 @@ exsiting->existing
 exsits->exists, exist,
 exspect->expect
 exspected->expected
+exspectedly->expectedly
+exspecting->expecting
 exspects->expects
 exspense->expense
 exspensed->expensed
@@ -11388,6 +12409,9 @@ extereme->extreme
 extermist->extremist
 extermporaneous->extemporaneous
 externaly->externally
+externel->external
+externelly->externally
+externels->externals
 extesion->extension
 extesions->extensions
 extesnion->extension
@@ -11477,9 +12501,9 @@ facorite->favorite
 facorites->favorites
 facors->favors, fakers,
 facour->favour, favor,
-facourite->favourite, favorite,
-facourites->favuourites, favorites,
-facours->favours, favors,
+facourite->favourite
+facourites->favourites
+facours->favours
 factization->factorization
 factorizaiton->factorization
 factorys->factories
@@ -11494,6 +12518,8 @@ failded->failed
 faile->failed
 failer->failure
 failes->fails
+failicies->facilities
+failicy->facility
 failied->failed
 failiure->failure
 failiures->failures
@@ -11513,6 +12539,8 @@ failuer->failure
 failues->failures
 faireness->fairness
 fairoh->pharaoh
+faiway->fairway
+faiways->fairways
 falg->flag
 falgs->flags
 falied->failed
@@ -11523,6 +12551,7 @@ fallbck->fallback
 fallhrough->fallthrough
 fallthruogh->fallthrough
 falltrough->fallthrough
+falsly->falsely
 falt->fault
 falure->failure
 familar->familiar
@@ -11536,6 +12565,7 @@ famlily->family
 famoust->famous
 fanatism->fanaticism
 fancyness->fanciness
+farction->fraction, faction,
 Farenheight->Fahrenheit
 Farenheit->Fahrenheit
 farest->fairest, farthest,
@@ -11558,9 +12588,15 @@ fatig->fatigue
 fatser->faster
 fature->feature
 faught->fought
+fauilure->failure
 fauilures->failures
-faund->found
+faund->found, fund,
+fauture->feature
+fautured->featured
+fautures->features
+fauturing->featuring
 favoutrable->favourable
+favuourites->favourites
 faymus->famous
 fcound->found
 feasabile->feasible
@@ -11646,7 +12682,6 @@ fileds->fields
 fileld->field
 filelds->fields
 filenae->filename
-files'->file's
 fileshystem->filesystem
 fileshystems->filesystems
 filesname->filename, filenames,
@@ -11678,6 +12713,11 @@ fillowing->following
 fillung->filling
 filnal->final
 filname->filename
+filp->flip
+filpped->flipped
+filpping->flipping
+filps->flips
+fils->fills, files, file,
 filse->files
 filsystem->filesystem
 filsystems->filesystems
@@ -11710,6 +12750,8 @@ findn->find
 findout->find out
 finelly->finally
 finess->finesse
+finge->finger, fringe,
+fingeprint->fingerprint
 finialization->finalization
 finializing->finalizing
 finilizes->finalizes
@@ -11750,25 +12792,40 @@ fisionable->fissionable
 fisisist->physicist
 fisist->physicist
 fisrt->first
-fiter->filter, fighter,
+fiter->filter, fighter, fitter, fiver,
 fitering->filtering
-fiters->filters, fighters,
+fiters->filters, fighters, fitters, fivers,
 fitler->filter
 fitlers->filters
 fivety->fifty
 fixe->fixed, fixes, fix, fixme, fixer,
 fixeme->fixme
+fixwd->fixed
 fizeek->physique
+flacor->flavor
+flacored->flavored
+flacoring->flavoring
+flacorings->flavorings
+flacors->flavors
+flacour->flavour
+flacoured->flavoured
+flacouring->flavouring
+flacourings->flavourings
+flacours->flavours
 flage->flags
 flaged->flagged
 flages->flags
 flagg->flag
+flahs->flash, flags,
+flahsed->flashed
+flahses->flashes
+flahsing->flashing
 flakyness->flakiness
 flamable->flammable
 flaot->float
 flaoting->floating
 flashflame->flashframe
-flass->class, flask,
+flass->class, glass, flask, flash,
 flate->flat
 flatened->flattened
 flattend->flattened
@@ -11781,8 +12838,10 @@ Flemmish->Flemish
 flewant->fluent
 flexability->flexibility
 flexable->flexible
-flexibel->flexibele
+flexibel->flexible
+flexibele->flexible
 flexibilty->flexibility
+flext->flex
 flie->file
 floading->floating, flooding,
 floading-add->floating-add
@@ -12048,6 +13107,7 @@ forbit->forbid
 forbiten->forbidden
 forbitten->forbidden
 forcably->forcibly
+forcot->forgot
 foreing->foreign
 forementionned->aforementioned
 foreward->foreword, forward,
@@ -12093,6 +13153,8 @@ forteen->fourteen
 fortelling->foretelling
 forthcominng->forthcoming
 forthcomming->forthcoming
+fortunaly->fortunately
+fortunat->fortunate
 fortunatly->fortunately
 fortunetly->fortunately
 forula->formula
@@ -12115,7 +13177,7 @@ forwardig->forwarding
 forwared->forwarded, forward,
 forwaring->forwarding
 forwwarded->forwarded
-fot->for
+fot->for, fit, dot, rot, cot, got, tot, fog,
 foto->photo
 fotograf->photograph
 fotografic->photographic
@@ -12166,6 +13228,12 @@ frankin->franklin
 Fransiscan->Franciscan
 Fransiscans->Franciscans
 franzise->franchise
+frecuencies->frequencies
+frecuency->frequency
+frecuent->frequent
+frecuented->frequented
+frecuently->frequently
+frecuents->frequents
 freecallrelpy->freecallreply
 freedon->freedom
 freedons->freedoms
@@ -12184,8 +13252,10 @@ frequant->frequent
 frequantly->frequently
 frequences->frequencies
 frequencey->frequency
-frequenct->frequency
+frequenct->frequency, frequent,
+frequenies->frequencies
 frequentily->frequently
+frequeny->frequency, frequently, frequent,
 frequncies->frequencies
 frequncy->frequency
 freze->freeze
@@ -12204,6 +13274,8 @@ fromed->formed
 froms->forms
 fromthe->from the
 fron->from
+fronend->frontend
+fronends->frontends
 froniter->frontier
 frontent->frontend
 frontents->frontends
@@ -12228,14 +13300,15 @@ fugured->figured
 fugures->figures
 fule->file
 fulfiled->fulfilled
+fullfil->fulfil, fulfill,
 fullfiled->fulfilled
 fullfiling->fulfilling
-fullfill->fulfill
+fullfill->fulfill, fulfil,
 fullfilled->fulfilled
 fullfilling->fulfilling
 fullfills->fulfills
-fullfils->fulfils
-fullill->fulfill
+fullfils->fulfils, fulfills,
+fullill->fulfil, fulfill,
 fullly->fully
 fulsh->flush
 funcation->function
@@ -12351,7 +13424,6 @@ fysisist->physicist
 fysisit->physicist
 gabage->garbage
 gadged->gadget, gauged,
-gae->game, Gael, gale,
 galatic->galactic
 Galations->Galatians
 gallaries->galleries
@@ -12400,8 +13472,8 @@ gaurenteed->guaranteed
 gaurentees->guarantees
 gaus'->Gauss'
 gaus's->Gauss'
-gaus->Gauss
-gausian->gaussian
+gaus->Gauss, gauze,
+gausian->Gaussian
 geenrate->generate
 geenrated->generated
 geenrates->generates
@@ -12461,19 +13533,34 @@ generilize->generalize
 generilized->generalized
 generilizes->generalizes
 generiously->generously
+generted->generated
+generting->generating
+genertion->generation
+genertor->generator
+genertors->generators
 genialia->genitalia
 genral->general
 genralisation->generalisation
 genralisations->generalisations
+genralise->generalise
+genralised->generalised
+genralises->generalises
 genralization->generalization
 genralizations->generalizations
+genralize->generalize
+genralized->generalized
+genralizes->generalizes
 genrally->generally
 genrals->generals
 genrate->generate
 genrated->generated
 genrates->generates
+genratet->generated
 genrating->generating
 genration->generation
+genrations->generations
+genrator->generator
+genrators->generators
 genreate->generate
 genreated->generated
 genreates->generates
@@ -12520,6 +13607,8 @@ gernerating->generating
 gerneration->generation
 gernerator->generator
 gernerators->generators
+gerneric->generic
+gernerics->generics
 gess->guess
 get's->gets
 get;s->gets
@@ -12647,7 +13736,9 @@ gratefull->grateful
 gratuitious->gratuitous
 grbber->grabber
 greate->greater, create, grate, great,
+greated->greater, grated, graded,
 greatful->grateful
+greatfull->grateful, gratefully,
 greatfully->gratefully
 greather->greater
 greif->grief
@@ -12659,11 +13750,16 @@ grigorian->Gregorian
 grobal->global
 grobally->globally
 grometry->geometry
+grooup->group
+groouped->grouped
+groouping->grouping
+grooups->groups
 grop->group, drop,
 gropu->group
 gropus->groups, gropes,
 groubpy->groupby
 groupd->grouped
+groupes->groups, grouped,
 groupt->grouped
 grranted->granted
 gruop->group
@@ -12805,7 +13901,7 @@ guas's->Gauss'
 guas->Gauss
 guass'->Gauss'
 guass->Gauss
-guassian->gaussian
+guassian->Gaussian
 Guatamala->Guatemala
 Guatamalan->Guatemalan
 gud->good
@@ -12923,7 +14019,7 @@ hapenning->happening
 hapenns->happens
 hapens->happens
 happaned->happened
-happend->happened, happens,
+happend->happened, happens, happen,
 happended->happened
 happenned->happened
 happenning->happening
@@ -12967,6 +14063,7 @@ harrassment->harassment
 harrassments->harassments
 harth->hearth
 harware->hardware
+harwdare->hardware
 has'nt->hasn't
 hases->hashes
 hashi->hash
@@ -13047,6 +14144,7 @@ heree->here
 heridity->heredity
 heroe->hero
 heros->heroes
+herselv->herself
 hertiage->heritage
 hertically->hectically
 hertzs->hertz
@@ -13079,6 +14177,10 @@ hierarachy->hierarchy
 hierarchie->hierarchy
 hierarcical->hierarchical
 hierarcy->hierarchy
+hierarhcical->hierarchical
+hierarhcically->hierarchically
+hierarhcies->hierarchies
+hierarhcy->hierarchy
 hierchy->hierarchy
 hieroglph->hieroglyph
 hieroglphs->hieroglyphs
@@ -13168,7 +14270,11 @@ homegeneous->homogeneous
 homestate->home state
 homogeneize->homogenize
 homogeneized->homogenized
+homogenious->homogeneous
+homogeniously->homogeneously
 homogenity->homogeneity
+homogenius->homogeneous
+homogeniusly->homogeneously
 homogenoues->homogeneous
 homogenous->homogeneous
 homogenously->homogeneously
@@ -13210,6 +14316,8 @@ hostanme->hostname
 hostorical->historical
 hostories->histories
 hostory->history
+hostspot->hotspot
+hostspots->hotspots
 hotizontal->horizontal
 hotname->hostname
 hould->hold, should,
@@ -13223,6 +14331,8 @@ hovewer->however
 howerver->however
 howeverm->however
 howver->however
+hradware->hardware
+hradwares->hardwares
 hrlp->help
 hrlped->helped
 hrlper->helper
@@ -13234,6 +14344,7 @@ hsa->has
 hsell->shell
 hsi->his
 hsitorians->historians
+hsotname->hostname
 hsould'nt->shouldn't
 hsould->should
 hsouldn't->shouldn't
@@ -13260,6 +14371,7 @@ hunderd->hundred
 hundret->hundred, hundreds,
 hundreths->hundredths
 hundrets->hundreds
+hungs->hangs, hung,
 hunrgy->hungry
 huricane->hurricane
 huristic->heuristic
@@ -13317,7 +14429,6 @@ hypvisor->hypervisor
 hypvisors->hypervisors
 I'sd->I'd
 i;ll->I'll
-iam->I am, aim,
 iamge->image
 ibrary->library
 icesickle->icicle
@@ -13336,7 +14447,7 @@ idenfifier->identifier
 idenitify->identify
 identation->indentation
 identcial->identical
-identiable->identificable
+identiable->identifiable
 idential->identical
 identicial->identical
 identidier->identifier
@@ -13346,6 +14457,7 @@ identifeir->identifier
 identifeirs->identifiers
 identifer->identifier
 identifers->identifiers
+identificable->identifiable
 identifictaion->identification
 identifieer->identifier
 identifing->identifying
@@ -13451,6 +14563,11 @@ illustrasion->illustration
 illution->illusion
 ilness->illness
 ilogical->illogical
+iluminate->illuminate
+iluminated->illuminated
+iluminates->illuminates
+ilumination->illumination
+iluminations->illuminations
 ilustrate->illustrate
 ilustrated->illustrated
 ilustration->illustration
@@ -13579,7 +14696,9 @@ impiled->implied
 implace->inplace
 implament->implement
 implamentation->implementation
+implamented->implemented
 implamenting->implementing
+implaments->implements
 implcit->implicit
 implemantation->implementation
 implemataion->implementation
@@ -13707,13 +14826,22 @@ implmenting->implementing
 implments->implements
 imploys->employs
 imporing->importing
+imporove->improve
+imporoved->improved
+imporovement->improvement
+imporovements->improvements
+imporoves->improves
+imporoving->improving
 importamt->important
 importat->important
 importd->imported
 importent->important
 imporv->improve, improv,
 imporve->improve
+imporved->improved
 imporvement->improvement
+imporvements->improvements
+imporves->improves
 imporving->improving
 imporvment->improvement
 imposible->impossible
@@ -13722,6 +14850,7 @@ impotr->import, importer,
 impotrt->import, imported, importer,
 impove->improve
 impoved->improved
+impovement->improvement
 impovements->improvements
 impoves->improves
 impoving->improving
@@ -13757,8 +14886,10 @@ improovment->improvement
 improovments->improvements
 impropely->improperly
 improtant->important
+improvemen->improvement
 improvemenet->improvement
 improvemenets->improvements
+improvemens->improvements
 improvision->improvisation
 improvmenet->improvement
 improvmenets->improvements
@@ -13830,6 +14961,10 @@ incluing->including
 inclused->included
 inclusinve->inclusive
 incmrement->increment
+incoherance->incoherence
+incoherancy->incoherency
+incoherant->incoherent
+incoherantly->incoherently
 incomapatibility->incompatibility
 incomapatible->incompatible
 incomaptible->incompatible
@@ -13889,6 +15024,10 @@ inconsisntency->inconsistency
 inconsistancy->inconsistency
 inconsistant->inconsistent
 inconsisten->inconsistent
+inconsistend->inconsistent
+inconsistendly->inconsistently
+inconsistendt->inconsistent
+inconsistendtly->inconsistently
 inconsistenly->inconsistently
 inconsistented->inconsistent
 inconsisteny->inconsistency, inconsistent,
@@ -13951,6 +15090,10 @@ incremet->increment
 incremetal->incremental
 incremeted->incremented
 incremnet->increment
+increse->increase
+incresed->increased
+increses->increases
+incresing->increasing
 incrfemental->incremental
 incrmenet->increment
 incrmenetd->incremented
@@ -13969,6 +15112,9 @@ incuded->included
 incudes->includes
 incuding->including
 inculde->include
+inculded->included
+inculdes->includes
+inculding->including
 incunabla->incunabula
 incure->incur
 incurruptable->incorruptible
@@ -13994,17 +15140,36 @@ indentaion->indentation
 indentended->indented
 indentical->identical
 indentically->identically
+indentifer->identifier
 indentification->identification
 indentified->identified
 indentifier->identifier
 indentifies->identifies
+indentifing->identifying
 indentify->identify
 indentifying->identifying
 indentit->identity
 indentity->identity
 indenx->index
+indepandance->independence
+indepdence->independence
+indepdencente->independence
 indepdendance->independence
+indepdendant->independent
+indepdendantly->independently
+indepdendence->independence
 indepdendency->independency
+indepdendent->independent
+indepdendently->independently
+indepdendet->independent
+indepdendetly->independently
+indepdenence->independence
+indepdenent->independent
+indepdenently->independently
+indepdent->independent
+indepdented->independent
+indepdentedly->independently
+indepdently->independently
 indepedantly->independently
 indepedence->independence
 indepedent->independent
@@ -14024,6 +15189,7 @@ independnt->independent
 independntly->independently
 independt->independent
 independtly->independently
+indepenendence->independence
 indepenent->independent
 indepenently->independently
 indepent->independent
@@ -14045,6 +15211,7 @@ indicaite->indicate
 indicat->indicate
 indicateds->indicated, indicates,
 indicatee->indicates, indicated,
+indicats->indicates, indicate,
 indicees->indices
 indiciate->indicate
 indiciated->indicated
@@ -14056,10 +15223,14 @@ indictement->indictment
 indictes->indicates
 indictor->indicator
 indide->inside
+indien->indian, endian,
+indiens->indians, endians,
 indigineous->indigenous
 indipendence->independence
 indipendent->independent
 indipendently->independently
+indiquate->indicate
+indiquates->indicates
 indirecty->indirectly
 indispensible->indispensable
 indisputible->indisputable
@@ -14129,6 +15300,11 @@ inexpirienced->inexperienced
 infact->in fact
 infalability->infallibility
 infallable->infallible
+infaltable->inflatable, infallible,
+infalte->inflate
+infalted->inflated
+infaltes->inflates
+infalting->inflating
 infectuous->infectious
 infered->inferred
 inferface->interface
@@ -14158,6 +15334,10 @@ influencin->influencing
 influented->influenced
 infoemation->information
 infomation->information
+infomational->informational
+infomed->informed
+infomer->informer
+infoms->informs
 infor->info
 inforamtion->information
 inforation->information
@@ -14169,6 +15349,8 @@ informaiton->information
 informatation->information
 informatations->information
 informatikon->information
+informatin->information, informing,
+informatins->information
 informatiom->information
 informations->information
 informatoin->information
@@ -14357,11 +15539,18 @@ inizialize->initialize
 inizialized->initialized
 inizializes->initializes
 inlalid->invalid
+inlclude->include
+inlcluded->included
+inlcludes->includes
+inlcluding->including
+inlcludion->inclusion
+inlclusive->inclusive
 inlcude->include
 inlcuded->included
 inlcudes->includes
 inlcuding->including
 inlcusion->inclusion
+inlcusive->inclusive
 inlin->inline
 inlude->include
 inluded->included
@@ -14526,6 +15715,7 @@ instatance->instance
 instatiate->instantiate
 insteance->instance
 insted->instead
+insteead->instead
 inster->insert
 insterad->instead
 insterrupts->interrupts
@@ -14617,11 +15807,16 @@ intenational->international
 intendet->intended
 inteneded->intended
 intension->intention
+intensional->intentional
+intensionally->intentionally
+intensionaly->intentionally
 intensitive->insensitive, intensive,
 intentation->indentation
 intented->intended, indented,
 intentended->intended
 intentially->intentionally
+intentialy->intentionally
+intentionaly->intentionally
 intepolate->interpolate
 intepolated->interpolated
 intepolates->interpolates
@@ -14661,7 +15856,7 @@ interaktively->interactively
 interaktivly->interactively
 interal->internal, interval, integral,
 interally->internally
-interals->internals
+interals->internals, intervals, integrals,
 interaly->internally
 interanl->internal
 interanlly->internally
@@ -14716,7 +15911,12 @@ interesst->interest
 interessted->interested
 interessting->interesting
 intereview->interview
+interfal->interval
+interfals->intervals
 interfave->interface
+interfaves->interfaces
+interfcae->interface
+interfcaes->interfaces
 interfear->interfere
 interfearence->interference
 interfearnce->interference
@@ -14895,6 +16095,7 @@ intiial->initial
 intiialise->initialise
 intiialize->initialize
 intimite->intimate
+intinite->infinite
 intitial->initial
 intitialization->initialization
 intitialize->initialize
@@ -15032,12 +16233,20 @@ iresistably->irresistibly
 iresistible->irresistible
 iresistibly->irresistibly
 iritable->irritable
+iritate->irritate
 iritated->irritated
+iritating->irritating
 ironicly->ironically
+irradate->irradiate
+irradation->irradiation
+irregularties->irregularities
+irregulier->irregular
+irregulierties->irregularities
 irrelavent->irrelevant
 irrelevent->irrelevant
 irrelvant->irrelevant
 irreplacable->irreplaceable
+irreplacalbe->irreplaceable
 irreproducable->irreproducible
 irresepective->irrespective
 irresistable->irresistible
@@ -15046,6 +16255,8 @@ irreversable->irreversible
 is'nt->isn't
 isconnection->isconnected
 iscrated->iscreated
+iself->itself
+iselfe->itself
 iserting->inserting
 isimilar->similar
 isloation->isolation
@@ -15066,17 +16277,26 @@ isssue->issue
 isssued->issued
 isssues->issues
 issueing->issuing
-ist->is, it, its, it's, list,
+ist->is, it, its, it's, sit, list,
 istalling->installing
 istance->instance
 istead->instead
-istener->listeners
+istened->listened
+istener->listener
+isteners->listeners
+istening->listening
 ists->its, lists,
 isue->issue
 iteartor->iterator
 iteger->integer
+itegral->integral
+itegrals->integrals
 iten->item
 itens->items
+itention->intention
+itentional->intentional
+itentionally->intentionally
+itentionaly->intentionally
 iterater->iterator
 iteratered->iterated
 iteratons->iterations
@@ -15107,8 +16327,10 @@ itnroduced->introduced
 itsef->itself
 itselfs->itself
 itselt->itself
+itselv->itself
 itsems->items
 itslef->itself
+itslev->itself
 itteration->iteration
 itterations->iterations
 iunior->junior
@@ -15119,8 +16341,8 @@ iwth->with
 jagid->jagged
 jagwar->jaguar
 jalusey->jealousy, jalousie,
-januar->january
-janurary->january
+januar->January
+janurary->January
 Januray->January
 japaneese->Japanese
 Japanes->Japanese
@@ -15173,11 +16395,17 @@ jumpt->jumped, jump,
 juristiction->jurisdiction
 juristictions->jurisdictions
 jus->just
-juse->just
+juse->just, juice, Jude, June,
 justfied->justified
 justication->justification
 justifed->justified
 justs->just
+juxt->just
+juxtification->justification
+juxtifications->justifications
+juxtified->justified
+juxtifies->justifies
+juxtifying->justifying
 kake->cake, take,
 kazakstan->kazakhstan
 keep-alives->keep-alive
@@ -15194,17 +16422,23 @@ keword->keyword
 kewword->keyword
 kewwords->keywords
 keybaord->keyboard
+keybaords->keyboards
+keyboaard->keyboard
+keyboaards->keyboards
 keyboad->keyboard
 keyboads->keyboards
+keybooard->keyboard
+keybooards->keyboards
 keybord->keyboard
 keybords->keyboards
+keybroad->keyboard
+keybroads->keyboards
 keyevente->keyevent
 keyords->keywords
 keyoutch->keytouch
 keyowrd->keyword
 keypair->key pair
 keypairs->key pairs
-keyserver->key server
 keyservers->key servers
 keystokes->keystrokes
 keyward->keyword
@@ -15319,6 +16553,7 @@ lates->later, latest,
 latets->latest
 lating->latin
 latitide->latitude
+latitue->latitude
 latitute->latitude
 latops->laptops
 latset->latest
@@ -15373,6 +16608,7 @@ leat->lead, leak, least, leaf,
 leathal->lethal
 leats->least
 leaveing->leaving
+leavong->leaving
 lefted->left
 legac->legacy
 legact->legacy
@@ -15589,6 +16825,7 @@ litte->little
 littel->little
 littel-endian->little-endian
 littele->little
+littelry->literally
 litteral->literal
 litterally->literally
 litterals->literals
@@ -15599,6 +16836,9 @@ liveing->living
 livel->level
 livetime->lifetime
 livley->lively
+lizens->license
+lizense->license
+lizensing->licensing
 lke->like
 lmits->limits
 loaader->loader
@@ -15611,7 +16851,29 @@ loactions->locations
 loadig->loading
 loadin->loading
 loadning->loading
+locae->locate
+locaes->locates
 locahost->localhost
+locaiing->locating
+locailty->locality
+locaing->locating
+locaion->location
+locaions->locations
+locaise->localise
+locaised->localised
+locaiser->localiser
+locaises->localises
+locaite->locate
+locaites->locates
+locaiting->locating
+locaition->location
+locaitions->locations
+locaiton->location
+locaitons->locations
+locaize->localize
+locaized->localized
+locaizer->localizer
+locaizes->localizes
 localation->location
 localed->located
 localtion->location
@@ -15646,9 +16908,10 @@ lonber->longer
 lond->long
 lonelyness->loneliness
 long-runnign->long-running
-longe->longer
+longe->longer, lounge,
 longers->longer
 longitudonal->longitudinal
+longitue->longitude
 longitute->longitude
 longst->longest
 longuer->longer
@@ -15661,19 +16924,20 @@ looop->loop
 loopup->lookup
 loosley->loosely
 loosly->loosely
-loosy->lossy
+loosy->lossy, lousy,
+losd->lost, loss, lose, load,
 losely->loosely
 losen->loosen
 losened->loosened
-losted->lost
-lotation->rotation
-lotharingen->lothringen
-lowd->load
+losted->listed, lost, lasted,
+lotation->rotation, flotation,
+lotharingen->Lothringen
+lowd->load, low, loud,
 lpatform->platform
-lsat->last
-lsit->list
-lsits->lists
-lukid->likud
+lsat->last, slat, sat,
+lsit->list, slit, sit,
+lsits->lists, slits, sits,
+lukid->lucid, Likud,
 luminose->luminous
 luminousity->luminosity
 lveo->love
@@ -15703,6 +16967,7 @@ madantory->mandatory
 madatory->mandatory
 maddness->madness
 magasine->magazine
+magent->magenta, magnet,
 magincian->magician
 magisine->magazine
 magizine->magazine
@@ -15824,8 +17089,10 @@ manouverability->maneuverability, manoeu
 manouverable->maneuverable, manoeuvrable,
 manouvers->maneuvers, manoeuvres,
 mantain->maintain
+mantainable->maintainable
 mantained->maintained
 mantainer->maintainer
+mantainers->maintainers
 mantaining->maintaining
 mantains->maintains
 mantanine->maintain
@@ -15929,6 +17196,8 @@ materails->materials
 materalists->materialist
 materiasl->materials, material,
 materil->material
+materilism->materialism
+materilize->materialize
 materils->materials
 materla->material
 materlas->materials
@@ -15957,6 +17226,7 @@ mathod->method
 matix->matrix
 matser->master
 matzch->match
+maube->maybe, mauve,
 mavrick->maverick
 maximim->maximum
 maximimum->maximum
@@ -15967,11 +17237,28 @@ maxium->maximum
 maxiumum->maximum
 maxosx->macosx
 maxumum->maximum
+maybee->maybe
 mayu->may
 mazilla->Mozilla
 mccarthyst->mccarthyist
+mchanic->mechanic
+mchanical->mechanical
+mchanically->mechanically
+mchanicals->mechanicals
 mchanics->mechanics
+mchanism->mechanism
+mchanisms->mechanisms
+mcroscope->microscope
+mcroscopes->microscopes
+mcroscopic->microscopic
+mcroscopies->microscopies
+mcroscopy->microscopy
 mdoel->model
+mdoeled->modeled
+mdoeling->modeling
+mdoelled->modelled
+mdoelling->modelling
+mdoels->models
 meachanism->mechanism
 meachanisms->mechanisms
 meachinism->mechanism
@@ -15990,6 +17277,7 @@ meaninless->meaningless
 meaninng->meaning
 mear->wear, mere, mare,
 mearly->merely, nearly,
+measurd->measured, measure,
 measuremenet->measurement
 measuremenets->measurements
 measurmenet->measurement
@@ -16020,6 +17308,7 @@ mechamisms->mechanisms
 mechananism->mechanism
 mechancial->mechanical
 mechandise->merchandise
+mechanis->mechanism
 mechansim->mechanism
 mechine->machine
 mechines->machines
@@ -16033,7 +17322,8 @@ medeival->medieval
 medevial->medieval
 medhod->method
 medhods->methods
-mediciney->mediciny
+mediciney->medicine, medicinal,
+mediciny->medicine, medicinal,
 medievel->medieval
 mediterainnean->mediterranean
 Mediteranean->Mediterranean
@@ -16132,9 +17422,9 @@ messges->messages
 messsage->message
 messsages->messages
 messure->measure
-messured->measurd
+messured->measured
 messurement->measurement
-messures->measure
+messures->measures
 messuring->measuring
 messurment->measurement
 mesure->measure
@@ -16146,6 +17436,7 @@ mesuring->measuring
 mesurment->measurement
 meta-attrubute->meta-attribute
 meta-attrubutes->meta-attributes
+meta-progamming->meta-programming
 metacharater->metacharacter
 metacharaters->metacharacters
 metalic->metallic
@@ -16155,7 +17446,9 @@ metalurgy->metallurgy
 metamorphysis->metamorphosis
 metapackge->metapackage
 metapackges->metapackages
+metaphore->metaphor
 metaphoricial->metaphorical
+metaprogamming->metaprogramming
 metatdata->metadata
 metdata->metadata
 meterial->material
@@ -16187,14 +17480,28 @@ mial->mail
 mices->mice
 Michagan->Michigan
 micorcode->microcode
+micorcodes->microcodes
 Micorsoft->Microsoft
+micoscope->microscope
+micoscopes->microscopes
+micoscopic->microscopic
+micoscopies->microscopies
 micoscopy->microscopy
 Micosoft->Microsoft
+micrcontroller->microcontroller
+micrcontrollers->microcontrollers
 Microfost->Microsoft
+microntroller->microcontroller
+microntrollers->microcontrollers
 micropone->microphone
+micropones->microphones
 microprocesspr->microprocessor
+microprocessprs->microprocessors
+microseond->microsecond
+microseonds->microseconds
 Microsft->Microsoft
 microship->microchip
+microships->microchips
 Microsof->Microsoft
 Microsofot->Microsoft
 Micrsft->Microsoft
@@ -16203,9 +17510,21 @@ midified->modified
 migrateable->migratable
 migt->might, midget,
 migth->might
+miinimisation->minimisation
+miinimise->minimise
+miinimised->minimised
+miinimises->minimises
+miinimising->minimising
+miinimization->minimization
+miinimize->minimize
+miinimized->minimized
+miinimizes->minimizes
+miinimizing->minimizing
+miinimum->minimum
 mikrosecond->microsecond
 mikroseconds->microseconds
 milage->mileage
+milages->mileages
 mileau->milieu
 milennia->millennia
 milennium->millennium
@@ -16223,15 +17542,20 @@ milisecond->millisecond
 miliseconds->milliseconds
 milisecons->milliseconds
 milivolts->millivolts
+milleneum->millennium
 millenia->millennia
 millenial->millennial
 millenialism->millennialism
+millenials->millennials
 millenium->millennium
 millepede->millipede
+milliescond->millisecond
 milliesconds->milliseconds
 millioniare->millionaire
+millioniares->millionaires
 millisencond->millisecond
 millisenconds->milliseconds
+milliseond->millisecond
 milliseonds->milliseconds
 millitant->militant
 millitary->military
@@ -16269,14 +17593,24 @@ MingGW->MinGW
 minimam->minimum
 minimial->minimal
 minimium->minimum
+minimsation->minimisation
+minimse->minimise
+minimsed->minimised
+minimses->minimises
+minimsing->minimising
 minimumm->minimum
 minimumn->minimum
 minimun->minimum
+minimzation->minimization
+minimze->minimize
+minimzed->minimized
+minimzes->minimizes
+minimzing->minimizing
 mininal->minimal
 mininum->minimum
 miniscule->minuscule
-miniscully->minusculy
-ministery->ministry
+miniscully->minusculely
+ministery->ministry, minister,
 miniture->miniature
 minium->minimum
 miniums->minimums
@@ -16293,9 +17627,14 @@ mintors->mentors, monitors,
 minum->minimum
 minumum->minimum
 minuscle->minuscule
+minusculy->minusculely, minuscule,
 minuts->minutes
 miplementation->implementation
 mirconesia->micronesia
+mircophone->microphone
+mircophones->microphones
+mircoscope->microscope
+mircoscopes->microscopes
 mircosoft->Microsoft
 mirgate->migrate
 mirgated->migrated
@@ -16335,6 +17674,7 @@ misintepret->misinterpret
 misintepreted->misinterpreted
 misinterprett->misinterpret
 misinterpretted->misinterpreted
+misisng->missing
 mismach->mismatch
 mismached->mismatched
 mismaches->mismatches
@@ -16397,8 +17737,22 @@ mmbers->members
 mmnemonic->mnemonic
 mnay->many
 mobify->modify
+mocrochip->microchip
+mocrochips->microchips
+mocrocode->microcode
+mocrocodes->microcodes
+mocrocontroller->microcontroller
+mocrocontrollers->microcontrollers
+mocrophone->microphone
+mocrophones->microphones
+mocroprocessor->microprocessor
+mocroprocessors->microprocessors
+mocrosecond->microsecond
+mocroseconds->microseconds
+Mocrosoft->Microsoft
 mocule->module
 mocules->modules
+moddel->model
 moddels->models
 modell->model
 moderm->modem
@@ -16410,9 +17764,42 @@ modesettting->modesetting
 modeul->module
 modeuls->modules
 modfel->model
+modfiable->modifiable
+modfication->modification
+modfications->modifications
+modfide->modified
+modfided->modified
+modfider->modifier
+modfiders->modifiers
+modfides->modifies
 modfied->modified
+modfieid->modified
+modfieir->modifier
+modfieirs->modifiers
+modfieis->modifies
+modfier->modifier
+modfiers->modifiers
 modfies->modifies
+modfifiable->modifiable
+modfification->modification
+modfifications->modifications
+modfified->modified
+modfifier->modifier
+modfifiers->modifiers
+modfifies->modifies
+modfify->modify
+modfifying->modifying
+modfiiable->modifiable
+modfiication->modification
+modfiications->modifications
+modfitied->modified
+modfitier->modifier
+modfitiers->modifiers
+modfities->modifies
+modfity->modify
+modfitying->modifying
 modfiy->modify
+modfiying->modifying
 modfy->modify
 modfying->modifying
 modications->modifications
@@ -16439,6 +17826,8 @@ modifiation->modification
 modifiations->modifications
 modificatioon->modification
 modifid->modified
+modifified->modified
+modifify->modify
 modifing->modifying
 modifiy->modify
 modifiyng->modifying
@@ -16494,7 +17883,7 @@ momomentarily->momentarily
 momomento->memento, moment,
 momomentos->mementos, moments,
 momoments->moments
-mone->mono, money,
+mone->mono, money, none,
 monestaries->monasteries
 monestary->monastery, monetary,
 monestic->monastic
@@ -16600,13 +17989,14 @@ mudering->murdering
 mudule->module
 mudules->modules
 muext->mutex
-muhammadan->muslim
 mulithread->multithread
 mulitpart->multipart
 mulitpath->multipath
 mulitple->multiple
 mulitplicative->multiplicative
 mulitplied->multiplied
+mulitplier->multiplier
+mulitpliers->multipliers
 multi-dimenional->multi-dimensional
 multi-dimenionsal->multi-dimensional
 multi-langual->multi-lingual
@@ -16629,8 +18019,10 @@ multilpe->multiple
 multipe->multiple
 multipes->multiples
 multipiler->multiplier
+multipilers->multipliers
 multipl->multiple, multiply,
 multipled->multiplied
+multipler->multiplier, multiple,
 multiplers->multipliers
 multipliciaton->multiplication
 multiplicites->multiplicities
@@ -16645,8 +18037,17 @@ multitute->multitude
 multivriate->multivariate
 multixsite->multisite
 multliple->multiple
+multliples->multiples
+multliplied->multiplied
+multliplier->multiplier
+multlipliers->multipliers
+multliplies->multiplies
+multliply->multiply
+multliplying->multiplying
 multple->multiple
 multplied->multiplied
+multplier->multiplier
+multpliers->multipliers
 multplies->multiplies
 multply->multiply
 multplying->multiplying
@@ -16671,6 +18072,7 @@ mutbale->mutable
 mutch->much
 mutches->matches
 mutecies->mutexes
+mutexs->mutexes
 muti->multi
 muticast->multicast
 mutices->mutexes
@@ -16686,10 +18088,17 @@ mutli->multi
 mutli-threaded->multi-threaded
 mutlipart->multipart
 mutliple->multiple
-mutlipler->multiplier
+mutlipler->multiplier, multiple,
+mutliples->multiples
+mutliplication->multiplication
 mutliplicites->multiplicities
+mutliplier->multiplier
+mutlipliers->multipliers
 mutliply->multiply
 mutully->mutually
+mutux->mutex
+mutuxes->mutexes
+mutuxs->mutexes
 muyst->must
 myabe->maybe
 mybe->maybe
@@ -16699,6 +18108,11 @@ myraid->myriad
 mysef->myself
 mysefl->myself
 mysekf->myself
+myselfe->myself
+myselfes->myself
+myselv->myself
+myselve->myself
+myselves->myself
 myslef->myself
 mysogynist->misogynist
 mysogyny->misogyny
@@ -16727,6 +18141,8 @@ nams->names
 nane->name
 nanosencond->nanosecond
 nanosenconds->nanoseconds
+nanoseond->nanosecond
+nanoseonds->nanoseconds
 Naploeon->Napoleon
 Napolean->Napoleon
 Napoleonian->Napoleonic
@@ -16743,6 +18159,10 @@ navagate->navigate
 navagating->navigating
 navagation->navigation
 navagitation->navigation
+nax->max, nad,
+naxima->maxima
+naximal->maximal
+naximum->maximum
 Nazereth->Nazareth
 nclude->include
 nd->and, 2nd,
@@ -16782,6 +18202,7 @@ necessery->necessary
 necessesary->necessary
 necessiate->necessitate
 nechanism->mechanism
+necssary->necessary
 ned->need
 nedd->need
 nedded->needed
@@ -16789,11 +18210,17 @@ neded->needed
 nedia->media
 nedium->medium
 nediums->mediums
+nedle->needle
+nedles->needles, needless,
+nedless->needless, needles,
 neede->needed, need,
 needeed->needed
 neeed->need
 neeeded->needed
 neeeding->needing
+neeedle->needle
+neeedles->needles, needless,
+neeedless->needless, needles,
 neeedn't->needn't
 neeeds->needs
 nees->needs
@@ -17266,11 +18693,15 @@ nighboring->neighboring
 nightfa;;->nightfall
 nightime->nighttime
 nimutes->minutes
+nin->inn, min, bin, nine,
 nineth->ninth
+ninima->minima
+ninimal->minimal
+ninimum->minimum
 ninjs->ninja
 ninteenth->nineteenth
-ninties->1990s
-ninty->ninety
+ninties->nineties, 1990s,
+ninty->ninety, minty,
 nither->neither
 nknown->unknown
 nkow->know
@@ -17350,6 +18781,8 @@ non-negoziable->non-negotiable
 non-negoziated->non-negotiated
 non-priviliged->non-privileged
 non-referenced-counted->non-reference-counted
+non-replacable->non-replaceable
+non-replacalbe->non-replaceable
 non-reproducable->non-reproducible
 non-seperable->non-separable
 non-trasparent->non-transparent
@@ -17440,6 +18873,7 @@ notse->notes, note,
 nott->not
 notwhithstanding->notwithstanding
 noveau->nouveau
+Novemer->November
 Novermber->November
 nowadys->nowadays
 nowdays->nowadays
@@ -17470,10 +18904,14 @@ numebrs->numbers
 numer->number
 numeraotr->numerator
 numerbering->numbering
-numerial->numeral
+numerial->numeral, numerical,
 numering->numbering
 numers->numbers
 nummbers->numbers
+numnber->number
+numnbered->numbered
+numnbering->numbering
+numnbers->numbers
 numner->number
 numners->numbers
 numver->number
@@ -17509,9 +18947,9 @@ objet->object
 objetc->object
 objetcs->objects
 objets->objects
-objext->object
 objtain->obtain
 objtained->obtained
+objtains->obtains
 objump->objdump
 oblitque->oblique
 obnject->object
@@ -17532,10 +18970,15 @@ obstacal->obstacle
 obstancles->obstacles
 obstruced->obstructed
 obsure->obscure
+obtaien->obtain, obtained,
 obtaiend->obtained
+obtaiens->obtains
 obtaion->obtain
+obtaioned->obtained
+obtaions->obtains
 obtrain->obtain
 obtrained->obtained
+obtrains->obtains
 obusing->abusing
 obvisious->obvious
 obvisous->obvious
@@ -17613,7 +19056,6 @@ ocurrance->occurrence
 ocurred->occurred
 ocurrence->occurrence
 ocurrences->occurrences
-od->of
 oder->order, odor,
 odly->oddly
 oen->one
@@ -17655,11 +19097,18 @@ ofrom->from
 ofsetted->offsetted
 oftenly->often
 ofthe->of the
+ofthen->often, of then,
 oging->going, ogling,
 oherwise->otherwise
 ohter->other
 ohters->others
 ohterwise->otherwise
+oigin->origin
+oiginal->original
+oiginally->originally
+oiginals->originals
+oiginating->originating
+oigins->origins
 oints->points, pints,
 ois->is
 ojbect->object
@@ -17713,6 +19162,14 @@ ons->owns
 onself->oneself
 onservation->conservation, observation,
 ontain->contain
+ontained->contained
+ontainer->container
+ontainers->containers
+ontainging->containing
+ontaining->containing
+ontainor->container
+ontainors->containers
+ontains->contains
 onthe->on the
 ontrolled->controlled
 ony->only
@@ -17784,6 +19241,8 @@ openess->openness
 openin->opening
 openned->opened
 openning->opening
+openscource->open-source, open source, opensource,
+openscourced->open-sourced, open sourced, opensourced,
 operaand->operand
 operaands->operands
 operaion->operation
@@ -17817,6 +19276,7 @@ opne->open
 opnegroup->opengroup
 opnssl->openssl
 oponent->opponent
+oportions->options, apportions,
 oportunity->opportunity
 opose->oppose
 oposed->opposed
@@ -17850,6 +19310,8 @@ opreations->operations
 opression->oppression
 opressive->oppressive
 optain->obtain
+optained->obtained
+optains->obtains
 optaionl->optional
 opten->often, open,
 optening->opening
@@ -17975,6 +19437,8 @@ origially->originally
 origianal->original
 origianally->originally
 origianaly->originally
+origianl->original
+origianls->originals
 origigin->origin
 origiginal->original
 origiginally->originally
@@ -18019,11 +19483,14 @@ osciallator->oscillator
 oscilate->oscillate
 oscilated->oscillated
 oscilating->oscillating
+oscilator->oscillator
 osffset->offset
 osffsets->offsets
 osffsetting->offsetting
 osicllations->oscillations
 ot->to, of, or,
+otain->obtain
+otained->obtained
 otains->obtains
 otehr->other
 otehrwice->otherwise
@@ -18090,8 +19557,11 @@ ouputarea->outputarea
 ouputs->outputs
 ouputted->outputted
 ouputting->outputting
+ourselfe->ourselves, ourself,
+ourselfes->ourselves
 ourselfs->ourselves
-ourselve->ourselves
+ourselv->ourself, ourselves,
+ourselve->ourself, ourselves,
 ourselvs->ourselves
 ouside->outside
 oustanding->outstanding
@@ -18104,12 +19574,16 @@ outllook->outlook
 outoign->outgoing
 outout->output
 outpupt->output
+outpus->output, outputs,
+outpust->output, outputs,
+outpusts->outputs
 outputed->outputted
 outputing->outputting
 outputof->output-of
 outrside->outside, other side,
 outselves->ourselves
 outter->outer
+outtermost->outermost
 outupt->output
 outupts->outputs
 outuput->output
@@ -18248,7 +19722,7 @@ pacakge->package
 pacakges->packages
 pacakging->packaging
 paceholder->placeholder
-pach->patch
+pach->patch, path,
 pachage->package
 paches->patches
 pacht->patch
@@ -18311,7 +19785,7 @@ Palistinians->Palestinians
 pallete->palette
 pallette->palette
 palletted->paletted
-paln->plan
+paln->plan, pain, palm,
 paltette->palette
 paltform->platform
 pamflet->pamphlet
@@ -18439,11 +19913,13 @@ paritition->partition
 parititions->partitions
 parituclar->particular
 parliment->parliament
+parm->param, pram, Parma,
 parmaeter->parameter
 parmaeters->parameters
 parmaters->parameters
 parmeter->parameter
 parmeters->parameters
+parms->params, prams,
 parnoia->paranoia
 parrakeets->parakeets
 parralel->parallel
@@ -18482,18 +19958,30 @@ particulaly->particularly
 particularily->particularly
 particulary->particularly
 partifular->particular
+partiiton->partition
+partiitoned->partitioned
+partiitoning->partitioning
 partiitons->partitions
 partion->partition, portion,
 partioned->partitioned
-partioning->partitioning
-partions->partitions
+partioning->partitioning, portioning,
+partions->partitions, portions,
+partirion->partition
+partirioned->partitioned
+partirioning->partitioning
+partirions->partitions
 partision->partition
+partisioned->partitioned
+partisioning->partitioning
+partisions->partitions
 partitial->partial
 partiticular->particular
 partitioing->partitioning
 partitiones->partitions
 partiton->partition
+partitoned->partitioned
 partitoning->partitioning
+partitons->partitions
 pary->party, parry,
 pase->pass, pace, parse,
 pased->passed
@@ -18513,11 +20001,17 @@ passthrought->passthrough
 passthruogh->passthrough
 passtime->pastime
 passtrough->passthrough
+passwird->password
+passwirds->passwords
 passwrod->password
+passwrods->passwords
 pasteing->pasting
 pasttime->pastime
 pastural->pastoral
 pasword->password
+paswords->passwords
+patchs->patches, paths,
+patcket->packet
 patckets->packets
 patern->pattern
 paterns->patterns
@@ -18571,12 +20065,12 @@ pege->page
 peice->piece
 peicemeal->piecemeal
 peices->pieces
-peicewise->piecewise
+peicewise->piecewise, piece wise,
 peirod->period
 peirodical->periodical
 peirodicals->periodicals
 peirods->periods
-Peloponnes->Peloponnesus
+Peloponnes->Peloponnese, Peloponnesus,
 penalities->penalties
 penality->penalty
 penatly->penalty
@@ -18666,6 +20160,7 @@ perfoms->performs
 perfoom->perfume, perform,
 perforemd->performed
 performace->performance
+performaed->performed
 performamce->performance
 performane->performance
 performe->perform, performed,
@@ -18683,6 +20178,8 @@ perhasp->perhaps
 perheaps->perhaps
 perhpas->perhaps
 peridic->periodic
+perimetre->perimeter
+perimetres->perimeters
 periode->period
 periodicaly->periodically
 periodioc->periodic
@@ -18718,7 +20215,6 @@ permuation->permutation
 permuations->permutations
 permutaion->permutation
 permutaions->permutations
-permuter->permutor
 peroendicular->perpendicular
 perogative->prerogative
 peroid->period
@@ -18737,7 +20233,11 @@ persan->person
 persepctive->perspective
 persepective->perspective
 persepectives->perspectives
+perserve->preserve
+perserved->preserved
 perserverance->perseverance
+perserves->preserves
+perserving->preserving
 perseverence->perseverance
 persisit->persist
 persisited->persisted
@@ -18762,8 +20262,19 @@ persuing->pursuing
 persuit->pursuit
 persuits->pursuits
 persumably->presumably
+pertrub->perturb
+pertrubation->perturbation
+pertrubations->perturbations
+pertrubing->perturbing
+pertub->perturb
+pertubate->perturb
+pertubated->perturbed
+pertubates->perturbs
 pertubation->perturbation
 pertubations->perturbations
+pertubing->perturbing
+perturbate->perturb
+perturbates->perturbs
 pervious->previous
 perviously->previously
 pessiary->pessary
@@ -18816,6 +20327,11 @@ phyton->python
 phy_interace->phy_interface
 piblisher->publisher
 pich->pitch
+picoseond->picosecond
+picoseonds->picoseconds
+pieceweise->piecewise, piece wise,
+piecewiese->piecewise, piece wise,
+piecwise->piecewise, piece wise,
 pilgrimmage->pilgrimage
 pilgrimmages->pilgrimages
 pimxap->pixmap
@@ -18827,6 +20343,19 @@ piont->point
 pionter->pointer
 pionts->points
 piority->priority
+pipeine->pipeline
+pipeines->pipelines
+pipelin->pipeline
+pipelinining->pipelining
+pipelins->pipelines
+pipepline->pipeline
+pipeplines->pipelines
+pipiline->pipeline
+pipilines->pipelines
+pipleine->pipeline
+pipleines->pipelines
+pipleline->pipeline
+piplelines->pipelines
 pitmap->pixmap, bitmap,
 pitty->pity
 pivott->pivot
@@ -18881,6 +20410,7 @@ plattforms->platforms
 plausability->plausibility
 plausable->plausible
 playble->playable
+playfull->playful, playfully,
 playge->plague
 playgerise->plagiarise
 playgerize->plagiarize
@@ -18904,7 +20434,7 @@ plesant->pleasant
 plese->please
 plesently->pleasantly
 plesing->pleasing, blessing,
-plian->plain
+plian->plain, pliant,
 pllatforms->platforms
 ploting->plotting
 plugable->pluggable
@@ -19064,7 +20594,7 @@ portioon->portion
 portrail->portrayal, portrait,
 portraing->portraying
 portugese->Portuguese
-portuguease->portuguese
+portuguease->Portuguese
 portugues->Portuguese
 posative->positive
 posatives->positives
@@ -19080,6 +20610,8 @@ posibilities->possibilities
 posibility->possibility
 posibilties->possibilities
 posible->possible
+posiblity->possibility
+posibly->possibly
 posiitive->positive
 posiitives->positives
 posiitivity->positivity
@@ -19100,10 +20632,10 @@ positivies->positives
 positoin->position
 positoined->positioned
 positoins->positions
-positon->position
+positon->position, positron,
 positoned->positioned
 positoning->positioning
-positons->positions
+positons->positions, positrons,
 positve->positive
 positves->positives
 POSIX-complient->POSIX-compliant
@@ -19112,6 +20644,7 @@ posponed->postponed
 posption->position
 possabilites->possibilities
 possabilities->possibilities
+possability->possibility
 possabilties->possibilities
 possabily->possibly
 possable->possible
@@ -19165,6 +20698,7 @@ postiional->positional
 postiive->positive
 postincremend->postincrement
 postion->position
+postioned->positioned
 postions->positions
 postition->position
 postive->positive
@@ -19275,9 +20809,9 @@ preced->precede
 precedessor->predecessor
 preceds->precedes
 preceed->precede, proceed,
-preceeded->preceded
-preceeding->preceding
-preceeds->precedes
+preceeded->preceded, proceeded,
+preceeding->preceding, proceeding,
+preceeds->precedes, proceeds,
 preceision->precision
 precence->presence
 precendance->precedence
@@ -19297,6 +20831,8 @@ precenences->preferences
 precense->presence
 precent->percent, prescient,
 precentage->percentage
+precentile->percentile
+precentiles->percentiles
 precessor->predecessor, processor,
 precice->precise
 precicion->precision
@@ -19421,6 +20957,13 @@ prersistent->persistent
 presance->presence
 prescrition->prescription
 prescritions->prescriptions
+presearvation->preservation
+presearvations->preservations
+presearve->preserve
+presearved->preserved
+presearver->preserver
+presearves->preserves
+presearving->preserving
 presedential->presidential
 presenece->presence
 presener->presenter
@@ -19466,6 +21009,7 @@ prestigeous->prestigious
 prestigous->prestigious
 presuambly->presumably
 presumabely->presumably
+presumebly->presumably
 presumely->presumably
 presumibly->presumably
 pretection->protection
@@ -19490,6 +21034,7 @@ previosuly->previously
 previou->previous
 previouly->previously
 previouse->previous
+previousl->previously
 previsouly->previously
 previuous->previous
 previus->previous
@@ -19525,6 +21070,8 @@ primitve->primitive
 primitves->primitives
 primive->primitive
 primordal->primordial
+princeple->principle
+princeples->principles
 principaly->principality
 principial->principal
 principlaity->principality
@@ -19583,6 +21130,7 @@ proable->probable
 proably->probably
 probabaly->probably
 probabilaty->probability
+probabilites->probabilities
 probabilty->probability
 probabily->probability, probably,
 probablistic->probabilistic
@@ -19610,16 +21158,21 @@ proberty->property, properly,
 problably->probably
 problamatic->problematic
 proble->probe
+probleme->problem
+problemes->problems
 problimatic->problematic
 problme->problem
 problmes->problems
 probly->probably
 procceed->proceed
+proccesor->processor
 proccesors->processors
 proccess->process
 proccessed->processed
 proccesses->processes
 proccessing->processing
+proccessor->processor
+proccessors->processors
 procecure->procedure
 procecures->procedures
 procede->proceed, precede,
@@ -19628,6 +21181,8 @@ procedes->proceeds, precedes,
 procedger->procedure
 proceding->proceeding, preceding,
 procedings->proceedings
+procedre->procedure
+procedres->procedures
 proceedure->procedure
 proceedures->procedures
 proceeed->proceed
@@ -19647,7 +21202,6 @@ proceses->processes
 proceshandler->processhandler
 procesing->processing
 procesor->processor
-process'->process's
 processeed->processed
 processees->processes
 processer->processor
@@ -19710,8 +21264,68 @@ proffesor->professor
 proffessor->professor
 profilic->prolific
 profissional->professional
+progagate->propagate
+progagated->propagated
+progagates->propagates
+progagating->propagating
+progagation->propagation
+progagations->propagations
+progagator->propagator
+progagators->propagators
 progam->program
+progamability->programmability
+progamable->programmable
+progamatic->programmatic
+progamatically->programmatically
+progamed->programmed
+progamer->programmer
+progamers->programmers
+progaming->programming
+progamm->program
+progammability->programmability
+progammable->programmable
+progammatic->programmatic
+progammatically->programmatically
+progammed->programmed
+progammer->programmer
+progammers->programmers
+progamming->programming
+progamms->programs
 progams->programs
+progapate->propagate
+progapated->propagated
+progapates->propagates
+progapating->propagating
+progapation->propagation
+progapations->propagations
+progapator->propagator
+progapators->propagators
+progaramm->program
+progarammability->programmability
+progarammable->programmable
+progarammatic->programmatic
+progarammatically->programmatically
+progarammed->programmed
+progarammer->programmer
+progarammers->programmers
+progaramming->programming
+progaramms->programs
+progarm->program
+progarmability->programmability
+progarmable->programmable
+progarmatic->programmatic
+progarmatically->programmatically
+progarmed->programmed
+progarmer->programmer
+progarmers->programmers
+progarming->programming
+progarms->programs
+progate->propagate
+progated->propagated
+progates->propagates
+progating->propagating
+progation->propagation
+progations->propagations
 progess->progress
 progessbar->progressbar
 progessed->progressed
@@ -19724,12 +21338,15 @@ programable->programmable
 programatic->programmatic
 programatically->programmatically
 programattically->programmatically
+programd->programmed
+programed->programmed
 programemer->programmer
 programemers->programmers
 programers->programmers
 programing->programming
-programm->program
+programm->program, programme,
 programmaticaly->programmatically
+programmd->programmed, programme,
 programmend->programmed
 programmetically->programmatically
 programmical->programmatical
@@ -19825,6 +21442,8 @@ prooxy->proxy
 propably->probably
 propage->propagate
 propatagion->propagation
+propator->propagator
+propators->propagators
 propbably->probably
 propely->properly
 propeoperties->properties
@@ -19880,6 +21499,14 @@ propperly->properly
 proprietory->proprietary
 proproable->probable
 proproably->probably
+proprogate->propagate
+proprogated->propagated
+proprogates->propagates
+proprogating->propagating
+proprogation->propagation
+proprogations->propagations
+proprogator->propagator
+proprogators->propagators
 proproties->properties
 proprotion->proportion
 proprotional->proportional
@@ -19899,8 +21526,12 @@ protable->portable
 protaganist->protagonist
 protaganists->protagonists
 protcol->protocol
+protcool->protocol
+protcools->protocols
 protcted->protected
 protecion->protection
+protecte->protected, protect,
+protectiv->protective
 protedcted->protected
 protential->potential
 protext->protect
@@ -19955,6 +21586,12 @@ provsioning->provisioning
 proximty->proximity
 prozess->process
 prpeparations->preparations
+prpose->propose
+prposed->proposed
+prposer->proposer
+prposers->proposers
+prposes->proposes
+prposiing->proposing
 prrcision->precision
 prrottypes->prototypes
 prtinf->printf
@@ -19988,30 +21625,53 @@ psyhic->psychic
 ptd->pdf
 ptherad->pthread
 ptherads->pthreads
+pthon->python
 pthred->pthread
 pthreds->pthreads
 ptorions->portions
 ptrss->press
+pubilsh->publish
+pubilshed->published
 pubilsher->publisher
+pubilshers->publishers
+pubilshing->publishing
+pubish->publish
+pubished->published
 pubisher->publisher
-publc->public
+pubishers->publishers
+pubishing->publishing
+publc->public, pubic,
 publcation->publication
 publcise->publicise
 publcize->publicize
 publiaher->publisher
 publically->publicly
 publicaly->publicly
+publich->publish, public,
+publiched->published
 publicher->publisher
+publichers->publishers
+publiches->publishes
+publiching->publishing
+publihsed->published
 publihser->publisher
+publised->published
+publisehd->published
 publisehr->publisher
+publisehrs->publishers
 publiser->publisher
+publisers->publishers
+publisged->published
 publisger->publisher
+publisgers->publishers
 publishd->published
 publisheed->published
 publisherr->publisher
 publishher->publisher
 publishor->publisher
+publishr->publisher
 publishre->publisher
+publishrs->publishers
 publissher->publisher
 publlisher->publisher
 publsh->publish
@@ -20082,6 +21742,7 @@ pythjon->python
 pytnon->python
 pytohn->python
 pyton->python
+pytyon->python
 qeueue->queue
 qith->with
 qoute->quote
@@ -20151,11 +21812,18 @@ qutie->quite, quiet,
 rabinnical->rabbinical
 racaus->raucous
 ractise->practise
+radation->radiation
 rade->read, raid,
 radiactive->radioactive
+radiaton->radiation
 radify->ratify
 radiobuttion->radiobutton
 radis->radix
+rady->ready
+raed->read
+raeding->reading
+raeds->reads
+raedy->ready
 raelly->really
 raisedd->raised
 raison->reason, raisin,
@@ -20436,6 +22104,7 @@ reacahable->reachable
 reacahble->reachable
 reaccurring->recurring
 reaceive->receive
+reacheable->reachable
 reacher->richer
 reachs->reaches
 reacing->reaching
@@ -20453,6 +22122,7 @@ readibility->readability
 readible->readable
 readius->radius
 readl-only->read-only
+readly->readily, ready,
 readmition->readmission
 readnig->reading
 readning->reading
@@ -20472,6 +22142,19 @@ reall->real, really,
 realling->really
 reallize->realize
 reallllly->really
+reallocae->reallocate
+reallocaes->reallocates
+reallocaiing->reallocating
+reallocaing->reallocating
+reallocaion->reallocation
+reallocaions->reallocations
+reallocaite->reallocate
+reallocaites->reallocates
+reallocaiting->reallocating
+reallocaition->reallocation
+reallocaitions->reallocations
+reallocaiton->reallocation
+reallocaitons->reallocations
 realsitic->realistic
 realted->related
 realtion->relation, reaction,
@@ -20548,8 +22231,11 @@ reasonnable->reasonable
 reasonnably->reasonably
 reassocition->reassociation
 reasssign->reassign
+reasy->ready, easy,
 reatime->realtime
 reattachement->reattachment
+reay->ready, really, ray,
+reayd->ready, read,
 rebiulding->rebuilding
 rebllions->rebellions
 reboto->reboot
@@ -20634,6 +22320,7 @@ recenly->recently
 recepient->recipient
 recepients->recipients
 recepion->reception
+recepit->recipe, receipt,
 receve->receive
 receved->received
 receves->receives
@@ -20693,9 +22380,12 @@ recomends->recommends
 recommad->recommend
 recommaded->recommended
 recommand->recommend
+recommandation->recommendation
 recommanded->recommended
+recommanding->recommending
 recommands->recommends
 recommd->recommend
+recommdation->recommendation
 recommded->recommended
 recommdend->recommend
 recommdended->recommended
@@ -20790,8 +22480,10 @@ recontructs->reconstructs
 recordproducer->record producer
 recored->recorded
 recoriding->recording
-recource->resource
+recource->resource, recourse,
+recourced->resourced
 recources->resources
+recourcing->resourcing
 recquired->required
 recrational->recreational
 recreateation->recreation
@@ -20849,14 +22541,26 @@ redircet->redirect
 redirectd->redirected
 redirectrion->redirection
 redisign->redesign
+redistirbute->redistribute
+redistirbuted->redistributed
+redistirbutes->redistributes
+redistirbuting->redistributing
+redistirbution->redistribution
 redliens->redlines
 rednerer->renderer
 redonly->readonly
+redudancy->redundancy
+redudant->redundant
+redunancy->redundancy
 redunant->redundant
 redundacy->redundancy
+redundat->redundant
+redundency->redundancy
 redundent->redundant
+reduntancy->redundancy
 reduntant->redundant
-reduse->reduce
+reduse->reduce, reuse,
+redy->ready, red,
 reedeming->redeeming
 reelation->relation
 reelease->release
@@ -20984,6 +22688,8 @@ refrormatting->reformatting
 refure->refuse
 refures->refuses
 refusla->refusal
+regalar->regular
+regalars->regulars
 regardes->regards
 regardles->regardless
 regardlesss->regardless
@@ -20998,6 +22704,11 @@ regeister->register
 regeistered->registered
 regeistration->registration
 regenarated->regenerated
+regenrated->regenerated
+regenratet->regenerated
+regenrating->regenerating
+regenration->regeneration
+regenrative->regenerative
 regession->regression
 regestered->registered
 regidstered->registered
@@ -21015,6 +22726,7 @@ registeres->registers
 registeresd->registered
 registerred->registered
 registert->registered
+registery->registry
 registes->registers
 registing->registering
 registors->registers
@@ -21059,15 +22771,35 @@ reguarlize->regularize
 reguarlizer->regularizer
 reguarly->regularly
 reguator->regulator
+regulaer->regular
 regulaion->regulation
+regulamentation->regulation
 regulamentations->regulations
 regulaotrs->regulators
 regulaotry->regulatory
 regularily->regularly
-regulariry->regulary
+regulariry->regularly
+regularlisation->regularisation
+regularlise->regularise
+regularlised->regularised
+regularliser->regulariser
+regularlises->regularises
+regularlising->regularising
+regularlization->regularization
+regularlize->regularize
+regularlized->regularized
+regularlizer->regularizer
+regularlizes->regularizes
+regularlizing->regularizing
+regularlly->regularly
+regulary->regular, regularly,
+regulax->regular
+reguler->regular
+regulr->regular
 regultor->regulator
 regultors->regulators
-regurlarly->regulary
+regultory->regulatory
+regurlarly->regularly
 reguster->register
 rehersal->rehearsal
 rehersing->rehearsing
@@ -21108,6 +22840,7 @@ rekursed->recursed
 rekursion->recursion
 rekursive->recursive
 relaative->relative
+relady->ready
 relaease->release
 relaese->release
 relaesed->released
@@ -21183,6 +22916,19 @@ relized->realised, realized,
 rellocates->reallocates, relocates,
 relly->really
 reloade->reload
+relocae->relocate
+relocaes->relocates
+relocaiing->relocating
+relocaing->relocating
+relocaion->relocation
+relocaions->relocations
+relocaite->relocate
+relocaites->relocates
+relocaiting->relocating
+relocaition->relocation
+relocaitions->relocations
+relocaiton->relocation
+relocaitons->relocations
 relocateable->relocatable
 reloccate->relocate
 reloccated->relocated
@@ -21508,7 +23254,10 @@ reorginised->reorganised
 reorginized->reorganized
 reosnable->reasonable
 reosne->reason
+reosurce->resource
+reosurced->resourced
 reosurces->resources
+reosurcing->resourcing
 reounded->rounded
 reouted->routed, rerouted,
 repace->replace
@@ -21541,10 +23290,17 @@ repeition->repetition
 repentence->repentance
 repentent->repentant
 reperesent->represent
+reperesentation->representation
+reperesentational->representational
+reperesentations->representations
+reperesented->represented
+reperesenting->representing
+reperesents->represents
 repersentation->representation
 repertoir->repertoire
 repesent->represent
 repesentation->representation
+repesentational->representational
 repesented->represented
 repesenting->representing
 repesents->represents
@@ -21558,17 +23314,50 @@ repetions->repetitions
 repetive->repetitive
 repid->rapid
 repitition->repetition
+replaca->replica, replace,
+replacability->replaceability
 replacable->replicable, replaceable,
+replacables->replaceables
+replacacing->replacing
+replacaiblity->replaceability, replicability,
+replacalbe->replaceable
+replacalbes->replaceables
+replacament->replacement
+replacaments->replacements
+replacas->replicas, replaces,
+replacate->replicate
+replacated->replicated
+replacates->replicates
+replacating->replicating
+replacation->replication
+replacd->replaced
 replaceemnt->replacement
 replaceemnts->replacements
 replacemenet->replacement
 replacmenet->replacement
 replacment->replacement
 replacments->replacements
+replacong->replacing
+replacte->replace, replicate,
+replacted->replaced, replicated,
+replactes->replaces, replicates,
+replacting->replacing, replicating,
 replaint->repaint
 replcace->replace
 replcaced->replaced
 replcaof->replicaof
+replicae->replicate
+replicaes->replicates
+replicaiing->replicating
+replicaion->replication
+replicaions->replications
+replicaite->replicate
+replicaites->replicates
+replicaiting->replicating
+replicaition->replication
+replicaitions->replications
+replicaiton->replication
+replicaitons->replications
 repling->replying
 replys->replies
 reponding->responding
@@ -21594,6 +23383,8 @@ repostiory->repository
 repote->report, remote,
 repport->report
 repraesentation->representation
+repraesentational->representational
+repraesentations->representations
 reprecussion->repercussion
 reprecussions->repercussions
 repreesnt->represent
@@ -21601,15 +23392,22 @@ repreesnted->represented
 repreesnts->represents
 reprensent->represent
 reprensentation->representation
+reprensentational->representational
+reprensentations->representations
 reprepresents->represents
 represantation->representation
+represantational->representational
 represantations->representations
 represantative->representative
 represenatation->representation
+represenatational->representational
+represenatations->representations
 represenation->representation
+represenational->representational
 represenations->representations
 represend->represent
 representaion->representation
+representaional->representational
 representaions->representations
 representaiton->representation
 representated->represented
@@ -21619,6 +23417,7 @@ represente->represents, represented,
 representiative->representative
 representive->representative
 representives->representatives
+represetation->representation
 represnet->represent
 represneted->represented
 represneting->representing
@@ -21760,11 +23559,19 @@ resaurant->restaurant
 resaurants->restaurants
 rescaned->rescanned
 rescource->resource
+rescourced->resourced
 rescources->resources
+rescourcing->resourcing
 rescrition->restriction
 rescritions->restrictions
 reseach->research
 reseached->researched
+researvation->reservation
+researvations->reservations
+researve->reserve
+researved->reserved
+researves->reserves
+researving->reserving
 reselction->reselection
 resembelance->resemblance
 resembes->resembles
@@ -21808,27 +23615,42 @@ resluts->results
 resoect->respect
 resoective->respective
 resoiurce->resource
+resoiurced->resourced
+resoiurces->resources
+resoiurcing->resourcing
 resoltion->resolution
 resoluitons->resolutions
 resoluton->resolution
+resolvinf->resolving
 reson->reason
 resonable->reasonable
 resons->reasons
 resonse->response
 resonses->responses
 resoource->resource
+resoourced->resourced
 resoources->resources
+resoourcing->resourcing
 resopnse->response
 resopnses->responses
 resorce->resource
+resorced->resourced
 resorces->resources
+resorcing->resourcing
 resore->restore
+resoruce->resource
+resoruced->resourced
+resoruces->resources
+resorucing->resourcing
 resouce->resource
+resouced->resourced
 resouces->resources
-resoultion->resolutions
+resoucing->resourcing
+resoultion->resolution
 resoultions->resolutions
 resourceype->resourcetype
 resoure->resource
+resoured->resourced
 resoures->resources
 resoution->resolution
 resoves->resolves
@@ -21867,6 +23689,7 @@ respose->response
 resposes->responses
 resposibility->responsibility
 resposible->responsible
+resposiblity->responsibility
 respositories->repositories
 respository->repository
 resposive->responsive
@@ -21875,6 +23698,9 @@ resposne->response
 resposnes->responses
 resquest->request
 resrouce->resource
+resrouced->resourced
+resrouces->resources
+resroucing->resourcing
 resrved->reserved
 ressapee->recipe
 ressemblance->resemblance
@@ -21887,7 +23713,9 @@ ressetting->resetting
 ressize->resize
 ressizes->resizes
 ressource->resource
+ressourced->resourced
 ressources->resources
+ressourcing->resourcing
 resssurecting->resurrecting
 ressult->result
 ressurect->resurrect
@@ -21916,6 +23744,9 @@ restoding->restoring
 restoiring->restoring
 restor->restore
 restorated->restored
+restoreable->restorable
+restoreble->restorable
+restoreing->restoring
 restors->restores
 restouration->restoration
 restraunt->restraint, restaurant,
@@ -21924,6 +23755,7 @@ restrcuture->restructure
 restriced->restricted
 restroing->restoring
 restuarant->restaurant
+restuarants->restaurants
 restucturing->restructuring
 resturant->restaurant
 resturants->restaurants
@@ -21947,7 +23779,13 @@ resumbmitting->resubmitting
 resumitted->resubmitted
 resumt->resume
 resuorce->resource
+resuorced->resourced
+resuorces->resources
+resuorcing->resourcing
 resurce->resource
+resurced->resourced
+resurces->resources
+resurcing->resourcing
 resurecting->resurrecting
 resurse->recurse, resource,
 resursive->recursive, resourceful,
@@ -21984,14 +23822,32 @@ retquireseek->requireseek
 retquiresgpos->requiresgpos
 retquiresgsub->requiresgsub
 retquiressl->requiressl
+retranser->retransfer
+retransferd->retransferred
+retransfered->retransferred
+retransfering->retransferring
+retransferrd->retransferred
+retransfert->retransfer, retransferred,
 retransmited->retransmitted
 retransmition->retransmission
+retreevable->retrievable
+retreeval->retrieval
+retreeve->retrieve
+retreeved->retrieved
+retreeves->retrieves
+retreeving->retrieving
 retreivable->retrievable
 retreival->retrieval
 retreive->retrieve
 retreived->retrieved
 retreives->retrieves
 retreiving->retrieving
+retrevable->retrievable
+retreval->retrieval
+retreve->retrieve
+retreved->retrieved
+retreves->retrieves
+retreving->retrieving
 retrict->restrict
 retricted->restricted
 retriebe->retrieve
@@ -21999,7 +23855,7 @@ retriece->retrieve
 retrieces->retrieves
 retriev->retrieve
 retrieveds->retrieved
-retrival->retrieval
+retrival->retrieval, retrial,
 retrive->retrieve
 retrived->retrieved
 retrives->retrieves
@@ -22031,6 +23887,7 @@ returnning->returning
 returs->returns
 retursn->returns
 retutning->returning
+retyring->retrying
 reudce->reduce
 reudced->reduced
 reudces->reduces
@@ -22171,6 +24028,12 @@ rococco->rococo
 rocord->record
 roduce->reduce, produce,
 roduceer->producer
+roigin->origin
+roiginal->original
+roiginally->originally
+roiginals->originals
+roiginating->originating
+roigins->origins
 roomate->roommate
 ropeat->repeat
 rorated->rotated
@@ -22183,10 +24046,10 @@ rotaitons->rotations
 rotat->rotate
 rotataion->rotation
 rotataions->rotations
-rotatd->rotated
-rotatio->rotation
-rotatios->rotations
-rotats->rotates
+rotatd->rotated, rotate,
+rotatio->rotation, ratio,
+rotatios->rotations, ratios,
+rotats->rotates, rotate,
 rouding->rounding
 roughtly->roughly
 rougly->roughly
@@ -22204,18 +24067,23 @@ rountriped->roundtripped, round-tripped,
 rountriping->roundtripping, round-tripping, round tripping,
 rountripped->roundtripped, round-tripped, round tripped,
 rountripping->roundtripping, round-tripping, round tripping,
-routet->routed
+routet->routed, route, router,
+routin->routine, routing,
 routins->routines
 rovide->provide
 rovided->provided
 rovider->provider
 rovides->provides
 roviding->providing
-rqeuests->requests
-rquest->request
+rqeuest->request, quest,
+rqeuested->requested
+rqeuesting->requesting
+rqeuests->requests, quests,
+rquest->request, quest,
 rquested->requested
 rquesting->requesting
-rquests->requests
+rquests->requests, quests,
+rquire->require
 rquired->required
 rquirement->requirement
 rquires->requires
@@ -22223,9 +24091,12 @@ rquiring->requiring
 rranslation->translation
 rranslations->translations
 rrase->erase
-rsizing->resizing
-rsource->resource
-rturns->returns
+rsizing->resizing, sizing,
+rsource->resource, source,
+rsourced->resourced, sourced,
+rsources->resources, sources,
+rsourcing->resourcing, sourcing,
+rturns->returns, turns,
 rubarb->rhubarb
 rucuperate->recuperate
 rudimentally->rudimentary
@@ -22233,9 +24104,10 @@ rudimentatry->rudimentary
 rudimentry->rudimentary
 rulle->rule
 rumatic->rheumatic
-runing->running
-runned->ran, run,
-runnging->running
+runing->running, ruining,
+runn->run
+runned->ran, run, ruined,
+runnging->running, rummaging,
 runnig->running
 runnign->running
 runnigng->running
@@ -22244,7 +24116,7 @@ runnint->running
 runnning->running
 runns->runs
 runnung->running
-runtine->runtime
+runtine->runtime, routine,
 runting->runtime
 rurrent->current
 russina->Russian
@@ -22322,6 +24194,8 @@ satandards->standards
 satelite->satellite
 satelites->satellites
 satelitte->satellite
+satement->statement
+satements->statements
 saterday->Saturday
 saterdays->Saturdays
 satified->satisfied
@@ -22330,6 +24204,7 @@ satify->satisfy
 satifying->satisfying
 satisfactority->satisfactorily
 satisfiabilty->satisfiability
+satisfing->satisfying
 satisfyied->satisfied
 satisifed->satisfied
 satisified->satisfied
@@ -22390,7 +24265,8 @@ sceme->scheme, scene,
 scemes->schemes, scenes,
 scenarion->scenario
 scenarions->scenarios
-scence->scene
+scence->scene, science, sense,
+scences->scenes, sciences, senses, census,
 scenegraaph->scenegraph
 scenegraaphs->scenegraphs
 sceond->second
@@ -22402,6 +24278,7 @@ scetching->sketching
 schdule->schedule
 schduled->scheduled
 schduleing->scheduling
+schduler->scheduler
 schdules->schedules
 schduling->scheduling
 schedual->schedule
@@ -22451,12 +24328,17 @@ scoll->scroll
 scolling->scrolling
 scopeing->scoping
 scorebord->scoreboard
+scource->source, scouse,
+scourced->sourced, scoured,
+scourcer->scourer, sorcerer, scouser,
+scources->sources
 scrach->scratch
 scrached->scratched
 scraches->scratches
 scraching->scratching
 scrachs->scratches
 scrao->scrap
+screem->scream, screen,
 screenchot->screenshot
 screenchots->screenshots
 screenwrighter->screenwriter
@@ -22490,6 +24372,12 @@ sctioned->sectioned, suctioned,
 sctioning->sectioning, suctioning,
 sctions->sections, suctions,
 scuccessully->successfully
+sculpter->sculptor, sculpture,
+sculpters->sculptors, sculptures,
+scupt->sculpt
+scupted->sculpted
+scupting->sculpting
+scupture->sculpture
 scuptures->sculptures
 seach->search
 seached->searched
@@ -22519,6 +24407,7 @@ secne->scene
 secod->second
 seconadry->secondary
 seconcary->secondary
+secondaray->secondary
 seconday->secondary
 secondy->secondly, secondary,
 seconf->second
@@ -22541,6 +24430,8 @@ secue->secure
 secuely->securely
 secuity->security
 secund->second
+securiy->security
+securiyt->security
 securly->securely
 securre->secure
 securrely->securely
@@ -22558,6 +24449,7 @@ seemless->seamless
 seemlessly->seamlessly
 seesion->session
 seesions->sessions
+seeting->seating, setting, seething,
 segement->segment
 segementation->segmentation
 segements->segments
@@ -22574,6 +24466,8 @@ segmenetd->segmented
 segmeneted->segmented
 segmenets->segments
 segmentaion->segmentation
+segmente->segment
+segmentes->segments
 segmetn->segment
 segmetned->segmented
 segmetns->segments
@@ -22584,6 +24478,9 @@ seige->siege
 seing->seeing
 seinor->senior
 seires->series
+sekect->select
+sekected->selected
+sekects->selects
 selcetion->selection
 selctable->selectable
 selctables->selectables
@@ -22605,16 +24502,25 @@ selectin->selection, selecting,
 selectoin->selection
 selecton->selection
 selectons->selections
-seledted->sekected
+seledted->selected
 selektions->selections
 selektor->selector
-seleted->selected
+seleted->selected, deleted,
+seletion->selection, deletion,
+seletions->selections, deletions,
 self-comparisson->self-comparison
 self-contianed->self-contained
 self-referencial->self-referential
 self-refering->self-referring
+selfs->self
+selt->set, self, sold,
+selv->self
 semaintics->semantics
 semaphone->semaphore
+semaphones->semaphores
+semaphor->semaphore
+semaphors->semaphores
+semapthore->semaphore
 semapthores->semaphores
 sematic->semantic
 sematical->semantical
@@ -22628,7 +24534,12 @@ semicolumn->semicolon
 semicondutor->semiconductor
 sempahore->semaphore
 sempahores->semaphores
+sempaphore->semaphore
+sempaphores->semaphores
 semphore->semaphore
+semphores->semaphores
+senaphore->semaphore
+senaphores->semaphores
 senario->scenario
 senarios->scenarios
 sence->sense, since,
@@ -22648,6 +24559,8 @@ sensisble->sensible
 sensistive->sensitive
 sensistively->sensitively, sensitivity,
 sensitiv->sensitive
+sensitiveties->sensitivities
+sensitivety->sensitivity
 sensitivties->sensitivities
 sensitivty->sensitivity
 sensitivy->sensitivity, sensitively,
@@ -22665,6 +24578,8 @@ sentinals->sentinels
 sentive->sensitive
 sentively->sensitively, sensitivity,
 sentivite->sensitive
+seond->second, send,
+seonds->seconds, sends,
 sepaate->separate
 separartor->separator
 separat->separate
@@ -22734,12 +24649,15 @@ sepend->depend, suspend,
 sependent->dependent
 sepending->depending
 seperable->separable
+seperad->separate
+seperadly->separately
 seperaly->separately
 seperaor->separator
 seperaors->separators
 seperare->separate
 seperared->separated
 seperares->separates
+seperat->separate
 seperataed->separated
 seperatally->separately
 seperataly->separately
@@ -22838,8 +24756,14 @@ serailization->serialization
 serailized->serialized
 serailze->serialize
 serailzed->serialized
+sercive->service
+sercived->serviced
+sercives->services
+serciving->servicing
 sergent->sergeant
 serialiazation->serialization
+serice->service
+serices->services, series,
 serie->series
 serieses->series
 serios->serious
@@ -22852,9 +24776,18 @@ sertificate->certificate
 sertificated->certificated
 sertificates->certificates
 sertification->certification
-servce->service
-servces->services
+servce->service, serve,
+servced->serviced, served,
+servces->services, serves,
+servcing->servicing, serving,
+servece->service
+serveced->serviced
+serveces->services
+servecing->servicing
 serveice->service
+serveiced->serviced
+serveices->services
+serveicing->servicing
 serveral->several
 serverite->severity
 serverites->severities
@@ -23030,6 +24963,7 @@ shure->sure
 shurely->surely
 shutdownm->shutdown
 shuting->shutting
+shutodwn->shutdown
 shwo->show
 shystem->system
 shystemerror->systemerror, system error,
@@ -23167,6 +25101,7 @@ singlar->singular
 single-threded->single-threaded
 singls->singles, single,
 singlton->singleton
+singltons->singletons
 singlular->singular
 singlularly->singularly
 singnal->signal
@@ -23185,6 +25120,7 @@ singools->singles, signals,
 singsog->singsong
 singuarity->singularity
 singuarl->singular
+singulaties->singularities
 sinlge->single
 sinlges->singles
 sinply->simply
@@ -23201,6 +25137,25 @@ sintakts->syntax
 sintax->syntax
 Sionist->Zionist
 Sionists->Zionists
+sirect->direct
+sirected->directed
+sirecting->directing
+sirection->direction
+sirectional->directional
+sirectionalities->directionalities
+sirectionality->directionality
+sirectionals->directionals
+sirectionless->directionless
+sirections->directions
+sirective->directive
+sirectives->directives
+sirectly->directly
+sirectness->directness
+sirector->director
+sirectories->directories
+sirectors->directors
+sirectory->directory
+sirects->directs
 sise->size, sisal,
 sisnce->since
 sitation->situation
@@ -23219,7 +25174,11 @@ situatution->situation
 situatutions->situations
 situbbornness->stubbornness
 situdio->studio
+situdios->studios
+situration->situation
 siturations->situations
+situtaion->situation
+situtaions->situations
 situtation->situation
 situtations->situations
 siute->suite
@@ -23236,6 +25195,9 @@ skeep->skip
 skelton->skeleton
 skept->skipped
 sketchs->sketches
+skilfull->skilful, skillful,
+skillfull->skillful, skilful, skillfully, skilfully,
+skillfullness->skillfulness, skilfulness,
 skipd->skipped
 skiped->skipped, skyped,
 skiping->skipping
@@ -23304,6 +25266,7 @@ snipets->snippets
 snpashot->snapshot
 snpashots->snapshots
 snyc->sync
+snytax->syntax
 Soalris->Solaris
 socail->social
 socalism->socialism
@@ -23348,6 +25311,7 @@ somehwat->somewhat
 somehwere->somewhere
 somehwo->somehow
 somelse->someone else
+somemore->some more
 somene->someone
 somenone->someone
 someon->someone
@@ -23385,15 +25349,15 @@ songles->singles, dongles,
 songling->singling, dongling,
 sooaside->suicide
 soodonim->pseudonym
-sooit->suet, suit,
-soop->soup, scoop, snoop,
+sooit->suet, suit, soot,
+soop->soup, scoop, snoop, soap,
 soource->source
 sophicated->sophisticated
 sophisicated->sophisticated
 sophmore->sophomore
-sorce->source
+sorce->source, force,
 sorceror->sorcerer
-sord->sword, sore, sored, sawed,
+sord->sword, sore, sored, sawed, soared,
 sorrounding->surrounding
 sortig->sorting
 sortings->sorting
@@ -23401,15 +25365,15 @@ sortlst->sortlist
 sortner->sorter
 sortnr->sorter
 sortrage->storage, shortage,
-soruce->source
-soruces->sources
+soruce->source, spruce,
+soruces->sources, spruces,
 soscket->socket
 soterd->stored, sorted,
 sotfware->software
 sotrage->storage, shortage,
 sotred->sorted, stored,
 sotring->storing, sorting,
-sotry->story
+sotry->story, sorry,
 sotyr->satyr, story,
 souce->source
 souces->sources
@@ -23424,10 +25388,10 @@ soundard->soundcard
 sountrack->soundtrack
 sourcedrectory->sourcedirectory
 sourct->source
-soure->source, sure,
-soures->sources
+soure->source, sure, sore, sour, soured,
+soures->sources, sores, sours, soured,
 sourrounding->surrounding
-sourt->sort, south,
+sourt->sort, south, sour,
 sourth->south
 sourthern->southern
 southbrige->southbridge
@@ -23509,6 +25473,7 @@ specificatin->specification
 specificaton->specification
 specificed->specified
 specifices->specifies
+specifich->specify, specific,
 specificially->specifically
 specificiation->specification
 specificiations->specifications
@@ -23516,6 +25481,8 @@ specificically->specifically
 specificied->specified
 specificl->specific
 specificly->specifically
+specifiction->specification
+specifictions->specifications
 specificy->specify, specificity, specifically,
 specifid->specified
 specifing->specifying
@@ -23558,20 +25525,272 @@ speep->sleep
 speep-up->speed-up
 speeped->sped
 speeping->sleeping
+spefally->specially, specifically,
+spefation->separation, specification,
+spefations->separations, specifications,
+spefcifiable->specifiable
+spefcific->specific
+spefcifically->specifically
+spefcification->specification
+spefcifications->specifications
+spefcifics->specifics
+spefcifieid->specified
+spefcifieir->specifier
+spefcifieirs->specifiers
+spefcifieis->specifies
+spefcifiy->specify
+spefcifiying->specifying
+spefeid->specified
+spefeir->specifier
+spefeirs->specifiers
+spefeis->specifies
+spefiable->specifiable
+spefial->special
 spefic->specific
+speficable->specifiable
 spefically->specifically
+spefication->specification
+spefications->specifications
+speficed->specified
+speficeid->specified
+speficeir->specifier
+speficeirs->specifiers
+speficeis->specifies
+speficer->specifier
+speficers->specifiers
+spefices->specifies
+speficiable->specifiable
+speficiallally->specifically
+speficiallation->specification
+speficiallations->specifications
+speficialleid->specified
+speficialleir->specifier
+speficialleirs->specifiers
+speficialleis->specifies
+speficialliable->specifiable
+speficiallic->specific
+speficiallically->specifically
+speficiallication->specification
+speficiallications->specifications
+speficiallics->specifics
+speficiallied->specified
+speficiallier->specifier
+speficialliers->specifiers
+speficiallies->specifies
+speficiallifed->specified
+speficiallifer->specifier
+speficiallifers->specifiers
+speficiallifes->specifies
+speficially->specifically
+speficiation->specification
+speficiations->specifications
+speficic->specific
 speficically->specifically
+speficication->specification
+speficications->specifications
+speficics->specifics
 speficied->specified
+speficieid->specified
+speficieir->specifier
+speficieirs->specifiers
+speficieis->specifies
+speficier->specifier
+speficiers->specifiers
 speficies->specifies
+speficifally->specifically
+speficifation->specification
+speficifations->specifications
+speficifc->specific
+speficifcally->specifically
+speficifcation->specification
+speficifcations->specifications
+speficifcs->specifics
+speficifed->specified
+speficifeid->specified
+speficifeir->specifier
+speficifeirs->specifiers
+speficifeis->specifies
+speficifer->specifier
+speficifers->specifiers
+speficifes->specifies
+speficifiable->specifiable
+speficific->specific
+speficifically->specifically
+speficification->specification
+speficifications->specifications
+speficifics->specifics
+speficified->specified
+speficifier->specifier
+speficifiers->specifiers
+speficifies->specifies
+speficififed->specified
+speficififer->specifier
+speficififers->specifiers
+speficififes->specifies
+speficify->specify
+speficifying->specifying
+speficiiable->specifiable
+speficiic->specific
+speficiically->specifically
+speficiication->specification
+speficiications->specifications
+speficiics->specifics
+speficiied->specified
+speficiier->specifier
+speficiiers->specifiers
+speficiies->specifies
+speficiifed->specified
+speficiifer->specifier
+speficiifers->specifiers
+speficiifes->specifies
+speficillally->specifically
+speficillation->specification
+speficillations->specifications
+speficilleid->specified
+speficilleir->specifier
+speficilleirs->specifiers
+speficilleis->specifies
+speficilliable->specifiable
+speficillic->specific
+speficillically->specifically
+speficillication->specification
+speficillications->specifications
+speficillics->specifics
+speficillied->specified
+speficillier->specifier
+speficilliers->specifiers
+speficillies->specifies
+speficillifed->specified
+speficillifer->specifier
+speficillifers->specifiers
+speficillifes->specifies
+speficilly->specifically
+speficitally->specifically
+speficitation->specification
+speficitations->specifications
+speficiteid->specified
+speficiteir->specifier
+speficiteirs->specifiers
+speficiteis->specifies
+speficitiable->specifiable
+speficitic->specific
+speficitically->specifically
+speficitication->specification
+speficitications->specifications
+speficitics->specifics
+speficitied->specified
+speficitier->specifier
+speficitiers->specifiers
+speficities->specificities
+speficitifed->specified
+speficitifer->specifier
+speficitifers->specifiers
+speficitifes->specifies
+speficity->specificity
+speficiy->specify
+speficiying->specifying
+spefics->specifics
 speficy->specify
+speficying->specifying
+spefied->specified
+spefier->specifier
+spefiers->specifiers
+spefies->specifies
+spefifally->specifically
+spefifation->specification
+spefifations->specifications
+spefifed->specified
+spefifeid->specified
+spefifeir->specifier
+spefifeirs->specifiers
+spefifeis->specifies
+spefifer->specifier
+spefifers->specifiers
+spefifes->specifies
+spefifiable->specifiable
 spefific->specific
+spefifically->specifically
+spefification->specification
+spefifications->specifications
+spefifics->specifics
+spefified->specified
+spefifier->specifier
+spefifiers->specifiers
+spefifies->specifies
+spefififed->specified
+spefififer->specifier
+spefififers->specifiers
+spefififes->specifies
+spefify->specify
+spefifying->specifying
+spefiiable->specifiable
+spefiic->specific
+spefiically->specifically
+spefiication->specification
+spefiications->specifications
+spefiics->specifics
+spefiied->specified
+spefiier->specifier
+spefiiers->specifiers
+spefiies->specifies
+spefiifally->specifically
+spefiifation->specification
+spefiifations->specifications
+spefiifeid->specified
+spefiifeir->specifier
+spefiifeirs->specifiers
+spefiifeis->specifies
+spefiifiable->specifiable
+spefiific->specific
+spefiifically->specifically
+spefiification->specification
+spefiifications->specifications
+spefiifics->specifics
+spefiified->specified
+spefiifier->specifier
+spefiifiers->specifiers
+spefiifies->specifies
+spefiififed->specified
+spefiififer->specifier
+spefiififers->specifiers
+spefiififes->specifies
+spefiify->specify
+spefiifying->specifying
+spefixally->specifically
+spefixation->specification
+spefixations->specifications
+spefixeid->specified
+spefixeir->specifier
+spefixeirs->specifiers
+spefixeis->specifies
+spefixiable->specifiable
 spefixic->specific
+spefixically->specifically
+spefixication->specification
+spefixications->specifications
+spefixics->specifics
 spefixied->specified
+spefixier->specifier
+spefixiers->specifiers
+spefixies->specifies
+spefixifed->specified
+spefixifer->specifier
+spefixifers->specifiers
+spefixifes->specifies
+spefixy->specify
+spefixying->specifying
+spefiy->specify
+spefiying->specifying
+spefy->specify
+spefying->specifying
+speical->special
 speices->species
 speicfied->specified
 speicific->specific
+speicified->specified
 speicify->specify
 speling->spelling
+spellshecking->spellchecking
 spendour->splendour
 speparate->separate
 speparated->separated
@@ -23594,11 +25813,14 @@ spezific->specific
 spezified->specified
 spezify->specify
 spicific->specific
+spile->spite, spiral,
 spiltting->splitting
 spinlcok->spinlock
 spinock->spinlock
+splig->split, splign,
+spligs->splits
 spliitting->splitting
-splite->split
+splite->split, splits, splice,
 spliting->splitting
 splitted->split
 splittng->splitting
@@ -23658,8 +25880,12 @@ srink->shrink
 srinkd->shrunk
 srinked->shrunk
 srinking->shrinking
+sript->script
+sripts->scripts
 srollbar->scrollbar
 srouce->source
+srting->string, sorting,
+srtings->strings
 srtructure->structure
 sructure->structure
 sructures->structures
@@ -23674,6 +25900,14 @@ stablility->stability
 stablilization->stabilization
 stablize->stabilize
 stach->stack
+stadnard->standard
+stadnardisation->standardisation
+stadnardised->standardised
+stadnardising->standardising
+stadnardization->standardization
+stadnardized->standardized
+stadnardizing->standardizing
+stadnards->standards
 stae->state
 staement->statement
 staically->statically
@@ -23703,7 +25937,7 @@ standartized->standardized
 standarts->standards
 standatd->standard
 standtard->standard
-standy->standby
+standy->standby, sandy, standee,
 stange->strange
 stanp->stamp
 staration->starvation
@@ -23754,6 +25988,7 @@ statuss->status
 statusses->statuses
 statustics->statistics
 staulk->stalk
+stauration->saturation
 staus->status
 stawk->stalk
 stcokbrush->stockbrush
@@ -23801,27 +26036,35 @@ stoppping->stopping
 stopps->stops
 stopry->story
 storag->storage
+storeable->storable
 storeage->storage
 stoream->stream
-storeis->stories
+storeble->storable
+storeing->storing
+storeis->stories, stores, store is, storeys,
 storise->stories
 stornegst->strongest
+storys->stories, storeys,
 stoyr->story
 stpo->stop
-strack->stack
+strack->stack, track,
 stradegies->strategies
 stradegy->strategy
-stragedy->strategy
+stragedy->strategy, tragedy,
 stragegy->strategy
+strageties->strategies
+stragety->strategy
 straigh-forward->straightforward
 straighforward->straightforward
 straightfoward->straightforward
 straigt->straight
 straigth->straight
 straines->strains
-straming->streaming
-stran->strand
-strangly->strangely, strange,
+stram->steam, stream, tram,
+straming->streaming, steaming,
+strams->steams, streams, trams,
+stran->strand, strain,
+strangly->strangely, strange, strangle,
 strangness->strangeness
 strat->start, strata,
 stratagically->strategically
@@ -23859,8 +26102,13 @@ strenous->strenuous
 strentgh->strength
 strenth->strength
 strerrror->strerror
+striaght->straight
+striaghten->straighten
+striaghtens->straightens
 striaghtforward->straightforward
+striaghts->straights
 striclty->strictly
+stricly->strictly
 stricteir->stricter
 strictier->stricter
 strictiest->strictest
@@ -23877,6 +26125,7 @@ strirngification->stringification
 strnad->strand
 strng->string
 stroage->storage
+stroe->store
 stroing->storing
 stronlgy->strongly
 stronly->strongly
@@ -23905,6 +26154,7 @@ structue->structure
 structued->structured
 structues->structures
 structur->structure
+strucure->structure
 strucutre->structure
 strucutred->structured
 strucutres->structures
@@ -23917,8 +26167,12 @@ struttural->structural
 strutture->structure
 struture->structure
 ststr->strstr
+stteting->setting
 sttetings->settings
-stting->string
+stting->string, setting, sitting,
+sttings->strings, settings, sittings,
+stuation->situation, station,
+stuations->situations, stations,
 stubborness->stubbornness
 stucked->stuck
 stuckt->stuck
@@ -23928,9 +26182,14 @@ stucture->structure
 stuctured->structured
 stuctures->structures
 studdy->study
-studi->study
+studi->study, studio,
 studing->studying
+studis->studies, studios,
+studoi->studio
+studois->studios
 stuggling->struggling
+stuido->studio
+stuidos->studios
 stuill->still
 stummac->stomach
 sturcture->structure
@@ -23967,6 +26226,8 @@ subexperesion->subexpression
 subexperesions->subexpressions
 subexperession->subexpression
 subexperessions->subexpressions
+subexpersion->subexpression
+subexpersions->subexpressions
 subexperssion->subexpression
 subexperssions->subexpressions
 subexpession->subexpression
@@ -24048,7 +26309,6 @@ subpackges->subpackages
 subpecies->subspecies
 subporgram->subprogram
 subproccese->subprocess
-subprocess'->subprocess's
 subpsace->subspace
 subquue->subqueue
 subract->subtract
@@ -24087,9 +26347,22 @@ subshystem->subsystem
 subshystems->subsystems
 subsidary->subsidiary
 subsiduary->subsidiary
+subsituent->substituent
+subsituents->substituents
+subsitutable->substitutable
+subsitutatble->substitutable
 subsitute->substitute
+subsituted->substituted
+subsitutes->substitutes
 subsituting->substituting
 subsitution->substitution
+subsitutuent->substituent
+subsitutuents->substituents
+subsitutute->substitute
+subsitututed->substituted
+subsitututes->substitutes
+subsitututing->substituting
+subsitutution->substitution
 subsquent->subsequent
 subsquently->subsequently
 subsriber->subscriber
@@ -24109,6 +26382,8 @@ substituded->substituted
 substitudes->substitutes
 substituding->substituting
 substitue->substitute
+substitued->substituted, substitute,
+substitues->substitutes
 substituing->substituting
 substituion->substitution
 substituions->substitutions
@@ -24118,6 +26393,8 @@ substracted->subtracted
 substracting->subtracting
 substraction->subtraction
 substracts->subtracts
+substucture->substructure
+substuctures->substructures
 substutite->substitute
 subsysthem->subsystem
 subsysthems->subsystems
@@ -24141,6 +26418,8 @@ subtitutions->substitutions
 subtrafuge->subterfuge
 subtring->substring
 subtrings->substrings
+subtsitutable->substitutable
+subtsitutatble->substitutable
 suburburban->suburban
 subystem->subsystem
 subystems->subsystems
@@ -24297,6 +26576,12 @@ summay->summary
 summerised->summarised
 summerized->summarized
 summersalt->somersault
+summmaries->summaries
+summmarisation->summarisation
+summmarised->summarised
+summmarization->summarization
+summmarized->summarized
+summmary->summary
 sumodules->submodules
 sunglases->sunglasses
 suntask->subtask
@@ -24454,6 +26739,8 @@ surrouded->surrounded
 surrouding->surrounding
 surrrounded->surrounded
 surrundering->surrendering
+survay->survey
+survays->surveys
 surveilence->surveillance
 surveill->surveil
 surveyer->surveyor
@@ -24489,7 +26776,7 @@ sustems->systems
 sustitution->substitution
 sustitutions->substitutions
 susupend->suspend
-sutable->suitable
+sutable->suitable, stable,
 sutdown->shutdown
 sute->site, suite, suit,
 suttle->subtle
@@ -24506,6 +26793,7 @@ swalloed->swallowed
 swaped->swapped
 swapiness->swappiness
 swaping->swapping
+swarmin->swarming
 swcloumns->swcolumns
 swepth->swept
 swich->switch
@@ -24533,15 +26821,30 @@ swithing->switching
 switiches->switches
 swown->shown
 swtich->switch
+swtiching->switching
 swtichs->switches
 sxl->xsl
+syantax->syntax
 syas->says
 syatem->system
 syatems->systems
 sybsystem->subsystem
 sybsystems->subsystems
+sychronisation->synchronisation
+sychronise->synchronise
+sychronised->synchronised
+sychroniser->synchroniser
+sychronises->synchronises
 sychronisly->synchronously
+sychronization->synchronization
+sychronize->synchronize
+sychronized->synchronized
+sychronizer->synchronizer
+sychronizes->synchronizes
 sychronmode->synchronmode
+sychronous->synchronous
+sychronously->synchronously
+sycn->sync
 sycology->psychology
 sycronise->synchronise
 sycronised->synchronised
@@ -24614,9 +26917,9 @@ synchronsouly->synchronously
 synchronuous->synchronous
 synchronuously->synchronously
 synchronus->synchronous
-syncrhonise->sychronise
+syncrhonise->synchronise
 syncrhonised->synchronised
-syncrhonize->sychronize
+syncrhonize->synchronize
 syncrhonized->synchronized
 syncronise->synchronise
 syncronised->synchronised
@@ -24685,8 +26988,10 @@ systhemerror->systemerror, system error,
 systhemmemory->systemmemory, system memory,
 systhems->systems
 systhemwindow->systemwindow, system window,
+systm->system
 systme->system
 systmes->systems
+systms->systems
 systyem->system
 systyems->systems
 sysyem->system
@@ -24694,6 +26999,7 @@ sysyems->systems
 sytem->system
 sytematic->systematic
 sytemd->systemd
+syteme->system
 sytemerror->systemerror, system error,
 sytemmemory->systemmemory, system memory,
 sytems->systems
@@ -24724,6 +27030,17 @@ tabke->table
 tablepsace->tablespace
 tablepsaces->tablespaces
 tablle->table
+tabluar->tabular
+tabluate->tabulate
+tabluated->tabulated
+tabluates->tabulates
+tabluating->tabulating
+tabualte->tabulate
+tabualted->tabulated
+tabualtes->tabulates
+tabualting->tabulating
+tabualtor->tabulator
+tabualtors->tabulators
 tage->stage, take, tag, tagged,
 taged->tagged
 taget->target
@@ -24738,6 +27055,10 @@ takslet->tasklet
 talbe->table
 talekd->talked
 tallerable->tolerable
+tamplate->template
+tamplated->templated
+tamplates->templates
+tamplating->templating
 tangeant->tangent
 tangeantial->tangential
 tangeants->tangents
@@ -24799,7 +27120,7 @@ tbey->they
 tcahce->cache
 tcahces->caches
 tcheckout->checkout
-te->the, be,
+te->the, be, we,
 teached->taught
 teachnig->teaching
 teamplate->template
@@ -24810,6 +27131,7 @@ techicians->technicians
 techincal->technical
 techincally->technically
 techinically->technically
+techinique->technique
 techiniques->techniques
 techique->technique
 techiques->techniques
@@ -24825,6 +27147,12 @@ technnology->technology
 technolgy->technology
 technoloiges->technologies
 tecnic->technique
+tecnical->technical
+tecnically->technically
+tecnician->technician
+tecnicians->technicians
+tecnique->technique
+tecniques->techniques
 tedeous->tedious
 tefine->define
 teh->the
@@ -24838,6 +27166,8 @@ telocom->telecom
 telphony->telephony
 temaplate->template
 temaplates->templates
+temeprature->temperature
+temepratures->temperatures
 temerature->temperature
 teminate->terminate
 teminated->terminated
@@ -24914,15 +27244,44 @@ tempory->temporary
 temporyries->temporaries
 temporyrily->temporarily
 temporyry->temporary
+tempraaily->temporarily
+tempraal->temporal
+tempraarily->temporarily
+tempraarly->temporarily
+tempraary->temporary
+tempraay->temporary
+tempraily->temporarily
+tempral->temporal
+temprament->temperament
+tempramental->temperamental
+tempraraily->temporarily
+tempraral->temporal
+tempraraly->temporarily, temporally,
+temprararily->temporarily
+temprararly->temporarily
+temprarary->temporary
+tempraray->temporary
 temprarily->temporarily
 temprary->temporary, temporarily,
 temprature->temperature
 tempratures->temperatures
+tempray->temporary
 tempreature->temperature
 tempreatures->temperatures
+temprement->temperament
+tempremental->temperamental
+temproaily->temporarily
+temproal->temporal
 temproarily->temporarily
+temproarly->temporarily
 temproary->temporary
+temproay->temporary
+temproily->temporarily, temporally,
+temprol->temporal
+temproment->temperament
+tempromental->temperamental
 temproraily->temporarily
+temproral->temporal
 temproraly->temporarily
 temprorarily->temporarily
 temprorarly->temporarily
@@ -24930,6 +27289,7 @@ temprorary->temporary
 temproray->temporary
 temprorily->temporarily
 temprory->temporary
+temproy->temporary
 temptatation->temptation
 tempurature->temperature
 tempurture->temperature
@@ -24943,6 +27303,7 @@ tendacy->tendency
 tendancies->tendencies
 tendancy->tendency
 tennisplayer->tennis player
+tention->tension
 teplmate->template
 teplmated->templated
 teplmates->templates
@@ -24958,6 +27319,7 @@ termindate->terminate
 termine->determine
 termined->terminated
 terminte->terminate
+termo->thermo
 termostat->thermostat
 termperatue->temperature
 termperatues->temperatures
@@ -25001,6 +27363,7 @@ tessleator->tessellator
 testeing->testing
 testiclular->testicular
 testin->testing
+testng->testing
 testof->test of
 testomony->testimony
 tetrahedran->tetrahedron
@@ -25050,8 +27413,10 @@ theive->thief
 theives->thieves
 themplate->template
 themselces->themselves
+themselfe->themselves, themself,
+themselfes->themselves
 themselfs->themselves
-themselve->themselves
+themselve->themselves, themself,
 themslves->themselves
 thenes->themes
 thenn->then
@@ -25236,11 +27601,16 @@ tihs->this
 timedlta->timedelta
 timeing->timing
 timeot->timeout
+timeoutted->timed out
+timeput->timeout, time put,
+timeputs->timeouts, time puts,
 timere->timer
 timeschedule->time schedule
+timespanp->timespan
+timespanps->timespans
 timestan->timespan
-timestanp->timespanp
-timestanps->timespanps
+timestanp->timestamp, timespan,
+timestanps->timestamps, timespans,
 timestans->timespans
 timestemp->timestamp
 timestemps->timestamps
@@ -25255,6 +27625,10 @@ timne->time
 timoeut->timeout
 timout->timeout
 timtout->timeout
+timzeone->timezone
+timzeones->timezones
+timzezone->timezone
+timzezones->timezones
 tinterrupts->interrupts
 tiome->time, tome,
 tipe->type, tip,
@@ -25308,6 +27682,7 @@ tonihgt->tonight
 tood->todo
 toogle->toggle
 toogling->toggling
+tookit->toolkit, took it,
 tookits->toolkits
 toolar->toolbar
 toolsbox->toolbox
@@ -25349,6 +27724,7 @@ towrad->toward
 toxen->toxin
 tpyo->typo
 trabsform->transform
+traceablity->traceability
 trackign->tracking
 trackling->tracking
 tradgic->tragic
@@ -25357,6 +27733,7 @@ traditilnal->traditional
 traditiona->traditional
 traditionaly->traditionally
 traditionnal->traditional
+traditionnally->traditionally
 traditition->tradition
 tradtional->traditional
 tradtionally->traditionally
@@ -25364,6 +27741,10 @@ trafficed->trafficked
 trafficing->trafficking
 trafic->traffic
 tragectory->trajectory
+traget->target
+trageted->targeted
+trageting->targeting
+tragets->targets
 traiing->trailing, training,
 trailling->trailing
 traker->tracker
@@ -25422,6 +27803,8 @@ transalted->translated
 transaltes->translates
 transaltion->translation
 transaltions->translations
+transaltor->translator
+transaltors->translators
 transation->transaction, translation,
 transations->transactions, translations,
 transcendance->transcendence
@@ -25430,6 +27813,29 @@ transcendentational->transcendental
 transcevier->transceiver
 transciever->transceiver
 transcievers->transceivers
+transcocde->transcode
+transcocded->transcoded
+transcocder->transcoder
+transcocders->transcoders
+transcocdes->transcodes
+transcocding->transcoding
+transcocdings->transcodings
+transconde->transcode
+transconded->transcoded
+transconder->transcoder
+transconders->transcoders
+transcondes->transcodes
+transconding->transcoding
+transcondings->transcodings
+transcorde->transcode
+transcorded->transcoded
+transcorder->transcoder
+transcorders->transcoders
+transcordes->transcodes
+transcording->transcoding
+transcordings->transcodings
+transcoser->transcoder
+transcosers->transcoders
 transcripting->transcribing, transcription,
 transeint->transient
 transending->transcending
@@ -25447,6 +27853,8 @@ transfomed->transformed
 transfomer->transformer
 transfomm->transform
 transfoprmation->transformation
+transforation->transformation
+transforations->transformations
 transformated->transformed
 transformaton->transformation
 transformatted->transformed
@@ -25489,6 +27897,19 @@ transmittd->transmitted
 transmittion->transmission
 transmitts->transmits
 transmmit->transmit
+transocde->transcode
+transocded->transcoded
+transocder->transcoder
+transocders->transcoders
+transocdes->transcodes
+transocding->transcoding
+transocdings->transcodings
+transolate->translate
+transolated->translated
+transolates->translates
+transolating->translating
+transolation->translation
+transolations->translations
 transorm->transform
 transormed->transformed
 transorming->transforming
@@ -25553,8 +27974,11 @@ transprent->transparent
 transprently->transparently
 transprot->transport
 transproted->transported
+transproting->transporting
 transprots->transports
 transprt->transport
+transprted->transported
+transprting->transporting
 transprts->transports
 transpsition->transposition
 transsend->transcend
@@ -25570,11 +27994,28 @@ transvormed->transformed
 transvorming->transforming
 transvorms->transforms
 tranversing->traversing
+trapeziod->trapezoid
+trapeziodal->trapezoidal
 trasaction->transaction
 trascation->transaction
 trasfer->transfer
 trasferred->transferred
 trasfers->transfers
+trasform->transform
+trasformable->transformable
+trasformation->transformation
+trasformations->transformations
+trasformative->transformative
+trasformed->transformed
+trasformer->transformer
+trasformers->transformers
+trasforming->transforming
+trasforms->transforms
+traslalate->translate
+traslalated->translated
+traslalating->translating
+traslalation->translation
+traslalations->translations
 traslate->translate
 traslated->translated
 traslates->translates
@@ -25652,6 +28093,7 @@ trianglular->triangular
 trianglutaion->triangulation
 triangulataion->triangulation
 triangultaion->triangulation
+triger->trigger, tiger,
 trigered->triggered
 trigerred->triggered
 trigerring->triggering
@@ -25716,6 +28158,7 @@ truns->turns
 trustworthyness->trustworthiness
 trustworty->trustworthy
 trustwortyness->trustworthiness
+truw->true
 tryed->tried
 tryes->tries
 tryig->trying
@@ -25762,6 +28205,9 @@ tyhe->they
 tyies->tries
 tymecode->timecode
 tyope->type
+typcast->typecast
+typcasting->typecasting
+typcasts->typecasts
 typcial->typical
 typechek->typecheck
 typecheking->typechecking
@@ -25771,13 +28217,15 @@ typicaly->typically
 typicially->typically
 typle->tuple
 typles->tuples
-typoes->typos
+typoe->typo, type, types,
+typoes->typos, types,
 typographc->typographic
 typpe->type
 typped->typed
 typpes->types
 tyranies->tyrannies
 tyrany->tyranny
+tyring->trying
 tyrranies->tyrannies
 tyrrany->tyranny
 ubelieveble->unbelievable
@@ -25788,6 +28236,9 @@ ubitquitous->ubiquitous
 ublisher->publisher
 ubunut->Ubuntu
 ubutunu->Ubuntu
+udated->updated, dated,
+udater->updater, dater,
+udating->updating, dating,
 udno->undo, uno,
 udpatable->updatable
 udpate->update
@@ -25871,6 +28322,16 @@ unbeliveable->unbelievable
 unbeliveably->unbelievably
 unbelivebly->unbelievably
 unborned->unborn
+unbouind->unbound
+unbouinded->unbounded
+unboun->unbound
+unbounad->unbound
+unbounaded->unbounded
+unbouned->unbounded
+unbounnd->unbound
+unbounnded->unbounded
+unbouund->unbound
+unbouunded->unbounded
 unbunded->unbundled, unbounded,
 uncahnged->unchanged
 uncalcualted->uncalculated
@@ -25957,6 +28418,7 @@ undecideable->undecidable
 undefied->undefined
 undefien->undefine
 undefiend->undefined
+undefinied->undefined
 undeflow->underflow
 undeflows->underflows
 undefuned->undefined
@@ -25982,6 +28444,8 @@ undertsand->understand
 undertsanding->understanding
 undertsands->understands
 undertsood->understood
+undertstand->understand
+undertstands->understands
 underun->underrun
 underuns->underruns
 underware->underwear
@@ -25998,7 +28462,7 @@ undfine->undefine
 undfined->undefined
 undfines->undefines
 undistinghable->indistinguishable
-undoed->undone
+undoed->undo, undone,
 undorder->unorder
 undordered->unordered
 undoubtely->undoubtedly
@@ -26023,31 +28487,51 @@ unesacpe->unescape
 unesacped->unescaped
 unessecarry->unnecessary
 unessecary->unnecessary
+unexcected->unexpected
+unexcectedly->unexpectedly
 unexcpected->unexpected
+unexcpectedly->unexpectedly
 unexecpted->unexpected
+unexecptedly->unexpectedly
 unexected->unexpected
+unexectedly->unexpectedly
 unexepcted->unexpected
+unexepctedly->unexpectedly
 unexepected->unexpected
 unexepectedly->unexpectedly
 unexpacted->unexpected
+unexpactedly->unexpectedly
 unexpcted->unexpected
+unexpctedly->unexpectedly
 unexpecetd->unexpected
+unexpecetdly->unexpectedly
 unexpect->unexpected
 unexpectd->unexpected
 unexpectdly->unexpectedly
 unexpecte->unexpected
+unexpectely->unexpectedly
 unexpectend->unexpected
+unexpectendly->unexpectedly
+unexpectly->unexpectedly
 unexpeected->unexpected
 unexpeectedly->unexpectedly
 unexpepected->unexpected
 unexpepectedly->unexpectedly
 unexpepted->unexpected
 unexpeptedly->unexpectedly
+unexpercted->unexpected
+unexperctedly->unexpectedly
+unexpested->unexpected
+unexpestedly->unexpectedly
 unexpetced->unexpected
 unexpetcedly->unexpectedly
+unexpetct->unexpected
 unexpetcted->unexpected
 unexpetctedly->unexpectedly
+unexpetctly->unexpectedly
 unexpetect->unexpected
+unexpetected->unexpected
+unexpetectedly->unexpectedly
 unexpetectly->unexpectedly
 unexpeted->unexpected
 unexpetedly->unexpectedly
@@ -26056,6 +28540,11 @@ unexpexctedly->unexpectedly
 unexpexted->unexpected
 unexpextedly->unexpectedly
 unexspected->unexpected
+unexspectedly->unexpectedly
+unfilp->unflip
+unfilpped->unflipped
+unfilpping->unflipping
+unfilps->unflips
 unflaged->unflagged
 unflexible->inflexible
 unforetunately->unfortunately
@@ -26066,6 +28555,9 @@ unforseen->unforeseen
 unforttunately->unfortunately
 unfortuante->unfortunate
 unfortuantely->unfortunately
+unfortunaltely->unfortunately
+unfortunaly->unfortunately
+unfortunat->unfortunate
 unfortunatelly->unfortunately
 unfortunatetly->unfortunately
 unfortunatley->unfortunately
@@ -26115,6 +28607,7 @@ uninitalize->uninitialize
 uninitalized->uninitialized
 uninitalizes->uninitializes
 uniniteresting->uninteresting
+uninitializaed->uninitialized
 uninitialse->uninitialise
 uninitialsed->uninitialised
 uninitialses->uninitialises
@@ -26203,6 +28696,12 @@ unmaping->unmapping
 unmappend->unmapped
 unmarsalling->unmarshalling
 unmistakeably->unmistakably
+unmodfide->unmodified
+unmodfided->unmodified
+unmodfied->unmodified
+unmodfieid->unmodified
+unmodfified->unmodified
+unmodfitied->unmodified
 unmodifable->unmodifiable
 unmodifed->unmodified
 unmoutned->unmounted
@@ -26251,6 +28750,8 @@ unoticeable->unnoticeable
 unpacke->unpacked
 unpacket->unpacked
 unparseable->unparsable
+unpertubated->unperturbed
+unperturbated->unperturbed
 unplease->displease
 unpleasent->unpleasant
 unplesant->unpleasant
@@ -26319,6 +28820,8 @@ unrelying->underlying
 unrepentent->unrepentant
 unrepetant->unrepentant
 unrepetent->unrepentant
+unreplacable->unreplaceable
+unreplacalbe->unreplaceable
 unreproducable->unreproducible
 unresgister->unregister
 unresgisterd->unregistered
@@ -26356,6 +28859,39 @@ unsoclicited->unsolicited
 unsolicitied->unsolicited
 unsolicted->unsolicited
 unspecificed->unspecified
+unspefcifieid->unspecified
+unspefeid->unspecified
+unspeficed->unspecified
+unspeficeid->unspecified
+unspeficialleid->unspecified
+unspeficiallied->unspecified
+unspeficiallifed->unspecified
+unspeficied->unspecified
+unspeficieid->unspecified
+unspeficifed->unspecified
+unspeficifeid->unspecified
+unspeficified->unspecified
+unspeficififed->unspecified
+unspeficiied->unspecified
+unspeficiifed->unspecified
+unspeficilleid->unspecified
+unspeficillied->unspecified
+unspeficillifed->unspecified
+unspeficiteid->unspecified
+unspeficitied->unspecified
+unspeficitifed->unspecified
+unspefied->unspecified
+unspefifed->unspecified
+unspefifeid->unspecified
+unspefified->unspecified
+unspefififed->unspecified
+unspefiied->unspecified
+unspefiifeid->unspecified
+unspefiified->unspecified
+unspefiififed->unspecified
+unspefixeid->unspecified
+unspefixied->unspecified
+unspefixifed->unspecified
 unspported->unsupported
 unstabel->unstable
 unstall->install, uninstall,
@@ -26429,7 +28965,10 @@ unsurprizing->unsurprising
 unsurprizingly->unsurprisingly
 unsused->unused
 unswithced->unswitched
+unsychronise->unsynchronise
 unsychronised->unsynchronised
+unsychronize->unsynchronize
+unsychronized->unsynchronized
 untargetted->untargeted
 unter->under
 untill->until
@@ -26439,6 +28978,8 @@ untoched->untouched
 untqueue->unqueue
 untrached->untracked
 untranslateable->untranslatable
+untrasform->untransform, undo transform, reverse transform,
+untrasformed->untransformed
 untrasposed->untransposed
 untrustworty->untrustworthy
 unued->unused
@@ -26446,6 +28987,7 @@ ununsed->unused
 ununsual->unusual
 unusal->unusual
 unusally->unusually
+unuseable->unusable
 unuseful->useless
 unusre->unsure
 unusuable->unusable
@@ -26491,6 +29033,7 @@ updateing->updating
 updatig->updating
 updats->updates
 updgrade->upgrade
+updrage->upgrade
 updte->update
 uperclass->upperclass
 upgade->upgrade
@@ -26571,6 +29114,7 @@ upstreems->upstreams
 upstrema->upstream
 upsupported->unsupported
 uptadeable->updatable
+uptdate->update
 uptim->uptime
 uptions->options
 upto->up to
@@ -26587,6 +29131,7 @@ usal->usual
 usally->usually
 uscaled->unscaled
 useability->usability
+useable->usable
 useage->usage
 usebility->usability
 useble->usable
@@ -26615,6 +29160,7 @@ usesfull->useful
 usespace->userspace
 usetnet->Usenet
 usibility->usability
+usible->usable
 usig->using
 usign->using, unsign,
 usiing->using
@@ -26677,6 +29223,9 @@ vailidity->validity
 vailidty->validity
 vairable->variable
 vairous->various
+vakue->value
+vakued->valued
+vakues->values
 valailable->available
 valdate->validate
 valetta->valletta
@@ -26690,8 +29239,13 @@ valies->values
 valif->valid
 valitdity->validity
 valkues->values
+vallid->valid
+vallidation->validation
+vallidity->validity
 vallue->value
 vallues->values
+valtage->voltage
+valtages->voltages
 valu->value
 valuble->valuable
 valudes->values
@@ -26898,6 +29452,7 @@ violoation->violation
 violoations->violations
 virtal->virtual
 virtaul->virtual
+virtical->vertical
 virtiual->virtual
 virtualisaion->virtualisation
 virtualisaiton->virtualisation
@@ -26946,17 +29501,30 @@ vissible->visible
 visted->visited
 visting->visiting
 vistors->visitors
+visuallisation->visualisation
+visuallization->visualization
+visualyse->visualise, visualize,
 vitories->victories
 vitual->virtual
 viusally->visually
 viusualisation->visualisation
 viwer->viewer
 viwers->viewers
+vizualisation->visualisation
+vizualise->visualise
+vizualization->visualization
+vizualize->visualize
 vlarge->large
 vlaue->value
 vlaues->values
+vlone->clone
+vloned->cloned
+vlones->clones
 vlues->values
 volatage->voltage
+volatages->voltages
+volatge->voltage
+volatges->voltages
 volcanoe->volcano
 volenteer->volunteer
 volenteered->volunteered
@@ -27035,8 +29603,16 @@ vulerable->vulnerable
 vulerabuilities->vulnerabilities
 vulerabuility->vulnerability
 vulerabule->vulnerable
+vulernabilities->vulnerabilities
+vulernability->vulnerability
+vulernable->vulnerable
 vulnarabilities->vulnerabilities
 vulnarability->vulnerability
+vulneabilities->vulnerabilities
+vulneability->vulnerability
+vulneable->vulnerable
+vulnearabilities->vulnerabilities
+vulnearability->vulnerability
 vulnearable->vulnerable
 vulnearabule->vulnerable
 vulnearbilities->vulnerabilities
@@ -27070,6 +29646,9 @@ vulnerabuilties->vulnerabilities
 vulnerabuilty->vulnerability
 vulnerabule->vulnerable
 vulnerabulility->vulnerability
+vulnerarbilities->vulnerabilities
+vulnerarbility->vulnerability
+vulnerarble->vulnerable
 vulnerbilities->vulnerabilities
 vulnerbility->vulnerability
 vulnerbuilities->vulnerabilities
@@ -27078,7 +29657,7 @@ vunerable->vulnerable
 vyer->very
 vyre->very
 waht->what
-wakeus->wakeups
+wakeus->wakeups, wake us, walrus,
 wakup->wakeup
 wallthickness->wall thickness
 wan't->want, wasn't,
@@ -27095,10 +29674,31 @@ warinigs->warnings
 warinings->warnings
 warks->works
 warlking->walking
+warnibg->warning
+warnibgs->warnings
 warnig->warning
 warnign->warning
 warnigns->warnings
 warnigs->warnings
+warniing->warning
+warniings->warnings
+warnin->warning
+warnind->warning
+warninds->warnings
+warninf->warning
+warninfs->warnings
+warningss->warnings
+warninig->warning
+warninigs->warnings
+warnining->warning
+warninings->warnings
+warninng->warning
+warninngs->warnings
+warnins->warnings
+warninsg->warnings
+warninsgs->warnings
+warniong->warning
+warniongs->warnings
 warrent->warrant
 warrriors->warriors
 was'nt->wasn't
@@ -27113,8 +29713,11 @@ wass->was
 watchdong->watchdog
 watchog->watchdog
 watermask->watermark
+wath->watch, wrath, what,
 wathc->watch
 wathdog->watchdog
+wathever->whatever
+waths->whats, watches,
 wating->waiting
 watn->want
 wavelenght->wavelength
@@ -27144,7 +29747,6 @@ well-reknowned->well-renowned, well reno
 wendesday->Wednesday
 wendsay->Wednesday
 wensday->Wednesday
-were'->we're
 were'nt->weren't
 wereabouts->whereabouts
 wereas->whereas
@@ -27272,6 +29874,8 @@ windoes->windows
 windos->windows
 windwo->window
 winn->win
+winndow->window
+winndows->windows
 winodw->window
 wipoing->wiping
 wirded->wired, weird,
@@ -27361,6 +29965,8 @@ wordlwide->worldwide
 wordpres->wordpress
 worfklow->workflow
 worfklows->workflows
+worflow->workflow
+worflows->workflow
 workaorund->workaround
 workaraound->workaround
 workarbound->workaround
@@ -27381,7 +29987,11 @@ workbneches->workbenches
 workboos->workbooks
 workd->worked
 workes->works
+workfow->workflow
+workfows->workflows
 workign->working
+worklfow->workflow
+worklfows->workflows
 workpsace->workspace
 workpsaces->workspaces
 workspsace->workspace
@@ -27419,6 +30029,8 @@ wounderful->wonderful
 wouold->would
 wouuld->would
 wqs->was
+wraning->warning
+wranings->warnings
 wraped->wrapped, warped,
 wrapepd->wrapped
 wraper->wrapper
@@ -27444,6 +30056,8 @@ wroet->wrote
 wrog->wrong
 wrok->work
 wroked->worked
+wrokflow->workflow
+wrokflows->workflows
 wroking->working
 wroks->works
 wron->wrong
@@ -27499,6 +30113,10 @@ yotube->youtube
 youn->your, you, young,
 youre->your, you're,
 yourr->your, you're,
+yourselfe->yourself, yourselves,
+yourselfes->yourselves
+yourselv->yourself, yourselves,
+yourselve->yourselves, yourself,
 youseff->yourself, yousef,
 youself->yourself
 ypes->types
@@ -27524,3 +30142,11 @@ __attribyte__->__attribute__
 __cpluspus->__cplusplus
 __cpusplus->__cplusplus
 évaluate->evaluate
+сontain->contain
+сontained->contained
+сontainer->container
+сontainers->containers
+сontaining->containing
+сontainor->container
+сontainors->containers
+сontains->contains
diff -pruN 1.17.1-1/codespell_lib/data/dictionary_usage.txt 2.0.0-1/codespell_lib/data/dictionary_usage.txt
--- 1.17.1-1/codespell_lib/data/dictionary_usage.txt	1970-01-01 00:00:00.000000000 +0000
+++ 2.0.0-1/codespell_lib/data/dictionary_usage.txt	2020-11-23 15:42:41.000000000 +0000
@@ -0,0 +1,9 @@
+blacklist->blocklist
+blacklists->blocklists
+man-in-the-middle->on-path attacker
+master->primary, leader, active, writer, coordinator, parent, manager, main,
+masters->primaries, leaders, actives, writers, coordinators, parents, managers,
+slave->secondary, follower, standby, replica, reader, worker, helper, subordinate, subsystem,
+slaves->secondaries, followers, standbys, replicas, readers, workers, helpers, subordinates,
+whitelist->allowlist, permitlist,
+whitelists->allowlists, permitlists,
diff -pruN 1.17.1-1/codespell_lib/__main__.py 2.0.0-1/codespell_lib/__main__.py
--- 1.17.1-1/codespell_lib/__main__.py	1970-01-01 00:00:00.000000000 +0000
+++ 2.0.0-1/codespell_lib/__main__.py	2020-11-23 15:42:41.000000000 +0000
@@ -0,0 +1,4 @@
+from ._codespell import _script_main
+
+if __name__ == '__main__':
+    _script_main()
diff -pruN 1.17.1-1/codespell_lib/tests/test_basic.py 2.0.0-1/codespell_lib/tests/test_basic.py
--- 1.17.1-1/codespell_lib/tests/test_basic.py	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/tests/test_basic.py	2020-11-23 15:42:41.000000000 +0000
@@ -3,23 +3,63 @@
 from __future__ import print_function
 
 import contextlib
+import inspect
 import os
 import os.path as op
+from shutil import copyfile
 import subprocess
 import sys
 
-import codespell_lib as cs
+import pytest
+
+import codespell_lib as cs_
+from codespell_lib._codespell import EX_USAGE, EX_OK, EX_DATAERR
+
+
+def test_constants():
+    """Test our EX constants."""
+    assert EX_OK == 0
+    assert EX_USAGE == 64
+    assert EX_DATAERR == 65
+
+
+class MainWrapper(object):
+    """Compatibility wrapper for when we used to return the count."""
+
+    def main(self, *args, count=True, std=False, **kwargs):
+        if count:
+            args = ('--count',) + args
+        code = cs_.main(*args, **kwargs)
+        capsys = inspect.currentframe().f_back.f_locals['capsys']
+        stdout, stderr = capsys.readouterr()
+        assert code in (EX_OK, EX_USAGE, EX_DATAERR)
+        if code == EX_DATAERR:  # have some misspellings
+            code = int(stderr.split('\n')[-2])
+        elif code == EX_OK and count:
+            code = int(stderr.split('\n')[-2])
+            assert code == 0
+        if std:
+            return (code, stdout, stderr)
+        else:
+            return code
+
+
+cs = MainWrapper()
 
 
 def run_codespell(args=(), cwd=None):
-    """Helper to run codespell"""
-    return subprocess.Popen(
+    """Run codespell."""
+    args = ('--count',) + args
+    proc = subprocess.Popen(
         ['codespell'] + list(args), cwd=cwd,
-        stdout=subprocess.PIPE, stderr=subprocess.PIPE).wait()
+        stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    stderr = proc.communicate()[1].decode('utf-8')
+    count = int(stderr.split('\n')[-2])
+    return count
 
 
 def test_command(tmpdir):
-    """Test running the codespell executable"""
+    """Test running the codespell executable."""
     # With no arguments does "."
     d = str(tmpdir)
     assert run_codespell(cwd=d) == 0
@@ -29,13 +69,14 @@ def test_command(tmpdir):
 
 
 def test_basic(tmpdir, capsys):
-    """Test some basic functionality"""
+    """Test some basic functionality."""
     assert cs.main('_does_not_exist_') == 0
     fname = op.join(str(tmpdir), 'tmp')
     with open(fname, 'w') as f:
         pass
-    assert cs.main('-D', 'foo', f.name) == 1, 'missing dictionary'
-    assert 'cannot find dictionary' in capsys.readouterr()[1]
+    code, _, stderr = cs.main('-D', 'foo', f.name, std=True)
+    assert code == EX_USAGE, 'missing dictionary'
+    assert 'cannot find dictionary' in stderr
     assert cs.main(fname) == 0, 'empty file'
     with open(fname, 'a') as f:
         f.write('this is a test file\n')
@@ -50,22 +91,21 @@ def test_basic(tmpdir, capsys):
         f.write('tim\ngonna\n')
     assert cs.main(fname) == 2, 'with a name'
     assert cs.main('--builtin', 'clear,rare,names,informal', fname) == 4
-    capsys.readouterr()
-    assert cs.main(fname, '--builtin', 'foo') == 1  # bad type sys.exit(1)
-    stdout = capsys.readouterr()[1]
-    assert 'Unknown builtin dictionary' in stdout
-    d = str(tmpdir)
-    assert cs.main(fname, '-D', op.join(d, 'foo')) == 1  # bad dict
-    stdout = capsys.readouterr()[1]
-    assert 'cannot find dictionary' in stdout
+    code, _, stderr = cs.main(fname, '--builtin', 'foo', std=True)
+    assert code == EX_USAGE  # bad type
+    assert 'Unknown builtin dictionary' in stderr
+    d = str(tmpdir)
+    code, _, stderr = cs.main(fname, '-D', op.join(d, 'foo'), std=True)
+    assert code == EX_USAGE  # bad dict
+    assert 'cannot find dictionary' in stderr
     os.remove(fname)
 
     with open(op.join(d, 'bad.txt'), 'w') as f:
         f.write('abandonned\nAbandonned\nABANDONNED\nAbAnDoNnEd')
     assert cs.main(d) == 4
-    capsys.readouterr()
-    assert cs.main('-w', d) == 0
-    assert 'FIXED:' in capsys.readouterr()[1]
+    code, _, stderr = cs.main('-w', d, std=True)
+    assert code == 0
+    assert 'FIXED:' in stderr
     with open(op.join(d, 'bad.txt')) as f:
         new_content = f.read()
     assert cs.main(d) == 0
@@ -74,9 +114,10 @@ def test_basic(tmpdir, capsys):
     with open(op.join(d, 'bad.txt'), 'w') as f:
         f.write('abandonned abandonned\n')
     assert cs.main(d) == 2
-    capsys.readouterr()
-    assert cs.main('-q', '16', '-w', d) == 0
-    assert capsys.readouterr() == ('', '')
+    code, stdout, stderr = cs.main(
+        '-q', '16', '-w', d, count=False, std=True)
+    assert code == 0
+    assert stdout == stderr == ''
     assert cs.main(d) == 0
 
     # empty directory
@@ -98,8 +139,9 @@ def test_interactivity(tmpdir, capsys):
         with FakeStdin('y\n'):
             assert cs.main('-i', '3', f.name) == 1
         with FakeStdin('n\n'):
-            assert cs.main('-w', '-i', '3', f.name) == 0
-        assert '==>' in capsys.readouterr()[0]
+            code, stdout, _ = cs.main('-w', '-i', '3', f.name, std=True)
+            assert code == 0
+        assert '==>' in stdout
         with FakeStdin('x\ny\n'):
             assert cs.main('-w', '-i', '3', f.name) == 0
         assert cs.main(f.name) == 0
@@ -138,10 +180,10 @@ def test_interactivity(tmpdir, capsys):
         with open(f.name, 'w') as f:
             f.write('ackward\n')
         assert cs.main(f.name) == 1
-        capsys.readouterr()
         with FakeStdin('x\n1\n'):  # blank input -> nothing
-            assert cs.main('-w', '-i', '3', f.name) == 0
-        assert 'a valid option' in capsys.readouterr()[0]
+            code, stdout, _ = cs.main('-w', '-i', '3', f.name, std=True)
+            assert code == 0
+        assert 'a valid option' in stdout
         assert cs.main(f.name) == 0
         with open(f.name, 'r') as f:
             assert f.read() == 'backward\n'
@@ -150,30 +192,28 @@ def test_interactivity(tmpdir, capsys):
 
 
 def test_summary(tmpdir, capsys):
-    """Test summary functionality"""
+    """Test summary functionality."""
     with open(op.join(str(tmpdir), 'tmp'), 'w') as f:
         pass
-    try:
-        cs.main(f.name)
-        assert capsys.readouterr() == ('', ''), 'no output'
-        cs.main(f.name, '--summary')
-        stdout, stderr = capsys.readouterr()
-        assert stderr == ''
-        assert 'SUMMARY' in stdout
-        assert len(stdout.split('\n')) == 5
-        with open(f.name, 'w') as f:
-            f.write('abandonned\nabandonned')
-        cs.main(f.name, '--summary')
-        stdout, stderr = capsys.readouterr()
-        assert stderr == ''
-        assert 'SUMMARY' in stdout
-        assert len(stdout.split('\n')) == 7
-        assert 'abandonned' in stdout.split()[-2]
-    finally:
-        os.remove(f.name)
+    code, stdout, stderr = cs.main(f.name, std=True, count=False)
+    assert code == 0
+    assert stdout == stderr == '', 'no output'
+    code, stdout, stderr = cs.main(f.name, '--summary', std=True)
+    assert code == 0
+    assert stderr == '0\n'
+    assert 'SUMMARY' in stdout
+    assert len(stdout.split('\n')) == 5
+    with open(f.name, 'w') as f:
+        f.write('abandonned\nabandonned')
+    assert code == 0
+    code, stdout, stderr = cs.main(f.name, '--summary', std=True)
+    assert stderr == '2\n'
+    assert 'SUMMARY' in stdout
+    assert len(stdout.split('\n')) == 7
+    assert 'abandonned' in stdout.split()[-2]
 
 
-def test_ignore_dictionary(tmpdir):
+def test_ignore_dictionary(tmpdir, capsys):
     """Test ignore dictionary functionality."""
     d = str(tmpdir)
     with open(op.join(d, 'bad.txt'), 'w') as f:
@@ -185,8 +225,8 @@ def test_ignore_dictionary(tmpdir):
     assert cs.main('-I', f.name, bad_name) == 1
 
 
-def test_ignore_word_list(tmpdir):
-    """Test ignore word list functionality"""
+def test_ignore_word_list(tmpdir, capsys):
+    """Test ignore word list functionality."""
     d = str(tmpdir)
     with open(op.join(d, 'bad.txt'), 'w') as f:
         f.write('abandonned\nabondon\nabilty\n')
@@ -201,12 +241,12 @@ def test_custom_regex(tmpdir, capsys):
         f.write('abandonned_abondon\n')
     assert cs.main(d) == 0
     assert cs.main('-r', "[a-z]+", d) == 2
-    capsys.readouterr()
-    assert cs.main('-r', '[a-z]+', '--write-changes', d) == 1
-    assert 'ERROR:' in capsys.readouterr()[0]
+    code, stdout, _ = cs.main('-r', '[a-z]+', '--write-changes', d, std=True)
+    assert code == EX_USAGE
+    assert 'ERROR:' in stdout
 
 
-def test_exclude_file(tmpdir):
+def test_exclude_file(tmpdir, capsys):
     """Test exclude file functionality."""
     d = str(tmpdir)
     with open(op.join(d, 'bad.txt'), 'wb') as f:
@@ -226,27 +266,26 @@ def test_encoding(tmpdir, capsys):
         pass
     # with CaptureStdout() as sio:
     assert cs.main(f.name) == 0
-    try:
-        with open(f.name, 'wb') as f:
-            f.write(u'naïve\n'.encode('utf-8'))
-        assert cs.main(f.name) == 0
-        assert cs.main('-e', f.name) == 0
-        with open(f.name, 'ab') as f:
-            f.write(u'naieve\n'.encode('utf-8'))
-        assert cs.main(f.name) == 1
-        # Binary file warning
-        with open(f.name, 'wb') as f:
-            f.write(b'\x00\x00naiive\x00\x00')
-        capsys.readouterr()
-        assert cs.main(f.name) == 0
-        assert 'WARNING: Binary file' in capsys.readouterr()[1]
-        assert cs.main('-q', '2', f.name) == 0
-        assert capsys.readouterr() == ('', '')
-    finally:
-        os.remove(f.name)
+    with open(f.name, 'wb') as f:
+        f.write(u'naïve\n'.encode('utf-8'))
+    assert cs.main(f.name) == 0
+    assert cs.main('-e', f.name) == 0
+    with open(f.name, 'ab') as f:
+        f.write(u'naieve\n'.encode('utf-8'))
+    assert cs.main(f.name) == 1
+    # Binary file warning
+    with open(f.name, 'wb') as f:
+        f.write(b'\x00\x00naiive\x00\x00')
+    code, stdout, stderr = cs.main(f.name, std=True, count=False)
+    assert code == 0
+    assert stdout == stderr == ''
+    code, stdout, stderr = cs.main('-q', '0', f.name, std=True, count=False)
+    assert code == 0
+    assert stdout == ''
+    assert 'WARNING: Binary file' in stderr
 
 
-def test_ignore(tmpdir):
+def test_ignore(tmpdir, capsys):
     """Test ignoring of files and directories."""
     d = str(tmpdir)
     with open(op.join(d, 'good.txt'), 'w') as f:
@@ -268,29 +307,67 @@ def test_ignore(tmpdir):
     assert cs.main('--skip=*ignoredir/bad*', d) == 1
 
 
-def test_check_filename(tmpdir):
+def test_check_filename(tmpdir, capsys):
     """Test filename check."""
     d = str(tmpdir)
+    # Empty file
+    with open(op.join(d, 'abandonned.txt'), 'w') as f:
+        f.write('')
+    assert cs.main('-f', d) == 1
+    # Normal file with contents
     with open(op.join(d, 'abandonned.txt'), 'w') as f:
         f.write('.')
     assert cs.main('-f', d) == 1
+    # Normal file with binary contents
+    with open(op.join(d, 'abandonned.txt'), 'wb') as f:
+        f.write(b'\x00\x00naiive\x00\x00')
+    assert cs.main('-f', d) == 1
 
 
-def test_check_hidden(tmpdir):
+@pytest.mark.skipif((not hasattr(os, "mkfifo") or not callable(os.mkfifo)),
+                    reason='requires os.mkfifo')
+def test_check_filename_irregular_file(tmpdir, capsys):
+    """Test irregular file filename check."""
+    # Irregular file (!isfile())
+    d = str(tmpdir)
+    os.mkfifo(op.join(d, 'abandonned'))
+    assert cs.main('-f', d) == 1
+    d = str(tmpdir)
+
+
+def test_check_hidden(tmpdir, capsys):
     """Test ignoring of hidden files."""
     d = str(tmpdir)
-    # hidden file
+    # visible file
     with open(op.join(d, 'test.txt'), 'w') as f:
         f.write('abandonned\n')
     assert cs.main(op.join(d, 'test.txt')) == 1
+    assert cs.main(d) == 1
+    # hidden file
     os.rename(op.join(d, 'test.txt'), op.join(d, '.test.txt'))
     assert cs.main(op.join(d, '.test.txt')) == 0
+    assert cs.main(d) == 0
     assert cs.main('--check-hidden', op.join(d, '.test.txt')) == 1
+    assert cs.main('--check-hidden', d) == 1
+    # hidden file with typo in name
     os.rename(op.join(d, '.test.txt'), op.join(d, '.abandonned.txt'))
     assert cs.main(op.join(d, '.abandonned.txt')) == 0
+    assert cs.main(d) == 0
     assert cs.main('--check-hidden', op.join(d, '.abandonned.txt')) == 1
+    assert cs.main('--check-hidden', d) == 1
     assert cs.main('--check-hidden', '--check-filenames',
                    op.join(d, '.abandonned.txt')) == 2
+    assert cs.main('--check-hidden', '--check-filenames', d) == 2
+    # hidden directory
+    assert cs.main(d) == 0
+    assert cs.main('--check-hidden', d) == 1
+    assert cs.main('--check-hidden', '--check-filenames', d) == 2
+    os.mkdir(op.join(d, '.abandonned'))
+    copyfile(op.join(d, '.abandonned.txt'),
+             op.join(d, '.abandonned', 'abandonned.txt'))
+    assert cs.main(d) == 0
+    assert cs.main('--check-hidden', d) == 2
+    assert cs.main('--check-hidden', '--check-filenames', d) == 5
 
 
 def test_case_handling(tmpdir, capsys):
@@ -300,17 +377,16 @@ def test_case_handling(tmpdir, capsys):
         pass
     # with CaptureStdout() as sio:
     assert cs.main(f.name) == 0
-    try:
-        with open(f.name, 'wb') as f:
-            f.write('this has an ACII error'.encode('utf-8'))
-        assert cs.main(f.name) == 1
-        assert 'ASCII' in capsys.readouterr()[0]
-        assert cs.main('-w', f.name) == 0
-        assert 'FIXED' in capsys.readouterr()[1]
-        with open(f.name, 'rb') as f:
-            assert f.read().decode('utf-8') == 'this has an ASCII error'
-    finally:
-        os.remove(f.name)
+    with open(f.name, 'wb') as f:
+        f.write('this has an ACII error'.encode('utf-8'))
+    code, stdout, _ = cs.main(f.name, std=True)
+    assert code == 1
+    assert 'ASCII' in stdout
+    code, _, stderr = cs.main('-w', f.name, std=True)
+    assert code == 0
+    assert 'FIXED' in stderr
+    with open(f.name, 'rb') as f:
+        assert f.read().decode('utf-8') == 'this has an ASCII error'
 
 
 def test_context(tmpdir, capsys):
@@ -320,16 +396,18 @@ def test_context(tmpdir, capsys):
         f.write('line 1\nline 2\nline 3 abandonned\nline 4\nline 5')
 
     # symmetric context, fully within file
-    cs.main('-C', '1', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, _ = cs.main('-C', '1', d, std=True)
+    assert code == 1
+    lines = stdout.split('\n')
     assert len(lines) == 5
     assert lines[0] == ': line 2'
     assert lines[1] == '> line 3 abandonned'
     assert lines[2] == ': line 4'
 
     # requested context is bigger than the file
-    cs.main('-C', '10', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, _ = cs.main('-C', '10', d, std=True)
+    assert code == 1
+    lines = stdout.split('\n')
     assert len(lines) == 7
     assert lines[0] == ': line 1'
     assert lines[1] == ': line 2'
@@ -338,23 +416,26 @@ def test_context(tmpdir, capsys):
     assert lines[4] == ': line 5'
 
     # only before context
-    cs.main('-B', '2', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, _ = cs.main('-B', '2', d, std=True)
+    assert code == 1
+    lines = stdout.split('\n')
     assert len(lines) == 5
     assert lines[0] == ': line 1'
     assert lines[1] == ': line 2'
     assert lines[2] == '> line 3 abandonned'
 
     # only after context
-    cs.main('-A', '1', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, _ = cs.main('-A', '1', d, std=True)
+    assert code == 1
+    lines = stdout.split('\n')
     assert len(lines) == 4
     assert lines[0] == '> line 3 abandonned'
     assert lines[1] == ': line 4'
 
     # asymmetric context
-    cs.main('-B', '2', '-A', '1', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, _ = cs.main('-B', '2', '-A', '1', d, std=True)
+    assert code == 1
+    lines = stdout.split('\n')
     assert len(lines) == 6
     assert lines[0] == ': line 1'
     assert lines[1] == ': line 2'
@@ -362,16 +443,84 @@ def test_context(tmpdir, capsys):
     assert lines[3] == ': line 4'
 
     # both '-C' and '-A' on the command line
-    cs.main('-C', '2', '-A', '1', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, _ = cs.main('-C', '2', '-A', '1', d, std=True)
+    assert code == EX_USAGE
+    lines = stdout.split('\n')
     assert 'ERROR' in lines[0]
 
     # both '-C' and '-B' on the command line
-    cs.main('-C', '2', '-B', '1', d)
-    lines = capsys.readouterr()[0].split('\n')
+    code, stdout, stderr = cs.main('-C', '2', '-B', '1', d, std=True)
+    assert code == EX_USAGE
+    lines = stdout.split('\n')
     assert 'ERROR' in lines[0]
 
 
+def test_ignore_regex_flag(tmpdir, capsys):
+    """Test ignore regex flag functionality."""
+    d = str(tmpdir)
+
+    # Invalid regex.
+    code, stdout, _ = cs.main('--ignore-regex=(', std=True)
+    assert code == EX_USAGE
+    assert 'usage:' in stdout
+
+    with open(op.join(d, 'flag.txt'), 'w') as f:
+        f.write('# Please see http://example.com/abandonned for info\n')
+    # Test file has 1 invalid entry, and it's not ignored by default.
+    assert cs.main(f.name) == 1
+    # An empty regex is the default value, and nothing is ignored.
+    assert cs.main(f.name, '--ignore-regex=') == 1
+    assert cs.main(f.name, '--ignore-regex=""') == 1
+    # Non-matching regex results in nothing being ignored.
+    assert cs.main(f.name, '--ignore-regex=^$') == 1
+    # A word can be ignored.
+    assert cs.main(f.name, '--ignore-regex=abandonned') == 0
+    # Ignoring part of the word can result in odd behavior.
+    assert cs.main(f.name, '--ignore-regex=nn') == 0
+
+    with open(op.join(d, 'flag.txt'), 'w') as f:
+        f.write('abandonned donn\n')
+    # Test file has 2 invalid entries.
+    assert cs.main(f.name) == 2
+    # Ignoring donn breaks them both.
+    assert cs.main(f.name, '--ignore-regex=donn') == 0
+    # Adding word breaks causes only one to be ignored.
+    assert cs.main(f.name, r'--ignore-regex=\Wdonn\W') == 1
+
+
+def test_config(tmpdir, capsys):
+    """
+    Tests loading options from a config file.
+    """
+    d = str(tmpdir)
+
+    # Create sample files.
+    with open(op.join(d, 'bad.txt'), 'w') as f:
+        f.write('abandonned donn\n')
+    with open(op.join(d, 'good.txt'), 'w') as f:
+        f.write("good")
+
+    # Create a config file.
+    conffile = op.join(d, 'config.cfg')
+    with open(conffile, 'w') as f:
+        f.write(
+            '[codespell]\n'
+            'skip = bad.txt\n'
+            'count = \n'
+        )
+
+    # Should fail when checking both.
+    code, stdout, _ = cs.main(d, count=True, std=True)
+    # Code in this case is not exit code, but count of misspellings.
+    assert code == 2
+    assert 'bad.txt' in stdout
+
+    # Should pass when skipping bad.txt
+    code, stdout, _ = cs.main('--config', conffile, d, count=True, std=True)
+    assert code == 0
+    assert 'bad.txt' not in stdout
+
+
 @contextlib.contextmanager
 def FakeStdin(text):
     if sys.version[0] == '2':
diff -pruN 1.17.1-1/codespell_lib/tests/test_dictionary.py 2.0.0-1/codespell_lib/tests/test_dictionary.py
--- 1.17.1-1/codespell_lib/tests/test_dictionary.py	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/codespell_lib/tests/test_dictionary.py	2020-11-23 15:42:41.000000000 +0000
@@ -9,12 +9,15 @@ import warnings
 import pytest
 
 from codespell_lib._codespell import _builtin_dictionaries
+from codespell_lib._codespell import supported_languages
+
+spellers = dict()
 
 try:
     import aspell
-    speller = aspell.Speller('lang', 'en')
+    for lang in supported_languages:
+        spellers[lang] = aspell.Speller('lang', lang)
 except Exception as exp:  # probably ImportError, but maybe also language
-    speller = None
     if os.getenv('REQUIRE_ASPELL', 'false').lower() == 'true':
         raise RuntimeError(
             'Cannot run complete tests without aspell when '
@@ -34,9 +37,9 @@ global_pairs = set()
 # Filename, should be seen as errors in aspell or not
 _data_dir = op.join(op.dirname(__file__), '..', 'data')
 _fnames_in_aspell = [
-    (op.join(_data_dir, 'dictionary%s.txt' % d[2]), d[3:5])
+    (op.join(_data_dir, 'dictionary%s.txt' % d[2]), d[3:5], d[5:7])
     for d in _builtin_dictionaries]
-fname_params = pytest.mark.parametrize('fname, in_aspell', _fnames_in_aspell)
+fname_params = pytest.mark.parametrize('fname, in_aspell, in_dictionary', _fnames_in_aspell)  # noqa: E501
 
 
 def test_dictionaries_exist():
@@ -48,7 +51,7 @@ def test_dictionaries_exist():
 
 
 @fname_params
-def test_dictionary_formatting(fname, in_aspell):
+def test_dictionary_formatting(fname, in_aspell, in_dictionary):
     """Test that all dictionary entries are valid."""
     errors = list()
     with open(fname, 'rb') as fid:
@@ -57,32 +60,33 @@ def test_dictionary_formatting(fname, in
             err = err.lower()
             rep = rep.rstrip('\n')
             try:
-                _check_err_rep(err, rep, in_aspell, fname)
+                _check_err_rep(err, rep, in_aspell, fname, in_dictionary)
             except AssertionError as exp:
                 errors.append(str(exp).split('\n')[0])
     if len(errors):
         raise AssertionError('\n' + '\n'.join(errors))
 
 
-def _check_aspell(phrase, msg, in_aspell, fname):
-    if speller is None:
+def _check_aspell(phrase, msg, in_aspell, fname, languages):
+    if not spellers:  # if no spellcheckers exist
         return  # cannot check
     if in_aspell is None:
         return  # don't check
     if ' ' in phrase:
         for word in phrase.split():
-            _check_aspell(word, msg, in_aspell, fname)
+            _check_aspell(word, msg, in_aspell, fname, languages)
         return  # stop normal checking as we've done each word above
-    this_in_aspell = speller.check(
-        phrase.encode(speller.ConfigKeys()['encoding'][1]))
-    end = 'be in aspell for dictionary %s' % (fname,)
+    this_in_aspell = any(spellers[lang].check(phrase.encode(
+        spellers[lang].ConfigKeys()['encoding'][1])) for lang in languages)
+    end = 'be in aspell dictionaries (%s) for dictionary %s' % (
+        ', '.join(languages), fname)
     if in_aspell:  # should be an error in aspell
         assert this_in_aspell, '%s should %s' % (msg, end)
     else:  # shouldn't be
         assert not this_in_aspell, '%s should not %s' % (msg, end)
 
 
-def _check_err_rep(err, rep, in_aspell, fname):
+def _check_err_rep(err, rep, in_aspell, fname, languages):
     assert ws.match(err) is None, 'error %r has whitespace' % err
     assert comma.match(err) is None, 'error %r has a comma' % err
     assert len(rep) > 0, ('error %s: correction %r must be non-empty'
@@ -90,7 +94,7 @@ def _check_err_rep(err, rep, in_aspell,
     assert not re.match(r'^\s.*', rep), ('error %s: correction %r '
                                          'cannot start with whitespace'
                                          % (err, rep))
-    _check_aspell(err, 'error %r' % (err,), in_aspell[0], fname)
+    _check_aspell(err, 'error %r' % (err,), in_aspell[0], fname, languages[0])
     prefix = 'error %s: correction %r' % (err, rep)
     for (r, msg) in [
             (r'^,',
@@ -110,13 +114,19 @@ def _check_err_rep(err, rep, in_aspell,
     if rep.count(','):
         assert rep.endswith(','), ('error %s: multiple corrections must end '
                                    'with trailing ","' % (err,))
-    reps = [r.strip() for r in rep.lower().split(',')]
+    reps = [r.strip() for r in rep.split(',')]
     reps = [r for r in reps if len(r)]
     for r in reps:
         assert err != r.lower(), ('error %r corrects to itself amongst others'
                                   % (err,))
         _check_aspell(
-            r, 'error %s: correction %r' % (err, r), in_aspell[1], fname)
+            r, 'error %s: correction %r' % (err, r),
+            in_aspell[1], fname, languages[1])
+
+    # aspell dictionary is case sensitive, so pass the original case into there
+    # we could ignore the case, but that would miss things like days of the
+    # week which we want to be correct
+    reps = [r.lower() for r in reps]
     assert len(set(reps)) == len(reps), ('error %s: corrections "%s" are not '
                                          '(lower-case) unique' % (err, rep))
 
@@ -134,15 +144,16 @@ def _check_err_rep(err, rep, in_aspell,
     ('a', 'bar, bat', 'must end with trailing ","'),
     ('a', 'a, bar,', 'corrects to itself amongst others'),
     ('a', 'a', 'corrects to itself'),
-    ('a', 'bar, bar,', 'unique'),
+    ('a', 'bar, Bar,', 'unique'),
 ])
 def test_error_checking(err, rep, match):
     """Test that our error checking works."""
     with pytest.raises(AssertionError, match=match):
-        _check_err_rep(err, rep, (None, None), 'dummy')
+        _check_err_rep(err, rep, (None, None), 'dummy',
+                       (supported_languages, supported_languages))
 
 
-@pytest.mark.skipif(speller is None, reason='requires aspell')
+@pytest.mark.skipif(not spellers, reason='requires aspell-en')
 @pytest.mark.parametrize('err, rep, err_aspell, rep_aspell, match', [
     # This doesn't raise any exceptions, so skip for now:
     # pytest.param('a', 'uvw, bar,', None, None, 'should be in aspell'),
@@ -152,12 +163,14 @@ def test_error_checking(err, rep, match)
     ('abcdef', 'uvwxyz, bar,', True, True, 'should be in aspell'),
     ('abcdef', 'uvwxyz, bar,', False, True, 'should be in aspell'),
     ('a', 'bar, back,', None, False, 'should not be in aspell'),
+    ('a', 'bar, back, Wednesday,', None, False, 'should not be in aspell'),
     ('abcdef', 'ghijkl, uvwxyz,', True, False, 'should be in aspell'),
     ('abcdef', 'uvwxyz, bar,', False, False, 'should not be in aspell'),
     # Multi-word corrections
     # One multi-word, both parts
     ('a', 'abcdef uvwxyz', None, True, 'should be in aspell'),
     ('a', 'bar back', None, False, 'should not be in aspell'),
+    ('a', 'bar back Wednesday', None, False, 'should not be in aspell'),
     # Second multi-word, both parts
     ('a', 'bar back, abcdef uvwxyz, bar,', None, True, 'should be in aspell'),
     ('a', 'abcdef uvwxyz, bar back, ghijkl,', None, False, 'should not be in aspell'),  # noqa: E501
@@ -168,19 +181,23 @@ def test_error_checking(err, rep, match)
 def test_error_checking_in_aspell(err, rep, err_aspell, rep_aspell, match):
     """Test that our error checking works with aspell."""
     with pytest.raises(AssertionError, match=match):
-        _check_err_rep(err, rep, (err_aspell, rep_aspell), 'dummy')
+        _check_err_rep(
+            err, rep, (err_aspell, rep_aspell), 'dummy',
+            (supported_languages, supported_languages))
 
 
 # allow some duplicates, like "m-i-n-i-m-i-s-e", or "c-a-l-c-u-l-a-t-a-b-l-e"
 allowed_dups = {
     ('dictionary.txt', 'dictionary_en-GB_to_en-US.txt'),
     ('dictionary.txt', 'dictionary_rare.txt'),
+    ('dictionary.txt', 'dictionary_usage.txt'),
+    ('dictionary_rare.txt', 'dictionary_usage.txt'),
 }
 
 
 @fname_params
 @pytest.mark.dependency(name='dictionary loop')
-def test_dictionary_looping(fname, in_aspell):
+def test_dictionary_looping(fname, in_aspell, in_dictionary):
     """Test that all dictionary entries are valid."""
     this_err_dict = dict()
     short_fname = op.basename(fname)
@@ -240,9 +257,9 @@ def test_dictionary_looping(fname, in_as
 @pytest.mark.dependency(depends=['dictionary loop'])
 def test_ran_all():
     """Test that all pairwise tests ran."""
-    for f1, _ in _fnames_in_aspell:
+    for f1, _, _ in _fnames_in_aspell:
         f1 = op.basename(f1)
-        for f2, _ in _fnames_in_aspell:
+        for f2, _, _ in _fnames_in_aspell:
             f2 = op.basename(f2)
             assert (f1, f2) in global_pairs
     assert len(global_pairs) == len(_fnames_in_aspell) ** 2
diff -pruN 1.17.1-1/debian/changelog 2.0.0-1/debian/changelog
--- 1.17.1-1/debian/changelog	2020-05-24 21:53:06.000000000 +0000
+++ 2.0.0-1/debian/changelog	2020-11-23 19:22:39.000000000 +0000
@@ -1,3 +1,16 @@
+codespell (2.0.0-1) unstable; urgency=medium
+
+  [ Ondřej Nový ]
+  * d/control: Update Maintainer field with new Debian Python Team
+    contact address.
+  * d/control: Update Vcs-* fields with new Debian Python Team Salsa
+    layout.
+
+  [ Sylvestre Ledru ]
+  * New upstream release
+
+ -- Sylvestre Ledru <sylvestre@debian.org>  Mon, 23 Nov 2020 20:22:39 +0100
+
 codespell (1.17.1-1) unstable; urgency=medium
 
   * New upstream release
diff -pruN 1.17.1-1/debian/control 2.0.0-1/debian/control
--- 1.17.1-1/debian/control	2020-05-24 21:51:50.000000000 +0000
+++ 2.0.0-1/debian/control	2020-11-23 19:21:43.000000000 +0000
@@ -4,7 +4,7 @@ Priority: optional
 Uploaders: Sylvestre Ledru <sylvestre@debian.org>,
  Peter Spiess-Knafl <dev@spiessknafl.at>,
  Georg Faerber <georg@riseup.net>
-Maintainer: Debian Python Modules Team <python-modules-team@lists.alioth.debian.org>
+Maintainer: Debian Python Team <team+python@tracker.debian.org>
 Build-Depends:
  debhelper-compat (= 10),
  dh-python,
@@ -18,8 +18,8 @@ Build-Depends:
 # to run tests
 Standards-Version: 4.5.0
 Homepage: https://github.com/codespell-project/codespell/
-Vcs-Git: https://salsa.debian.org/python-team/modules/codespell.git
-Vcs-Browser: https://salsa.debian.org/python-team/modules/codespell
+Vcs-Git: https://salsa.debian.org/python-team/packages/codespell.git
+Vcs-Browser: https://salsa.debian.org/python-team/packages/codespell
 
 Package: codespell
 Architecture: all
diff -pruN 1.17.1-1/debian/patches/fix-pytest.diff 2.0.0-1/debian/patches/fix-pytest.diff
--- 1.17.1-1/debian/patches/fix-pytest.diff	1970-01-01 00:00:00.000000000 +0000
+++ 2.0.0-1/debian/patches/fix-pytest.diff	2020-11-23 19:22:39.000000000 +0000
@@ -0,0 +1,15 @@
+Index: codespell/Makefile
+===================================================================
+--- codespell.orig/Makefile
++++ codespell/Makefile
+@@ -27,8 +27,8 @@ check-dictionaries:
+ 			exit 1; \
+ 		fi; \
+ 	done
+-	@if command -v pytest > /dev/null; then \
+-		pytest codespell_lib/tests/test_dictionary.py; \
++	@if command -v pytest-3 > /dev/null; then \
++		pytest-3 codespell_lib/tests/test_dictionary.py; \
+ 	else \
+ 		echo "Test dependencies not present, install using 'pip install -e \".[dev]\"'"; \
+ 		exit 1; \
diff -pruN 1.17.1-1/debian/patches/series 2.0.0-1/debian/patches/series
--- 1.17.1-1/debian/patches/series	1970-01-01 00:00:00.000000000 +0000
+++ 2.0.0-1/debian/patches/series	2020-11-23 19:22:39.000000000 +0000
@@ -0,0 +1 @@
+fix-pytest.diff
diff -pruN 1.17.1-1/.github/workflows/codespell-private.yml 2.0.0-1/.github/workflows/codespell-private.yml
--- 1.17.1-1/.github/workflows/codespell-private.yml	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/.github/workflows/codespell-private.yml	2020-11-23 15:42:41.000000000 +0000
@@ -7,7 +7,13 @@ jobs:
   make-check-dictionaries:
     runs-on: ubuntu-latest
     steps:
+      - name: Set up Python
+        uses: actions/setup-python@v2
       - uses: actions/checkout@v2
+      - name: Install general dependencies
+        run: pip install -U pip wheel # upgrade to latest pip find 3.5 wheels; wheel to avoid errors
+      - name: Install codespell dependencies
+        run: pip install -e ".[dev]"
       - uses: codespell-project/sort-problem-matcher@v1
       - run: make check-dictionaries
 
diff -pruN 1.17.1-1/.github/workflows/codespell.yml 2.0.0-1/.github/workflows/codespell.yml
--- 1.17.1-1/.github/workflows/codespell.yml	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/.github/workflows/codespell.yml	2020-11-23 15:42:41.000000000 +0000
@@ -1,13 +1,16 @@
 # GitHub Action to automate the identification of common misspellings in text files.
+# https://github.com/codespell-project/actions-codespell
 # https://github.com/codespell-project/codespell
 name: codespell
 on: [push, pull_request]
 jobs:
   codespell:
+    name: Check for spelling errors
     runs-on: ubuntu-latest
     steps:
       - uses: actions/checkout@v2
-      - uses: actions/setup-python@v1
-      - run: pip install codespell
-      # When using this Action in other repos, the --skip option below can be removed
-      - run: codespell --skip=./.*,./codespell_lib/data,./example/code.c,test_basic.py,*.pyc
+      - uses: codespell-project/actions-codespell@master
+        with:
+          check_filenames: true
+          # When using this Action in other repos, the --skip option below can be removed
+          skip: ./.git,./codespell_lib/data,./example/code.c,test_basic.py,*.pyc
diff -pruN 1.17.1-1/Makefile 2.0.0-1/Makefile
--- 1.17.1-1/Makefile	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/Makefile	2020-11-23 15:42:41.000000000 +0000
@@ -2,15 +2,17 @@ SORT_ARGS := -f -b
 
 DICTIONARIES := codespell_lib/data/dictionary*.txt
 
-PHONY := all check check-dictionaries sort-dictionaries trim-dictionaries check-dictionary sort-dictionary trim-dictionary clean
+PHONY := all check check-dictionaries sort-dictionaries trim-dictionaries check-dictionary sort-dictionary trim-dictionary check-manifest check-distutils flake8 pytest pypi clean
 
 all: check-dictionaries codespell.1
 
+check: check-dictionaries check-manifest check-distutils flake8 pytest
+
 check-dictionary: check-dictionaries
 sort-dictionary: sort-dictionaries
 trim-dictionary: trim-dictionaries
 
-codespell.1: codespell.1.include bin/codespell
+codespell.1: codespell.1.include bin/codespell Makefile
 	PYTHONPATH=. help2man ./bin/codespell --include codespell.1.include --no-info --output codespell.1
 	sed -i '/\.SS \"Usage/,+2d' codespell.1
 
@@ -27,6 +29,9 @@ check-dictionaries:
 	done
 	@if command -v pytest > /dev/null; then \
 		pytest codespell_lib/tests/test_dictionary.py; \
+	else \
+		echo "Test dependencies not present, install using 'pip install -e \".[dev]\"'"; \
+		exit 1; \
 	fi
 
 sort-dictionaries:
@@ -42,6 +47,15 @@ trim-dictionaries:
 check-manifest:
 	check-manifest
 
+check-distutils:
+	python setup.py check --restructuredtext --strict
+
+flake8:
+	flake8
+
+pytest:
+	pytest codespell_lib
+
 pypi:
 	python setup.py sdist register upload
 
diff -pruN 1.17.1-1/README.rst 2.0.0-1/README.rst
--- 1.17.1-1/README.rst	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/README.rst	2020-11-23 15:42:41.000000000 +0000
@@ -19,7 +19,7 @@ Useful links
 Requirements
 ------------
 
-Python 2.7 or above.
+Python 3.5 or above.
 
 Installation
 ------------
@@ -41,11 +41,11 @@ The ``-w`` flag will actually implement
 
     codespell -I FILE, --ignore-words=FILE
 
-The ``-I`` flag can be used to whitelist certain words that are in the ``codespell_lib/data/dictionary.txt``. The format of the whitelist file is one word per line. Invoke using: ``codespell -I path/to/file.txt`` to execute codespell referencing said whitelist. **Important note:** The whitelist passed to ``-I`` is case-sensitive based on how it is listed in ``dictionary.txt``. ::
+The ``-I`` flag can be used for a list of certain words to allow that are in the codespell dictionaries. The format of the file is one word per line. Invoke using: ``codespell -I path/to/file.txt`` to execute codespell referencing said list of allowed words. **Important note:** The list passed to ``-I`` is case-sensitive based on how it is listed in the codespell dictionaries. ::
 
     codespell -L word1,word2,word3,word4
 
-The ``-L`` flag can be used to whitelist certain words that are comma-separated placed immediately after it. ::
+The ``-L`` flag can be used to allow certain words that are comma-separated placed immediately after it.  **Important note:** The list passed to ``-L`` is case-sensitive based on how it is listed in the codespell dictionaries. ::
 
     codespell -S, --skip=
 
@@ -67,24 +67,46 @@ Display them without terminal colors and
 
 Run interactive mode level 3 and write changes to file.
 
-We ship a dictionary that is an improved version of the one available
+We ship a collection of dictionaries that are an improved version of the one available
 `on Wikipedia <https://en.wikipedia.org/wiki/Wikipedia:Lists_of_common_misspellings/For_machines>`_
 after applying them in projects like Linux Kernel, EFL, oFono among others.
 You can provide your own version of the dictionary, but patches for
 new/different entries are very welcome.
 
-Want to know if a word you're proposing exists in codespell already? It is possible to test a word against the current dictionary that exists in ``codespell_lib/data/dictionary.txt`` via::
+Want to know if a word you're proposing exists in codespell already? It is possible to test a word against the current set dictionaries that exist in ``codespell_lib/data/dictionary*.txt`` via::
 
     echo "word" | codespell -
     echo "1stword,2ndword" | codespell -
 
+You can select the optional dictionaries with the ``--builtin`` option.
+
+Using a config file
+-------------------
+
+Command line options can also be specified in a config file.
+
+When running ``codespell``, it will check in the current directory for a file
+named ``setup.cfg`` or ``.codespellrc`` (or a file specified via ``--config``),
+containing an entry named ``[codespell]``. Each command line argument can
+be specified in this file (without the preceding dashes), for example::
+
+    [codespell]
+    skip = *.po,*.ts,./src/3rdParty,./src/Test
+    count =
+    quiet-level = 3
+
+This is equivalent to running::
+
+    codespell --quiet-level 3 --count --skip "*.po,*.ts,./src/3rdParty,./src/Test"
+
+Any options specified in the command line will *override* options from the
+config file.
+
 Dictionary format
 -----------------
 
-The format of the dictionary was influenced by the one it originally came from,
-i.e. from Wikipedia. The difference is how multiple options are treated and
-that the last argument is the reason why a certain entry could not be applied
-directly, but instead be manually inspected. E.g.:
+The format of the dictionaries was influenced by the one they originally came from,
+i.e. from Wikipedia. The difference is how multiple options are treated. E.g.:
 
 1. Simple entry: one wrong word / one suggestion::
 
@@ -100,12 +122,28 @@ directly, but instead be manually inspec
    to give the user the file and line where the error occurred as well as
    the suggestions.
 
-3. Entry with one word, but with automatically fix disabled::
+3. Entry with one word, but with automatic fix disabled::
 
        clas->class, disabled because of name clash in c++
 
-   Note that there isn't a comma in the end of the line. The last argument is
+   Note that there isn't a comma at the end of the line. The last argument is
    treated as the reason why a suggestion cannot be automatically applied.
+   
+   There can also be multiple suggestions but any automatic fix will again be
+   disabled::
+   
+       clas->class, clash, disabled because of name clash in c++
+
+Development Setup
+-----------------
+
+You can install required dependencies for development by running the following within a checkout of the codespell source::
+
+       pip install -e ".[dev]"
+
+To run tests against the codebase run::
+
+       make check
 
 Sending Pull Requests
 ---------------------
@@ -114,19 +152,21 @@ If you have a suggested typo that you'd
 
 1. Make sure you read the instructions mentioned in the ``Dictionary format`` section above to submit correctly formatted entries.
 
-2. Sort the dictionary. This is done by invoking (in the top level directory of ``codespell/``)::
+2. Choose the correct dictionary file to add your typo too. See `codespell --help` for explanations of the different dictionaries.
+
+3. Sort the dictionaries. This is done by invoking (in the top level directory of ``codespell/``)::
 
        make check-dictionaries
 
-   If the make script finds that you need to sort the dictionary, please then run::
+   If the make script finds that you need to sort a dictionary, please then run::
 
        make sort-dictionaries
 
-3. Only after this process is complete do we recommend you submit the PR.
+4. Only after this process is complete do we recommend you submit the PR.
 
 **Important Notes:**
 
-* If the dictionary is submitted without being pre-sorted the PR will fail via TravisCI.
+* If the dictionaries are submitted without being pre-sorted the PR will fail via our various CI tools.
 * Not all PRs will be merged. This is pending on the discretion of the devs, maintainers, and the community.
 
 Updating
@@ -145,16 +185,19 @@ To stay current with codespell developme
 * It has been reported that after installing from ``pip``, codespell can't be located. Please check the $PATH variable to see if ``~/.local/bin`` is present. If it isn't then add it to your path.
 * If you decide to install via ``pip`` then be sure to remove any previously installed versions of codespell (via your platform's preferred app manager).
 
-Updating the dictionary
------------------------
+Updating the dictionaries
+-------------------------
 
-In the scenario where the user prefers not to follow the development version of codespell yet still opts to benefit from the frequently updated `dictionary.txt` file, we recommend running a simple set of commands to achieve this ::
+In the scenario where the user prefers not to follow the development version of codespell yet still opts to benefit from the frequently updated dictionary files, we recommend running a simple set of commands to achieve this ::
 
     wget https://raw.githubusercontent.com/codespell-project/codespell/master/codespell_lib/data/dictionary.txt
     codespell -D dictionary.txt
 
 The above simply downloads the latest ``dictionary.txt`` file and then by utilizing the ``-D`` flag allows the user to specify the freshly downloaded ``dictionary.txt`` as the custom dictionary instead of the default one.
 
+You can also do the same thing for the other dictionaries listed here:
+    https://github.com/codespell-project/codespell/tree/master/codespell_lib/data
+
 License
 -------
 
@@ -181,6 +224,7 @@ with the following terms:
 
 .. _GPL v2: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
-dictionary.txt is a derived work of English Wikipedia and is released under the
-Creative Commons Attribution-Share-Alike License 3.0
+``dictionary.txt`` and the other ``dictionary_*.txt`` files are a derived work of
+English Wikipedia and are released under the Creative Commons
+Attribution-Share-Alike License 3.0
 http://creativecommons.org/licenses/by-sa/3.0/
diff -pruN 1.17.1-1/setup.py 2.0.0-1/setup.py
--- 1.17.1-1/setup.py	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/setup.py	2020-11-23 15:42:41.000000000 +0000
@@ -43,17 +43,26 @@ if __name__ == "__main__":
                        'Operating System :: Unix',
                        'Operating System :: MacOS'],
           platforms='any',
+          python_requires='>=3.5',
           packages=[
-              'codespell_lib', 'codespell_lib.tests',
+              'codespell_lib',
               'codespell_lib.data',
           ],
           package_data={'codespell_lib': [
               op.join('data', 'dictionary*.txt'),
               op.join('data', 'linux-kernel.exclude'),
           ]},
+          exclude_package_data={'codespell_lib': [
+              op.join('tests', '*'),
+          ]},
           entry_points={
               'console_scripts': [
                   'codespell = codespell_lib:_script_main'
               ],
+          },
+          extras_require={
+              "dev": ["check-manifest", "flake8", "pytest", "pytest-cov",
+                      "pytest-dependency"],
+              "hard-encoding-detection": ["chardet"],
           }
           )
diff -pruN 1.17.1-1/.travis.yml 2.0.0-1/.travis.yml
--- 1.17.1-1/.travis.yml	2020-05-22 13:31:13.000000000 +0000
+++ 2.0.0-1/.travis.yml	2020-11-23 15:42:41.000000000 +0000
@@ -4,11 +4,10 @@
 # for it to be on multiple physical lines, so long as you remember: - There
 # can't be any leading "-"s - All newlines will be removed, so use ";"s
 
-dist: bionic
+dist: focal
 language: python
 cache: pip
 python:
-  - 2.7
   - 3.5
   - 3.6
   - 3.7
@@ -30,26 +29,20 @@ before_install:
     - source venv/bin/activate
     - python --version  # just to check
     - pip install -U pip wheel # upgrade to latest pip find 3.5 wheels; wheel to avoid errors
-    - retry pip install pytest pytest-cov pytest-dependency flake8 coverage codecov chardet setuptools docutils check-manifest
-    - if [ ${TRAVIS_PYTHON_VERSION:0:1} == "2" ]; then retry pip install aspell-python-py2; fi
-    - if [ ${TRAVIS_PYTHON_VERSION:0:1} == "3" ]; then retry pip install aspell-python-py3; fi
+    - retry pip install codecov chardet "setuptools!=47.2.0" docutils
+    - retry pip install aspell-python-py3
     - cd $SRC_DIR
+    - pip install -e ".[dev]" # install the codespell dev packages
 
 install:
     - python setup.py install
 
 script:
     - codespell --help
-    - make check-dictionary
-    - codespell --skip="codespell_lib/tests/test_basic.py,codespell_lib/data/*" codespell_lib/
+    - make check
+    - codespell --check-filenames --skip="./.git/*,*.pyc,./codespell_lib/tests/test_basic.py,./codespell_lib/data/*,./example/code.c,./build/lib/codespell_lib/tests/test_basic.py,./build/lib/codespell_lib/data/*"
     # this file has an error
     - "! codespell codespell_lib/tests/test_basic.py"
-    - flake8
-    - if [ "$TRAVIS_PYTHON_VERSION" != "2.7" ]; then
-        python setup.py check --restructuredtext --strict;
-      fi;
-    - pytest codespell_lib
-    - make check-manifest
 
 after_success:
     - codecov
